@@ -26,6 +26,8 @@ MagickDLLDeclExtern const std::string Magick::borderGeometryDefault = "6x6+0+0";
 MagickDLLDeclExtern const std::string Magick::frameGeometryDefault  = "25x25+6+6";
 MagickDLLDeclExtern const std::string Magick::raiseGeometryDefault  = "6x6+0+0";
 
+static bool magick_initialized=false;
+
 //
 // Explicit template instantiations
 //
@@ -647,16 +649,16 @@ void Magick::Image::draw ( const Magick::Drawable &drawable_ )
 {
   modifyImage();
 
-  DrawContext context = DrawAllocateContext( options()->drawInfo(), image());
+  DrawingWand *wand = DrawAllocateWand( options()->drawInfo(), image());
 
-  if(context)
+  if(wand)
     {
-      drawable_.operator()(context);
+      drawable_.operator()(wand);
 
       if( constImage()->exception.severity == UndefinedException)
-        DrawRender(context);
+        DrawRender(wand);
 
-      DrawDestroyContext(context);
+      DestroyDrawingWand(wand);
     }
 
   throwImageException();
@@ -667,22 +669,22 @@ void Magick::Image::draw ( const std::list<Magick::Drawable> &drawable_ )
 {
   modifyImage();
 
-  DrawContext context = DrawAllocateContext( options()->drawInfo(), image());
+  DrawingWand *wand = DrawAllocateWand( options()->drawInfo(), image());
 
-  if(context)
+  if(wand)
     {
       for( std::list<Magick::Drawable>::const_iterator p = drawable_.begin();
            p != drawable_.end(); p++ )
         {
-          p->operator()(context);
+          p->operator()(wand);
           if( constImage()->exception.severity != UndefinedException)
             break;
         }
 
       if( constImage()->exception.severity == UndefinedException)
-        DrawRender(context);
+        DrawRender(wand);
 
-      DrawDestroyContext(context);
+      DestroyDrawingWand(wand);
     }
 
   throwImageException();
@@ -2072,25 +2074,19 @@ void Magick::Image::colorSpace( const ColorspaceType colorSpace_ )
 
   modifyImage();
 
-  if ( image()->colorspace == RGBColorspace ||
-       image()->colorspace == TransparentColorspace ||
-       image()->colorspace == GRAYColorspace )
+  if ( colorSpace_ != RGBColorspace &&
+       colorSpace_ != TransparentColorspace &&
+       colorSpace_ != GRAYColorspace )
     {
-      // Convert the image to an alternate colorspace representation
-      // In:			Out:
-      // RGBColorspace		RGBColorspace (no conversion)
-      // TransparentColorspace	TransparentColorspace (no conversion)
-      // GRAYColorspace		GRAYColorspace (no conversion if really Gray)
-      // RGBColorspace		CMYKColorspace
-      // RGBColorspace		GRAYColorspace
-      // RGBColorspace		OHTAColorspace
-      // RGBColorspace		sRGBColorspace
-      // RGBColorspace		XYZColorspace
-      // RGBColorspace		YCbCrColorspace
-      // RGBColorspace		YCCColorspace
-      // RGBColorspace		YIQColorspace
-      // RGBColorspace		YPbPrColorspace
-      // RGBColorspace		YUVColorspace
+      if (image()->colorspace != RGBColorspace &&
+          image()->colorspace != TransparentColorspace &&
+          image()->colorspace != GRAYColorspace)
+        {
+          /* Transform to RGB colorspace as intermediate step */
+          TransformRGBImage( image(), image()->colorspace );
+          throwImageException();
+        }
+      /* Transform to final non-RGB colorspace */
       RGBTransformImage( image(), colorSpace_ );
       throwImageException();
       return;
@@ -2100,21 +2096,8 @@ void Magick::Image::colorSpace( const ColorspaceType colorSpace_ )
        colorSpace_ == TransparentColorspace ||
        colorSpace_ == GRAYColorspace )
     {
-      // Convert the image from an alternate colorspace representation
-      // In:			Out:
-      // CMYKColorspace		RGBColorspace
-      // RGBColorspace          RGBColorspace (no conversion)
-      // GRAYColorspace         GRAYColorspace (no conversion)
-      // TransparentColorspace	TransparentColorspace (no conversion)
-      // OHTAColorspace		RGBColorspace
-      // sRGBColorspace		RGBColorspace
-      // XYZColorspace		RGBColorspace
-      // YCbCrColorspace	RGBColorspace
-      // YCCColorspace		RGBColorspace
-      // YIQColorspace		RGBColorspace
-      // YPbPrColorspace        RGBColorspace
-      // YUVColorspace		RGBColorspace
-      TransformRGBImage( image(), colorSpace_ );
+      /* Transform to a RGB-type colorspace */
+      TransformRGBImage( image(), image()->colorspace );
       throwImageException();
       return;
     }
@@ -2193,6 +2176,20 @@ void Magick::Image::density ( const Geometry &density_ )
 }
 Magick::Geometry Magick::Image::density ( void ) const
 {
+  if (isValid())
+    {
+      unsigned int x_resolution=72;
+      unsigned int y_resolution=72;
+
+      if (constImage()->x_resolution > 0.0)
+        x_resolution=static_cast<unsigned int>(constImage()->x_resolution + 0.5);
+
+      if (constImage()->y_resolution > 0.0)
+        y_resolution=static_cast<unsigned int>(constImage()->y_resolution + 0.5);
+
+      return Geometry(x_resolution,y_resolution);
+    }
+
   return constOptions()->density( );
 }
 
@@ -3306,10 +3303,10 @@ void Magick::Image::writePixels ( const Magick::QuantumType quantum_,
 
 
 //
-// Construct using Image and Magick::Options
+// Construct using existing image and default options
 //
 Magick::Image::Image ( MagickLib::Image* image_ )
-  : _imgRef(new ImageRef( image_, new Magick::Options() ))
+  : _imgRef(new ImageRef( image_))
 {
 }
 
@@ -3447,6 +3444,36 @@ void Magick::Image::unregisterId( void )
   _imgRef->id( -1 );
 }
 
+//
+// Create a local wrapper around DestroyMagick
+//
+namespace Magick
+{
+  extern "C" {
+    void MagickPlusPlusDestroyMagick(void);
+  }
+}
+
+void Magick::MagickPlusPlusDestroyMagick(void)
+{
+  if (magick_initialized)
+    {
+      magick_initialized=false;
+      MagickLib::DestroyMagick();
+    }
+}
+
+// C library initialization routine
+void MagickDLLDecl Magick::InitializeMagick(const char *path_)
+{
+  MagickLib::InitializeMagick(path_);
+  if (!magick_initialized)
+    {
+      magick_initialized=true;
+      atexit(MagickPlusPlusDestroyMagick);
+    }
+}
+
 //
 // Cleanup class to ensure that ImageMagick singletons are destroyed
 // so as to avoid any resemblence to a memory leak (which seems to
@@ -3469,10 +3496,10 @@ namespace Magick
 
 Magick::MagickCleanUp::MagickCleanUp ( void )
 {
-  // InitializeMagick(NULL);
+  // Don't even think about invoking InitializeMagick here!
 }
 
 Magick::MagickCleanUp::~MagickCleanUp ( void )
 {
-  DestroyMagick();
+  MagickPlusPlusDestroyMagick();
 }
