@@ -52,13 +52,14 @@
 /*
   Include declarations.
 */
-#include "studio.h"
-#include "blob.h"
-#include "list.h"
-#include "magick.h"
-#include "monitor.h"
-#include "static.h"
-#include "utility.h"
+#include "magick/studio.h"
+#include "magick/blob.h"
+#include "magick/error.h"
+#include "magick/list.h"
+#include "magick/magick.h"
+#include "magick/monitor.h"
+#include "magick/static.h"
+#include "magick/utility.h"
 
 /*
   Forward declarations.
@@ -91,7 +92,7 @@ static unsigned int
 %      reading. A null image is returned if there is a memory shortage or if
 %      the image cannot be read.
 %
-%    o image_info: Specifies a pointer to an ImageInfo structure.
+%    o image_info: The image info.
 %
 %    o exception: return any errors or warnings in this structure.
 %
@@ -187,7 +188,7 @@ static Image *ReadAVSImage(const ImageInfo *image_info,ExceptionInfo *exception)
     LiberateMemory((void **) &pixels);
     if (EOFBlob(image))
       {
-        ThrowException(exception,CorruptImageError,"UnexpectedEndOfFile",
+        (void) ThrowException(exception,CorruptImageError,"UnexpectedEndOfFile",
           image->filename);
         break;
       }
@@ -305,9 +306,9 @@ ModuleExport void UnregisterAVSImage(void)
 %      False is returned is there is a memory shortage or if the image file
 %      fails to write.
 %
-%    o image_info: Specifies a pointer to an ImageInfo structure.
+%    o image_info: The image info.
 %
-%    o image:  A pointer to a Image structure.
+%    o image:  The image.
 %
 %
 */
@@ -348,7 +349,7 @@ static unsigned int WriteAVSImage(const ImageInfo *image_info,Image *image)
     /*
       Write AVS header.
     */
-    (void) TransformRGBImage(image,image->colorspace);
+    (void) SetImageColorspace(image,RGBColorspace);
     (void) WriteBlobMSBLong(image,image->columns);
     (void) WriteBlobMSBLong(image,image->rows);
     /*
