@@ -53,14 +53,15 @@
 /*
   Include declarations.
 */
-#include "studio.h"
-#include "blob.h"
-#include "list.h"
-#include "log.h"
-#include "magick.h"
-#include "monitor.h"
-#include "static.h"
-#include "utility.h"
+#include "magick/studio.h"
+#include "magick/blob.h"
+#include "magick/error.h"
+#include "magick/list.h"
+#include "magick/log.h"
+#include "magick/magick.h"
+#include "magick/monitor.h"
+#include "magick/static.h"
+#include "magick/utility.h"
 
 /*
   Macro definitions (from Windows wingdi.h).
@@ -316,7 +317,7 @@ static unsigned int DecodeImage(Image *image,const unsigned long compression,
 %    o status:  Method EncodeImage returns the number of bytes in the
 %      runlength encoded compress_pixels array.
 %
-%    o image:  A pointer to a Image structure.
+%    o image:  The image.
 %
 %    o bytes_per_line: The number of bytes in a scanline of compressed pixels
 %
@@ -453,7 +454,7 @@ static unsigned int IsBMP(const unsigned char *magick,const size_t length)
 %      reading.  A null image is returned if there is a memory shortage or
 %      if the image cannot be read.
 %
-%    o image_info: Specifies a pointer to an ImageInfo structure.
+%    o image_info: The image info.
 %
 %    o exception: return any errors or warnings in this structure.
 %
@@ -1245,7 +1246,7 @@ static Image *ReadBMPImage(const ImageInfo *image_info,ExceptionInfo *exception)
     LiberateMemory((void **) &pixels);
     if (EOFBlob(image))
       {
-        ThrowException(exception,CorruptImageError,"UnexpectedEndOfFile",
+        (void) ThrowException(exception,CorruptImageError,"UnexpectedEndOfFile",
           image->filename);
         break;
       }
@@ -1406,9 +1407,9 @@ ModuleExport void UnregisterBMPImage(void)
 %      False is returned is there is a memory shortage or if the image file
 %      fails to write.
 %
-%    o image_info: Specifies a pointer to an ImageInfo structure.
+%    o image_info: The image info.
 %
-%    o image:  A pointer to a Image structure.
+%    o image:  The image.
 %
 %
 */
@@ -1472,7 +1473,7 @@ static unsigned int WriteBMPImage(const ImageInfo *image_info,Image *image)
     /*
       Initialize BMP raster file header.
     */
-    (void) TransformRGBImage(image,image->colorspace);
+    (void) SetImageColorspace(image,RGBColorspace);
     memset(&bmp_info,0,sizeof(BMPInfo));
     bmp_info.file_size=14+12;
     if (type > 2)
@@ -1480,7 +1481,7 @@ static unsigned int WriteBMPImage(const ImageInfo *image_info,Image *image)
     bmp_info.offset_bits=bmp_info.file_size;
     bmp_info.compression=BI_RGB;
     if ((image->storage_class != DirectClass) && (image->colors > 256))
-      SetImageType(image,TrueColorType);
+      image->storage_class=DirectClass;
     if (image->storage_class != DirectClass)
       {
         /*
@@ -1495,10 +1496,10 @@ static unsigned int WriteBMPImage(const ImageInfo *image_info,Image *image)
           bmp_info.bits_per_pixel=8;
         bmp_info.number_colors=1 << bmp_info.bits_per_pixel;
         if (image->matte)
-          SetImageType(image,TrueColorMatteType);
+          image->storage_class=DirectClass;
         else
           if (bmp_info.number_colors < image->colors)
-            SetImageType(image,TrueColorType);
+            image->storage_class=DirectClass;
           else
             {
               bmp_info.file_size+=3*(1 << bmp_info.bits_per_pixel);
@@ -1572,6 +1573,7 @@ static unsigned int WriteBMPImage(const ImageInfo *image_info,Image *image)
     pixels=(unsigned char *) AcquireMemory(bmp_info.image_size);
     if (pixels == (unsigned char *) NULL)
       ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed",image);
+    (void) memset(pixels,0,bmp_info.image_size);
     switch (bmp_info.bits_per_pixel)
     {
       case 1:
@@ -1712,8 +1714,8 @@ static unsigned int WriteBMPImage(const ImageInfo *image_info,Image *image)
             Convert run-length encoded raster pixels.
           */
           length=2*(bytes_per_line+2)*(image->rows+2)+2;
-          bmp_data=(unsigned char *) AcquireMemory(length);
-          if (pixels == (unsigned char *) NULL)
+          bmp_data=(unsigned char *) AcquireMemory(length+bytes_per_line);
+          if (bmp_data == (unsigned char *) NULL)
             {
               LiberateMemory((void **) &pixels);
               ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed",
