@@ -52,13 +52,14 @@
 /*
   Include declarations.
 */
-#include "studio.h"
-#include "blob.h"
-#include "list.h"
-#include "magick.h"
-#include "monitor.h"
-#include "static.h"
-#include "utility.h"
+#include "magick/studio.h"
+#include "magick/blob.h"
+#include "magick/error.h"
+#include "magick/list.h"
+#include "magick/magick.h"
+#include "magick/monitor.h"
+#include "magick/static.h"
+#include "magick/utility.h"
 
 /*
   Forward declaractions.
@@ -130,7 +131,7 @@ static unsigned int IsDPX(const unsigned char *magick,const size_t length)
 %      reading. A null image is returned if there is a memory shortage or if
 %      the image cannot be read.
 %
-%    o image_info: Specifies a pointer to an ImageInfo structure.
+%    o image_info: The image info.
 %
 %    o exception: return any errors or warnings in this structure.
 %
@@ -262,7 +263,7 @@ static Image *ReadDPXImage(const ImageInfo *image_info,ExceptionInfo *exception)
       ThrowReaderException(CorruptImageError,"ColorTypeNotSupported",image)
   }
   if (EOFBlob(image))
-    ThrowException(exception,CorruptImageError,"UnexpectedEndOfFile",
+    (void) ThrowException(exception,CorruptImageError,"UnexpectedEndOfFile",
       image->filename);
   CloseBlob(image);
   return(image);
@@ -352,9 +353,9 @@ ModuleExport void UnregisterDPXImage(void)
 %      False is returned is there is a memory shortage or if the image file
 %      fails to write.
 %
-%    o image_info: Specifies a pointer to an ImageInfo structure.
+%    o image_info: The image info.
 %
-%    o image:  A pointer to a Image structure.
+%    o image:  The image.
 %
 %
 */
@@ -386,7 +387,7 @@ static unsigned int WriteDPXImage(const ImageInfo *image_info,Image *image)
   status=OpenBlob(image_info,image,WriteBinaryBlobMode,&image->exception);
   if (status == False)
     ThrowWriterException(FileOpenError,"UnableToOpenFile",image);
-  (void) TransformRGBImage(image,image->colorspace);
+  (void) SetImageColorspace(image,RGBColorspace);
   (void) WriteBlobMSBLong(image,0x53445058);
   (void) WriteBlobMSBLong(image,0x2000);
   (void) WriteBlobMSBLong(image,0x56312E30);
