@@ -50,12 +50,13 @@
  * Include declarations.
  */
 
-#include "studio.h"
-#include "blob.h"
-#include "list.h"
-#include "magick.h"
-#include "static.h"
-#include "utility.h"
+#include "magick/studio.h"
+#include "magick/blob.h"
+#include "magick/error.h"
+#include "magick/list.h"
+#include "magick/magick.h"
+#include "magick/static.h"
+#include "magick/utility.h"
 #if defined(HasWINGDI32)
 #  if defined(__CYGWIN__)
 #    include <windows.h>
@@ -353,7 +354,7 @@ static Image *ReadEMFImage(const ImageInfo *image_info,
   image=AllocateImage(image_info);
   hemf=ReadEnhMetaFile(image_info->filename,&width,&height);
   if (!hemf)
-    ThrowReaderException(CorruptImageWarning,"NotAnEMFImageFile",image);
+    ThrowReaderException(CorruptImageError,"NotAnEMFImageFile",image);
   if ((image->columns == 0) || (image->rows == 0))
     {
       double
