@@ -52,14 +52,15 @@
 /*
   Include declarations.
 */
-#include "studio.h"
-#include "attribute.h"
-#include "blob.h"
-#include "list.h"
-#include "magick.h"
-#include "monitor.h"
-#include "static.h"
-#include "utility.h"
+#include "magick/studio.h"
+#include "magick/attribute.h"
+#include "magick/blob.h"
+#include "magick/error.h"
+#include "magick/list.h"
+#include "magick/magick.h"
+#include "magick/monitor.h"
+#include "magick/static.h"
+#include "magick/utility.h"
 #if defined(HasFPX)
 #if !defined(vms) && !defined(macintosh) && !defined(WIN32)
 #include <fpxlib.h>
@@ -138,7 +139,7 @@ static unsigned int IsFPX(const unsigned char *magick,const size_t length)
 %      reading. A null image is returned if there is a memory shortage or if
 %      the image cannot be read.
 %
-%    o image_info: Specifies a pointer to an ImageInfo structure.
+%    o image_info: The image info.
 %
 %    o exception: return any errors or warnings in this structure.
 %
@@ -221,7 +222,9 @@ static Image *ReadFPXImage(const ImageInfo *image_info,ExceptionInfo *exception)
   /*
     Initialize FPX toolkit.
   */
-  FPX_InitSystem();
+  fpx_status=FPX_InitSystem();
+  if (fpx_status != FPX_OK)
+    ThrowReaderException(CoderError,"UnableToInitializeFPXLibrary",image);
   memory_limit=20000000;
   fpx_status=FPX_SetToolkitMemoryLimit(&memory_limit);
   if (fpx_status != FPX_OK)
@@ -477,8 +480,8 @@ static Image *ReadFPXImage(const ImageInfo *image_info,ExceptionInfo *exception)
 #else
 static Image *ReadFPXImage(const ImageInfo *image_info,ExceptionInfo *exception)
 {
-  ThrowException(exception,CoderError,"FPXLibraryIsNotAvailable",
-    image_info->filename);
+  (void) ThrowException(exception,MissingDelegateError,
+    "FPXLibraryIsNotAvailable",image_info->filename);
   return((Image *) NULL);
 }
 #endif
@@ -571,9 +574,9 @@ ModuleExport void UnregisterFPXImage(void)
 %      False is returned is there is a memory shortage or if the image file
 %      fails to write.
 %
-%    o image_info: Specifies a pointer to an ImageInfo structure.
+%    o image_info: The image info.
 %
-%    o image:  A pointer to a Image structure.
+%    o image:  The image.
 %
 %
 */
@@ -826,7 +829,7 @@ static unsigned int WriteFPXImage(const ImageInfo *image_info,Image *image)
     Initialize FPX toolkit.
   */
   image->depth=8;
-  (void) TransformRGBImage(image,image->colorspace);
+  (void) SetImageColorspace(image,RGBColorspace);
   memory_limit=20000000;
   fpx_status=FPX_SetToolkitMemoryLimit(&memory_limit);
   if (fpx_status != FPX_OK)
@@ -924,7 +927,7 @@ static unsigned int WriteFPXImage(const ImageInfo *image_info,Image *image)
       if (summary_info.comments.ptr != (unsigned char *) NULL)
         (void) strcpy((char *) summary_info.comments.ptr,comment->value);
       else
-        ThrowWriterException(DelegateError,"UnableToSetImageComments",image);
+        ThrowWriterException(DelegateError,"UnableToSetImageComment",image);
     }
   fpx_status=FPX_SetSummaryInformation(flashpix,&summary_info);
   if (fpx_status != FPX_OK)
@@ -1114,7 +1117,7 @@ static unsigned int WriteFPXImage(const ImageInfo *image_info,Image *image)
 #else
 static unsigned int WriteFPXImage(const ImageInfo *image_info,Image *image)
 {
-  ThrowBinaryException(CoderError,"FPXLibraryIsNotAvailable",
+  ThrowBinaryException(MissingDelegateError,"FPXLibraryIsNotAvailable",
     image->filename)
 }
 #endif
