@@ -52,13 +52,15 @@
 /*
   Include declarations.
 */
-#include "studio.h"
-#include "attribute.h"
-#include "blob.h"
-#include "magick.h"
-#include "monitor.h"
-#include "static.h"
-#include "utility.h"
+#include "magick/studio.h"
+#include "magick/attribute.h"
+#include "magick/blob.h"
+#include "magick/error.h"
+#include "magick/magick.h"
+#include "magick/monitor.h"
+#include "magick/resource.h"
+#include "magick/static.h"
+#include "magick/utility.h"
 
 /*
   Forward declarations.
@@ -158,9 +160,9 @@ ModuleExport void UnregisterHISTOGRAMImage(void)
 %      False is returned is there is a memory shortage or if the image file
 %      fails to write.
 %
-%    o image_info: Specifies a pointer to an ImageInfo structure.
+%    o image_info: The image info.
 %
-%    o image:  A pointer to a Image structure.
+%    o image:  The image.
 %
 %
 */
@@ -181,6 +183,9 @@ static unsigned int WriteHISTOGRAMImage(const ImageInfo *image_info,
   Image
     *histogram_image;
 
+  int
+    unique_file;
+
   long
     *blue,
     *green,
@@ -228,7 +233,7 @@ static unsigned int WriteHISTOGRAMImage(const ImageInfo *image_info,
     &image->exception);
   if (histogram_image == (Image *) NULL)
     ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed",image);
-  SetImageType(histogram_image,TrueColorType);
+  histogram_image->matte=True;
   /*
     Allocate histogram count arrays.
   */
@@ -329,9 +334,11 @@ static unsigned int WriteHISTOGRAMImage(const ImageInfo *image_info,
   LiberateMemory((void **) &blue);
   LiberateMemory((void **) &green);
   LiberateMemory((void **) &red);
-  TemporaryFilename(filename);
-  file=fopen(filename,"wb");
-  if (file != (FILE *) NULL)
+  file=(FILE *) NULL;
+  unique_file=AcquireUniqueFileResource(filename);
+  if (unique_file != -1)
+    file=fdopen(unique_file,"wb");
+  if ((unique_file != -1) && (file != (FILE *) NULL))
     {
       char
         command[MaxTextExtent];
@@ -343,8 +350,8 @@ static unsigned int WriteHISTOGRAMImage(const ImageInfo *image_info,
       (void) fclose(file);
       FormatString(command,"@%.1024s",filename);
       (void) SetImageAttribute(histogram_image,"comment",command);
-      (void) remove(filename);
     }
+  (void) LiberateUniqueFileResource(filename);
   /*
     Write Histogram image as MIFF.
   */
