@@ -52,13 +52,14 @@
 /*
   Include declarations.
 */
-#include "studio.h"
-#include "attribute.h"
-#include "blob.h"
-#include "magick.h"
-#include "paint.h"
-#include "static.h"
-#include "utility.h"
+#include "magick/studio.h"
+#include "magick/attribute.h"
+#include "magick/blob.h"
+#include "magick/error.h"
+#include "magick/magick.h"
+#include "magick/paint.h"
+#include "magick/static.h"
+#include "magick/utility.h"
 
 /*
   Forward declarations.
@@ -206,9 +207,9 @@ ModuleExport void UnregisterHTMLImage(void)
 %      False is returned is there is a memory shortage or if the image file
 %      fails to write.
 %
-%    o image_info: Specifies a pointer to an ImageInfo structure.
+%    o image_info: The image info.
 %
-%    o image:  A pointer to a Image structure.
+%    o image:  The image.
 %
 %
 */
@@ -247,7 +248,7 @@ static unsigned int WriteHTMLImage(const ImageInfo *image_info,Image *image)
   if (status == False)
     ThrowWriterException(FileOpenError,"UnableToOpenFile",image);
   CloseBlob(image);
-  (void) TransformRGBImage(image,image->colorspace);
+  (void) SetImageColorspace(image,RGBColorspace);
   *url='\0';
   if ((LocaleCompare(image_info->magick,"FTP") == 0) ||
       (LocaleCompare(image_info->magick,"HTTP") == 0))
@@ -320,8 +321,7 @@ static unsigned int WriteHTMLImage(const ImageInfo *image_info,Image *image)
       */
       SetGeometry(image,&geometry);
       if (image->montage != (char *) NULL)
-        (void) ParseMetaGeometry(image->montage,&geometry.x,&geometry.y,
-          &geometry.width,&geometry.height);
+        (void) ParseAbsoluteGeometry(image->montage,&geometry);
       /*
         Write an image map.
       */
@@ -401,8 +401,7 @@ static unsigned int WriteHTMLImage(const ImageInfo *image_info,Image *image)
   */
   SetGeometry(image,&geometry);
   if (image->montage != (char *) NULL)
-    (void) ParseMetaGeometry(image->montage,&geometry.x,&geometry.y,
-      &geometry.width,&geometry.height);
+    (void) ParseAbsoluteGeometry(image->montage,&geometry);
   /*
     Write an image map.
   */
