@@ -52,13 +52,14 @@
 /*
   Include declarations.
 */
-#include "studio.h"
-#include "blob.h"
-#include "list.h"
-#include "magick.h"
-#include "monitor.h"
-#include "static.h"
-#include "utility.h"
+#include "magick/studio.h"
+#include "magick/blob.h"
+#include "magick/error.h"
+#include "magick/list.h"
+#include "magick/magick.h"
+#include "magick/monitor.h"
+#include "magick/static.h"
+#include "magick/utility.h"
 
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -86,7 +87,7 @@
 %      reading.  A null image is returned if there is a memory shortage or
 %      if the image cannot be read.
 %
-%    o image_info: Specifies a pointer to an ImageInfo structure.
+%    o image_info: The image info.
 %
 %    o exception: return any errors or warnings in this structure.
 %
@@ -191,7 +192,8 @@ static Image *ReadIconImage(const ImageInfo *image_info,
   icon_file.reserved=ReadBlobLSBShort(image);
   icon_file.resource_type=ReadBlobLSBShort(image);
   icon_file.count=ReadBlobLSBShort(image);
-  if ((icon_file.reserved != 0) || (icon_file.resource_type != 1) ||
+  if ((icon_file.reserved != 0) ||
+      ((icon_file.resource_type != 1) && (icon_file.resource_type != 2)) ||
       (icon_file.count > MaxIcons))
     ThrowReaderException(CorruptImageError,"NotAnICOImageFile",image);
   for (i=0; i < icon_file.count; i++)
@@ -478,7 +480,7 @@ static Image *ReadIconImage(const ImageInfo *image_info,
     }
     if (EOFBlob(image))
       {
-        ThrowException(exception,CorruptImageError,"UnexpectedEndOfFile",
+        (void) ThrowException(exception,CorruptImageError,"UnexpectedEndOfFile",
           image->filename);
         break;
       }
@@ -540,6 +542,13 @@ ModuleExport void RegisterICONImage(void)
   MagickInfo
     *entry;
 
+  entry=SetMagickInfo("CUR");
+  entry->decoder=(DecoderHandler) ReadIconImage;
+  entry->adjoin=False;
+  entry->seekable_stream=True;
+  entry->description=AcquireString("Microsoft icon");
+  entry->module=AcquireString("CUR");
+  (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("ICO");
   entry->decoder=(DecoderHandler) ReadIconImage;
   entry->adjoin=False;
