@@ -56,15 +56,29 @@
 /*
   Include declarations.
 */
-#include "studio.h"
-#include "attribute.h"
-#include "blob.h"
-#include "list.h"
-#include "log.h"
-#include "magick.h"
-#include "monitor.h"
-#include "static.h"
-#include "utility.h"
+#include "magick/studio.h"
+#include "magick/attribute.h"
+#include "magick/blob.h"
+#include "magick/error.h"
+#include "magick/list.h"
+#include "magick/log.h"
+#include "magick/magick.h"
+#include "magick/monitor.h"
+#include "magick/static.h"
+#include "magick/utility.h"
+
+/*
+  Include declarations.
+*/
+#include "magick/studio.h"
+#include "magick/attribute.h"
+#include "magick/blob.h"
+#include "magick/error.h"
+#include "magick/cache.h"
+#include "magick/log.h"
+#include "magick/magick.h"
+#include "magick/monitor.h"
+#include "magick/utility.h"
 
 /*
   Forward declarations.
@@ -192,7 +206,7 @@ typedef struct _SourceManager
 %      reading.  A null image is returned if there is a memory shortage or
 %      if the image cannot be read.
 %
-%    o image_info: Specifies a pointer to an ImageInfo structure.
+%    o image_info: The image info.
 %
 %    o exception: return any errors or warnings in this structure.
 %
@@ -223,7 +237,7 @@ static unsigned int EmitMessage(j_common_ptr jpeg_info,int level)
     }
   else
     if (jpeg_info->err->trace_level >= level)
-      ThrowBinaryException(CoderWarning,(char *) message,image->filename);
+      ThrowBinaryException(CoderError,(char *) message,image->filename);
   return(True);
 }
 
@@ -335,6 +349,9 @@ static boolean ReadGenericProfile(j_decompress_ptr jpeg_info)
   register unsigned char
     *p;
 
+  int
+    marker;
+
   /*
     Determine length of generic profile.
   */
@@ -343,6 +360,7 @@ static boolean ReadGenericProfile(j_decompress_ptr jpeg_info)
   length-=2;
   if (length <= 0)
     return(True);
+  marker=jpeg_info->unread_marker-JPEG_APP0;
   /*
     Allocate generic profile.
   */
@@ -352,7 +370,8 @@ static boolean ReadGenericProfile(j_decompress_ptr jpeg_info)
   if (image->generic_profile == (ProfileInfo *) NULL)
     image->generic_profile=(ProfileInfo *) AcquireMemory(sizeof(ProfileInfo));
   else
-    ReacquireMemory((void **) &image->generic_profile,(i+1)*sizeof(ProfileInfo));
+    ReacquireMemory((void **) &image->generic_profile,
+      (i+1)*sizeof(ProfileInfo));
   if (image->generic_profile == (ProfileInfo *) NULL)
     {
       image->generic_profiles=0;
@@ -360,8 +379,7 @@ static boolean ReadGenericProfile(j_decompress_ptr jpeg_info)
         (char *) NULL)
     }
   image->generic_profile[i].name=AllocateString((char *) NULL);
-  FormatString(image->generic_profile[i].name,"APP%d",jpeg_info->unread_marker-
-    JPEG_APP0);
+  FormatString(image->generic_profile[i].name,"APP%d",marker);
   image->generic_profile[i].info=(unsigned char *) AcquireMemory(length);
   if (image->generic_profile[i].info == (unsigned char *) NULL)
     ThrowBinaryException(ResourceLimitError,"MemoryAllocationFailed",
@@ -374,6 +392,15 @@ static boolean ReadGenericProfile(j_decompress_ptr jpeg_info)
     image->generic_profile[i].name,length);
   for (p=image->generic_profile[i].info; --length >= 0; p++)
     *p=GetCharacter(jpeg_info);
+  length=image->generic_profile[i].length;
+  p=image->generic_profile[i].info;
+  if (marker == 1)
+    {
+      if ((length > 4) && (LocaleNCompare((char *) p,"EXIF",4) == 0))
+        FormatString(image->generic_profile[i].name,"APP1");
+      if ((length > 5) && (LocaleNCompare((char *) p,"http:",5) == 0))
+        FormatString(image->generic_profile[i].name,"XMP");
+    }
   image->generic_profiles++;
   return(True);
 }
@@ -460,12 +487,12 @@ static boolean ReadIPTCProfile(j_decompress_ptr jpeg_info)
     length,
     tag_length;
 
-  register long
-    i;
-
   register unsigned char
     *p;
 
+  register long
+    i;
+
 #ifdef GET_ONLY_IPTC_DATA
   unsigned char
     tag[MaxTextExtent];
@@ -571,6 +598,7 @@ static void SkipInputData(j_decompress_ptr cinfo,long number_bytes)
 
 static void TerminateSource(j_decompress_ptr cinfo)
 {
+  cinfo=cinfo;
 }
 
 static void JPEGSourceManager(j_decompress_ptr cinfo,Image *image)
@@ -594,7 +622,8 @@ static void JPEGSourceManager(j_decompress_ptr cinfo,Image *image)
   source->image=image;
 }
 
-static Image *ReadJPEGImage(const ImageInfo *image_info,ExceptionInfo *exception)
+static Image *ReadJPEGImage(const ImageInfo *image_info,
+  ExceptionInfo *exception)
 {
   ErrorManager
     error_manager;
@@ -637,6 +666,9 @@ static Image *ReadJPEGImage(const ImageInfo *image_info,ExceptionInfo *exception
     logging,
     status;
 
+  unsigned long
+    number_pixels;
+
   /*
     Open image file.
   */
@@ -662,9 +694,10 @@ static Image *ReadJPEGImage(const ImageInfo *image_info,ExceptionInfo *exception
       if (jpeg_pixels != (JSAMPLE *) NULL)
         LiberateMemory((void **) &jpeg_pixels);
       jpeg_destroy_decompress(&jpeg_info);
-      ThrowException(exception,image->exception.severity,
+      (void) ThrowException(exception,image->exception.severity,
         image->exception.reason,image->exception.description);
-      if ((image->columns != 0) && (image->rows != 0))
+      number_pixels=image->columns*image->rows;
+      if (number_pixels != 0)
         return(image);
       DestroyImage(image);
       return((Image *) NULL);
@@ -696,7 +729,8 @@ static Image *ReadJPEGImage(const ImageInfo *image_info,ExceptionInfo *exception
             image->units=PixelsPerCentimeterResolution;
         }
     }
-  if ((image->columns != 0) && (image->rows != 0))
+  number_pixels=image->columns*image->rows;
+  if (number_pixels != 0)
     {
       double
         scale_factor;
@@ -712,12 +746,12 @@ static Image *ReadJPEGImage(const ImageInfo *image_info,ExceptionInfo *exception
         scale_factor=(double) jpeg_info.output_height/image->rows;
       jpeg_info.scale_denom=(unsigned int) scale_factor;
       jpeg_calc_output_dimensions(&jpeg_info);
-      (void) LogMagickEvent(CoderEvent,GetMagickModule(),"Scale_factor: %ld",
+      (void) LogMagickEvent(CoderEvent,GetMagickModule(),"Scale factor: %ld",
         (long) scale_factor);
     }
-  if (image_info->number_scenes != 0)
+  if (image_info->subrange != 0)
     {
-      jpeg_info.scale_denom=(int) image_info->number_scenes;
+      jpeg_info.scale_denom=(int) image_info->subrange;
       jpeg_calc_output_dimensions(&jpeg_info);
     }
 #if (JPEG_LIB_VERSION >= 61) && defined(D_PROGRESSIVE_SUPPORTED)
@@ -727,7 +761,7 @@ static Image *ReadJPEGImage(const ImageInfo *image_info,ExceptionInfo *exception
   image->compression=jpeg_info.process == JPROC_LOSSLESS ?
     LosslessJPEGCompression : JPEGCompression;
   if (jpeg_info.data_precision > 8)
-    MagickError(OptionError,
+    (void) ThrowException(exception,OptionError,
       "12-bit JPEG not supported. Reducing pixel data to 8 bits",(char *) NULL);
 #else
   image->interlace=jpeg_info.progressive_mode ? PlaneInterlace : NoInterlace;
@@ -758,87 +792,87 @@ static Image *ReadJPEGImage(const ImageInfo *image_info,ExceptionInfo *exception
           "Quality: 100 (lossless)");
       else
 #endif
+      {
+        int
+          hashval,
+          sum;
+
+        /*
+          Log the JPEG quality that was used for compression.A
+        */
+        sum=0;
+        for (i=0; i < NUM_QUANT_TBLS; i++)
         {
           int
-            hashval,
-            sum;
+            j;
 
-          /*
-            Log the JPEG quality that was used for compression.
-          */
-          sum=0;
-          for (i=0; i < NUM_QUANT_TBLS; i++)
-          {
-            int
-              j;
+          if (jpeg_info.quant_tbl_ptrs[i] != NULL)
+            for (j=0; j < DCTSIZE2; j++)
+            {
+              UINT16
+                *c;
 
-            if (jpeg_info.quant_tbl_ptrs[i] != NULL)
-              for (j=0; j < DCTSIZE2; j++)
-              {
-                UINT16
-                  *c;
-
-                c=jpeg_info.quant_tbl_ptrs[i]->quantval;
-                sum+=c[j];
-              }
-           }
-           if ((jpeg_info.quant_tbl_ptrs[0] != NULL) &&
-               (jpeg_info.quant_tbl_ptrs[1] != NULL))
+              c=jpeg_info.quant_tbl_ptrs[i]->quantval;
+              sum+=c[j];
+            }
+        }
+       if ((jpeg_info.quant_tbl_ptrs[0] != NULL) &&
+           (jpeg_info.quant_tbl_ptrs[1] != NULL))
+         {
+           int
+             hash[]=
              {
-               int
-                 hash[]=
-                 {
-                   1020, 1015,  932,  848,  780,  735,  702,  679,  660,  645,
-                    632,  623,  613,  607,  600,  594,  589,  585,  581,  571,
-                    555,  542,  529,  514,  494,  474,  457,  439,  424,  410,
-                    397,  386,  373,  364,  351,  341,  334,  324,  317,  309,
-                    299,  294,  287,  279,  274,  267,  262,  257,  251,  247,
-                    243,  237,  232,  227,  222,  217,  213,  207,  202,  198,
-                    192,  188,  183,  177,  173,  168,  163,  157,  153,  148,
-                    143,  139,  132,  128,  125,  119,  115,  108,  104,   99,
-                     94,   90,   84,   79,   74,   70,   64,   59,   55,   49,
-                     45,   40,   34,   30,   25,   20,   15,   11,    6,    4,
-                      0
-                 },
-                 sums[]=
-                 {
-                   32640,32635,32266,31495,30665,29804,29146,28599,28104,27670,
-                   27225,26725,26210,25716,25240,24789,24373,23946,23572,22846,
-                   21801,20842,19949,19121,18386,17651,16998,16349,15800,15247,
-                   14783,14321,13859,13535,13081,12702,12423,12056,11779,11513,
-                   11135,10955,10676,10392,10208, 9928, 9747, 9564, 9369, 9193,
-                    9017, 8822, 8639, 8458, 8270, 8084, 7896, 7710, 7527, 7347,
-                    7156, 6977, 6788, 6607, 6422, 6236, 6054, 5867, 5684, 5495,
-                    5305, 5128, 4945, 4751, 4638, 4442, 4248, 4065, 3888, 3698,
-                    3509, 3326, 3139, 2957, 2775, 2586, 2405, 2216, 2037, 1846,
-                    1666, 1483, 1297, 1109,  927,  735,  554,  375,  201,  128,
-                       0
-                 };
+                1020, 1015,  932,  848,  780,  735,  702,  679,  660,  645,
+                 632,  623,  613,  607,  600,  594,  589,  585,  581,  571,
+                 555,  542,  529,  514,  494,  474,  457,  439,  424,  410,
+                 397,  386,  373,  364,  351,  341,  334,  324,  317,  309,
+                 299,  294,  287,  279,  274,  267,  262,  257,  251,  247,
+                 243,  237,  232,  227,  222,  217,  213,  207,  202,  198,
+                 192,  188,  183,  177,  173,  168,  163,  157,  153,  148,
+                 143,  139,  132,  128,  125,  119,  115,  108,  104,   99,
+                  94,   90,   84,   79,   74,   70,   64,   59,   55,   49,
+                  45,   40,   34,   30,   25,   20,   15,   11,    6,    4,
+                   0
+             },
+             sums[]=
+             {
+               32640,32635,32266,31495,30665,29804,29146,28599,28104,27670,
+               27225,26725,26210,25716,25240,24789,24373,23946,23572,22846,
+               21801,20842,19949,19121,18386,17651,16998,16349,15800,15247,
+               14783,14321,13859,13535,13081,12702,12423,12056,11779,11513,
+               11135,10955,10676,10392,10208, 9928, 9747, 9564, 9369, 9193,
+                9017, 8822, 8639, 8458, 8270, 8084, 7896, 7710, 7527, 7347,
+                7156, 6977, 6788, 6607, 6422, 6236, 6054, 5867, 5684, 5495,
+                5305, 5128, 4945, 4751, 4638, 4442, 4248, 4065, 3888, 3698,
+                3509, 3326, 3139, 2957, 2775, 2586, 2405, 2216, 2037, 1846,
+                1666, 1483, 1297, 1109,  927,  735,  554,  375,  201,  128,
+                   0
+             };
 
-               hashval=(jpeg_info.quant_tbl_ptrs[0]->quantval[2]+
-                 jpeg_info.quant_tbl_ptrs[0]->quantval[53]+
-                 jpeg_info.quant_tbl_ptrs[1]->quantval[0]+
-                 jpeg_info.quant_tbl_ptrs[1]->quantval[DCTSIZE2-1]);
-               for (i=0; i < 100; i++)
+           hashval=(jpeg_info.quant_tbl_ptrs[0]->quantval[2]+
+             jpeg_info.quant_tbl_ptrs[0]->quantval[53]+
+             jpeg_info.quant_tbl_ptrs[1]->quantval[0]+
+             jpeg_info.quant_tbl_ptrs[1]->quantval[DCTSIZE2-1]);
+           for (i=0; i < 100; i++)
+           {
+             if ((hashval >= hash[i]) || (sum >= sums[i]))
                {
-                 if ((hashval >= hash[i]) || (sum >= sums[i]))
-                   {
-                     if ((hashval > hash[i]) || (sum > sums[i]))
-                       (void) LogMagickEvent(CoderEvent,GetMagickModule(),
-                         "Quality: %ld (approximate)",i+1);
-                     else
-                       (void) LogMagickEvent(CoderEvent,GetMagickModule(),
-                         "Quality: %ld",i+1);
-                     break;
-                   }
+                 if ((hashval > hash[i]) || (sum > sums[i]))
+                   (void) LogMagickEvent(CoderEvent,GetMagickModule(),
+                     "Quality: %ld (approximate)",i+1);
+                 else
+                   (void) LogMagickEvent(CoderEvent,GetMagickModule(),
+                     "Quality: %ld",i+1);
+                 break;
                }
-             }
-           else
-             if (jpeg_info.quant_tbl_ptrs[0] != NULL)
-             {
-               int
-                 bwhash[]=
-                 {
+           }
+         }
+       else
+         if (jpeg_info.quant_tbl_ptrs[0] != NULL)
+           {
+             int
+               bwhash[]=
+               {
                    510,  505,  422,  380,  355,  338,  326,  318,  311,  305,
                    300,  297,  293,  291,  288,  286,  284,  283,  281,  280,
                    279,  278,  277,  273,  262,  251,  243,  233,  225,  218,
@@ -850,39 +884,39 @@ static Image *ReadJPEGImage(const ImageInfo *image_info,ExceptionInfo *exception
                     50,   48,   44,   42,   39,   37,   34,   31,   29,   26,
                     24,   21,   18,   16,   13,   11,    8,    6,    3,    2,
                      0
-                 },
-                 bwsum[]=
-                 {
-                   16320,16315,15946,15277,14655,14073,13623,13230,12859,12560,
-                   12240,11861,11456,11081,10714,10360,10027, 9679, 9368, 9056,
-                    8680, 8331, 7995, 7668, 7376, 7084, 6823, 6562, 6345, 6125,
-                    5939, 5756, 5571, 5421, 5240, 5086, 4976, 4829, 4719, 4616,
-                    4463, 4393, 4280, 4166, 4092, 3980, 3909, 3835, 3755, 3688,
-                    3621, 3541, 3467, 3396, 3323, 3247, 3170, 3096, 3021, 2952,
-                    2874, 2804, 2727, 2657, 2583, 2509, 2437, 2362, 2290, 2211,
-                    2136, 2068, 1996, 1915, 1858, 1773, 1692, 1620, 1552, 1477,
-                    1398, 1326, 1251, 1179, 1109, 1031,  961,  884,  814,  736,
-                     667,  592,  518,  441,  369,  292,  221,  151,   86,   64,
-                       0
-                 };
-
-               hashval=(jpeg_info.quant_tbl_ptrs[0]->quantval[2]+
-                 jpeg_info.quant_tbl_ptrs[0]->quantval[53]);
-               for (i=0; i < 100; i++)
+               },
+               bwsum[]=
                {
-                 if ((hashval >= bwhash[i]) || (sum >= bwsum[i]))
-                   {
-                     if ((hashval > bwhash[i]) || (sum > bwsum[i]))
-                       (void) LogMagickEvent(CoderEvent,GetMagickModule(),
-                         "Quality: %ld (approximate)",i+1);
-                     else
-                       (void) LogMagickEvent(CoderEvent,GetMagickModule(),
-                         "Quality: %ld",i+1);
-                     break;
-                   }
-               }
+                 16320,16315,15946,15277,14655,14073,13623,13230,12859,12560,
+                 12240,11861,11456,11081,10714,10360,10027, 9679, 9368, 9056,
+                  8680, 8331, 7995, 7668, 7376, 7084, 6823, 6562, 6345, 6125,
+                  5939, 5756, 5571, 5421, 5240, 5086, 4976, 4829, 4719, 4616,
+                  4463, 4393, 4280, 4166, 4092, 3980, 3909, 3835, 3755, 3688,
+                  3621, 3541, 3467, 3396, 3323, 3247, 3170, 3096, 3021, 2952,
+                  2874, 2804, 2727, 2657, 2583, 2509, 2437, 2362, 2290, 2211,
+                  2136, 2068, 1996, 1915, 1858, 1773, 1692, 1620, 1552, 1477,
+                  1398, 1326, 1251, 1179, 1109, 1031,  961,  884,  814,  736,
+                   667,  592,  518,  441,  369,  292,  221,  151,   86,   64,
+                     0
+               };
+
+             hashval=(jpeg_info.quant_tbl_ptrs[0]->quantval[2]+
+               jpeg_info.quant_tbl_ptrs[0]->quantval[53]);
+             for (i=0; i < 100; i++)
+             {
+               if ((hashval >= bwhash[i]) || (sum >= bwsum[i]))
+                 {
+                   if ((hashval > bwhash[i]) || (sum > bwsum[i]))
+                     (void) LogMagickEvent(CoderEvent,GetMagickModule(),
+                       "Quality: %ld (approximate)",i+1);
+                   else
+                     (void) LogMagickEvent(CoderEvent,GetMagickModule(),
+                       "Quality: %ld",i+1);
+                   break;
+                 }
              }
-        }
+          }
+      }
       switch (jpeg_info.out_color_space)
       {
         case JCS_CMYK:
@@ -906,8 +940,7 @@ static Image *ReadJPEGImage(const ImageInfo *image_info,ExceptionInfo *exception
           (void) LogMagickEvent(CoderEvent,GetMagickModule(),
             "Colorspace: GRAYSCALE");
           (void) LogMagickEvent(CoderEvent,GetMagickModule(),
-            "Sampling factors: (%d,%d)",
-            jpeg_info.comp_info[0].h_samp_factor,
+            "Sampling factors: (%d,%d)",jpeg_info.comp_info[0].h_samp_factor,
             jpeg_info.comp_info[0].v_samp_factor);
           break;
         }
@@ -971,48 +1004,42 @@ static Image *ReadJPEGImage(const ImageInfo *image_info,ExceptionInfo *exception
     if (jpeg_info.data_precision > 8)
       {
         if (jpeg_info.out_color_space == JCS_GRAYSCALE)
+          for (x=0; x < (long) image->columns; x++)
           {
-            for (x=0; x < (long) image->columns; x++)
-            {
-              index=ConstrainColormapIndex(image,16*GETJSAMPLE(*p++));
-              indexes[x]=index;
-              *q++=image->colormap[index];
-            }
+            index=(IndexPacket) (16*GETJSAMPLE(*p++));
+            ConstrainColormapIndex(image,index);
+            indexes[x]=index;
+            *q++=image->colormap[index];
           }
         else
+          for (x=0; x < (long) image->columns; x++)
           {
-            for (x=0; x < (long) image->columns; x++)
-            {
-              q->red=ScaleShortToQuantum(16*GETJSAMPLE(*p++));
-              q->green=ScaleShortToQuantum(16*GETJSAMPLE(*p++));
-              q->blue=ScaleShortToQuantum(16*GETJSAMPLE(*p++));
-              if (image->colorspace == CMYKColorspace)
-                q->opacity=ScaleShortToQuantum(16*GETJSAMPLE(*p++));
-              q++;
-            }
+            q->red=ScaleShortToQuantum(16*GETJSAMPLE(*p++));
+            q->green=ScaleShortToQuantum(16*GETJSAMPLE(*p++));
+            q->blue=ScaleShortToQuantum(16*GETJSAMPLE(*p++));
+            if (image->colorspace == CMYKColorspace)
+              q->opacity=ScaleShortToQuantum(16*GETJSAMPLE(*p++));
+            q++;
           }
       }
     else
       if (jpeg_info.out_color_space == JCS_GRAYSCALE)
+        for (x=0; x < (long) image->columns; x++)
         {
-          for (x=0; x < (long) image->columns; x++)
-          {
-            index=ConstrainColormapIndex(image,GETJSAMPLE(*p++));
-            indexes[x]=index;
-            *q++=image->colormap[index];
-          }
+          index=(IndexPacket) (GETJSAMPLE(*p++));
+          ConstrainColormapIndex(image,index);
+          indexes[x]=index;
+          *q++=image->colormap[index];
         }
       else
+        for (x=0; x < (long) image->columns; x++)
         {
-          for (x=0; x < (long) image->columns; x++)
-          {
-            q->red=ScaleCharToQuantum(GETJSAMPLE(*p++));
-            q->green=ScaleCharToQuantum(GETJSAMPLE(*p++));
-            q->blue=ScaleCharToQuantum(GETJSAMPLE(*p++));
-            if (image->colorspace == CMYKColorspace)
-              q->opacity=ScaleCharToQuantum(GETJSAMPLE(*p++));
-            q++;
-          }
+          q->red=ScaleCharToQuantum(GETJSAMPLE(*p++));
+          q->green=ScaleCharToQuantum(GETJSAMPLE(*p++));
+          q->blue=ScaleCharToQuantum(GETJSAMPLE(*p++));
+          if (image->colorspace == CMYKColorspace)
+            q->opacity=ScaleCharToQuantum(GETJSAMPLE(*p++));
+          q++;
         }
     if (!SyncImagePixels(image))
       break;
@@ -1051,8 +1078,8 @@ static Image *ReadJPEGImage(const ImageInfo *image_info,ExceptionInfo *exception
   CloseBlob(image);
   if (logging)
     (void) LogMagickEvent(CoderEvent,GetMagickModule(),"return");
-  ThrowException(exception,image->exception.severity,image->exception.reason,
-    image->exception.description);
+  (void) ThrowException(exception,image->exception.severity,
+    image->exception.reason,image->exception.description);
   return(image);
 }
 #endif
@@ -1086,13 +1113,13 @@ ModuleExport void RegisterJPEGImage(void)
     *entry;
 
   entry=SetMagickInfo("JPEG");
+  entry->thread_support=False;
 #if defined(HasJPEG)
   entry->decoder=(DecoderHandler) ReadJPEGImage;
   entry->encoder=(EncoderHandler) WriteJPEGImage;
 #endif
   entry->magick=(MagickHandler) IsJPEG;
   entry->adjoin=False;
-  entry->thread_support=False;
   entry->description=
     AcquireString("Joint Photographic Experts Group JFIF format");
 #if defined(JPEG_LIB_VERSION)
@@ -1106,12 +1133,12 @@ ModuleExport void RegisterJPEGImage(void)
 #endif
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("JPG");
+  entry->thread_support=False;
 #if defined(HasJPEG)
   entry->decoder=(DecoderHandler) ReadJPEGImage;
   entry->encoder=(EncoderHandler) WriteJPEGImage;
 #endif
   entry->adjoin=False;
-  entry->thread_support=False;
   entry->description=
     AcquireString("Joint Photographic Experts Group JFIF format");
   entry->module=AcquireString("JPEG");
@@ -1169,9 +1196,9 @@ ModuleExport void UnregisterJPEGImage(void)
 %      False is returned is there is of a memory shortage or if the image
 %      file cannot be opened for writing.
 %
-%    o image_info: Specifies a pointer to an ImageInfo structure.
+%    o image_info: The image info.
 %
-%    o jpeg_image:  A pointer to a Image structure.
+%    o jpeg_image:  The image.
 %
 %
 */
@@ -1216,12 +1243,12 @@ static unsigned int JPEGWarningHandler(j_common_ptr jpeg_info,int level)
     {
       if ((jpeg_info->err->num_warnings == 0) ||
           (jpeg_info->err->trace_level >= 3))
-        ThrowBinaryException(CoderWarning,(char *) message,image->filename);
+        ThrowBinaryException(CoderError,(char *) message,image->filename);
       jpeg_info->err->num_warnings++;
     }
   else
     if (jpeg_info->err->trace_level >= level)
-      ThrowBinaryException(CoderWarning,(char *) message,image->filename);
+      ThrowBinaryException(CoderError,(char *) message,image->filename);
   return(True);
 }
 
@@ -1338,15 +1365,61 @@ static void JPEGDestinationManager(j_compress_ptr cinfo,Image * image)
   destination->image=image;
 }
 
+static char **SamplingFactorToList(const char *text)
+{
+  char
+    **textlist;
+
+  register char
+    *q;
+
+  register const char
+    *p;
+
+  register long
+    i;
+
+  unsigned long
+    lines;
+
+  if (text == (char *) NULL)
+    return((char **) NULL);
+  /*
+    Convert string to an ASCII list.
+  */
+  lines=1;
+  for (p=text; *p != '\0'; p++)
+    if (*p == ',')
+      lines++;
+  textlist=(char **) AcquireMemory((lines+MaxTextExtent)*sizeof(char *));
+  if (textlist == (char **) NULL)
+    MagickFatalError(ResourceLimitFatalError,"MemoryAllocationFailed",
+      "UnableToConvertText");
+  p=text;
+  for (i=0; i < (long) lines; i++)
+  {
+    for (q=(char *) p; *q != '\0'; q++)
+      if (*q == ',')
+        break;
+    textlist[i]=(char *) AcquireMemory(q-p+MaxTextExtent);
+    if (textlist[i] == (char *) NULL)
+      MagickFatalError(ResourceLimitFatalError,"MemoryAllocationFailed",
+        "UnableToConvertText");
+    (void) strncpy(textlist[i],p,q-p);
+    textlist[i][q-p]='\0';
+    if (*q == '\r')
+      q++;
+    p=q+1;
+  }
+  textlist[i]=(char *) NULL;
+  return(textlist);
+}
+
 static unsigned int WriteJPEGImage(const ImageInfo *image_info,Image *image)
 {
   const ImageAttribute
     *attribute;
 
-  double
-    x_resolution,
-    y_resolution;
-
   JSAMPLE
     *jpeg_pixels;
 
@@ -1399,6 +1472,7 @@ static unsigned int WriteJPEGImage(const ImageInfo *image_info,Image *image)
   jpeg_info.image_height=(unsigned int) image->rows;
   jpeg_info.input_components=3;
   jpeg_info.data_precision=(int) Min(image->depth,BITS_IN_JSAMPLE);
+
   jpeg_info.in_color_space=JCS_RGB;
   switch (image_info->colorspace)
   {
@@ -1406,15 +1480,13 @@ static unsigned int WriteJPEGImage(const ImageInfo *image_info,Image *image)
     {
       jpeg_info.input_components=4;
       jpeg_info.in_color_space=JCS_CMYK;
-      if (image->colorspace != CMYKColorspace)
-        (void) RGBTransformImage(image,CMYKColorspace);
+      (void) SetImageColorspace(image,CMYKColorspace);
       break;
     }
     case YCbCrColorspace:
     {
       jpeg_info.in_color_space=JCS_YCbCr;
-      if (image->colorspace != YCbCrColorspace)
-        (void) RGBTransformImage(image,YCbCrColorspace);
+      (void) SetImageColorspace(image,YCbCrColorspace);
       break;
     }
     default:
@@ -1430,8 +1502,7 @@ static unsigned int WriteJPEGImage(const ImageInfo *image_info,Image *image)
           jpeg_info.in_color_space=JCS_YCbCr;
           break;
         }
-      if (image->colorspace != RGBColorspace)
-        (void) TransformRGBImage(image,image->colorspace);
+      (void) SetImageColorspace(image,RGBColorspace);
       break;
     }
   }
@@ -1442,24 +1513,6 @@ static unsigned int WriteJPEGImage(const ImageInfo *image_info,Image *image)
       jpeg_info.in_color_space=JCS_GRAYSCALE;
     }
   jpeg_set_defaults(&jpeg_info);
-  x_resolution=72.0;
-  y_resolution=72.0;
-  if (image_info->density != (char *) NULL)
-    {
-      GeometryInfo
-        geometry_info;
-
-      unsigned int
-        flags;
-
-      flags=ParseGeometry(image_info->density,&geometry_info);
-      x_resolution=geometry_info.rho;
-      y_resolution=geometry_info.sigma;
-      if (!(flags & SigmaValue))
-        y_resolution=x_resolution;
-    }
-  image->x_resolution=x_resolution;
-  image->y_resolution=y_resolution;
   jpeg_info.density_unit=1;  /* default to DPI */
   if (logging)
     (void) LogMagickEvent(CoderEvent,GetMagickModule(),
@@ -1502,7 +1555,7 @@ static unsigned int WriteJPEGImage(const ImageInfo *image_info,Image *image)
     {
 #if defined(C_LOSSLESS_SUPPORTED)
       if (image_info->quality < 100)
-        ThrowException(&image->exception,CoderWarning,
+        (void) ThrowException(&image->exception,CoderWarning,
           "LosslessToLossyJPEGConversion",(char *) NULL);
       else
         {
@@ -1538,8 +1591,20 @@ static unsigned int WriteJPEGImage(const ImageInfo *image_info,Image *image)
         (void) LogMagickEvent(CoderEvent,GetMagickModule(),"Quality: %lu",
           image_info->quality);
     }
-  if (image_info->sampling_factor != (char *) NULL)
+  if (image_info->sampling_factor == (char *) NULL)
     {
+      if (image_info->quality >= 90)
+        for (i=0; i < MAX_COMPONENTS; i++)
+        {
+          jpeg_info.comp_info[i].h_samp_factor=1;
+          jpeg_info.comp_info[i].v_samp_factor=1;
+        }
+    }
+  else
+    {
+      char
+        **sampling_factor;
+
       GeometryInfo
         geometry_info;
 
@@ -1549,10 +1614,27 @@ static unsigned int WriteJPEGImage(const ImageInfo *image_info,Image *image)
       /*
         Set sampling factor.
       */
+      i=0;
+      sampling_factor=SamplingFactorToList(image_info->sampling_factor);
+      if (sampling_factor != (char **) NULL)
+        {
+          for (i=0; i < MAX_COMPONENTS; i++)
+          {
+            if (sampling_factor[i] == (char *) NULL)
+              break;
+            flags=ParseGeometry(sampling_factor[i],&geometry_info);
+            if (!(flags & SigmaValue))
+              geometry_info.sigma=geometry_info.rho;
+            jpeg_info.comp_info[i].h_samp_factor=(int) geometry_info.rho;
+            jpeg_info.comp_info[i].v_samp_factor=(int) geometry_info.sigma;
+            LiberateMemory((void **) &sampling_factor[i]);
+          }
+          LiberateMemory((void **) &sampling_factor);
+        }
       flags=ParseGeometry(image_info->sampling_factor,&geometry_info);
       if (!(flags & SigmaValue))
         geometry_info.sigma=geometry_info.rho;
-      for (i=0; i < MAX_COMPONENTS; i++)
+      for ( ; i < MAX_COMPONENTS; i++)
       {
         jpeg_info.comp_info[i].h_samp_factor=(int) geometry_info.rho;
         jpeg_info.comp_info[i].v_samp_factor=(int) geometry_info.sigma;
@@ -1626,7 +1708,7 @@ static unsigned int WriteJPEGImage(const ImageInfo *image_info,Image *image)
         case RGBColorspace:
         {
           (void) LogMagickEvent(CoderEvent,GetMagickModule(),
-            "Image colorspace is RGB");
+            " Image colorspace is RGB");
           (void) LogMagickEvent(CoderEvent,GetMagickModule(),
             "Sampling factors: (%d,%d),(%d,%d),(%d,%d)",
             jpeg_info.comp_info[0].h_samp_factor,
@@ -1845,7 +1927,7 @@ static unsigned int WriteJPEGImage(const ImageInfo *image_info,Image *image)
         }
   jpeg_finish_compress(&jpeg_info);
   /*
-    Free memory.
+    Free resources.
   */
   jpeg_destroy_compress(&jpeg_info);
   LiberateMemory((void **) &jpeg_pixels);
