@@ -52,12 +52,13 @@
 /*
   Include declarations.
 */
-#include "studio.h"
-#include "blob.h"
-#include "list.h"
-#include "magick.h"
-#include "static.h"
-#include "utility.h"
+#include "magick/studio.h"
+#include "magick/blob.h"
+#include "magick/error.h"
+#include "magick/list.h"
+#include "magick/magick.h"
+#include "magick/static.h"
+#include "magick/utility.h"
 
 /*
   Forward declarations.
@@ -94,6 +95,7 @@ static unsigned int
 %
 %
 */
+#ifdef IMPLEMENT_IS_FUNCTION
 static unsigned int IsMETA(const unsigned char *magick,const size_t length)
 {
   if (length < 4)
@@ -102,10 +104,11 @@ static unsigned int IsMETA(const unsigned char *magick,const size_t length)
     return(True);
   if (LocaleNCompare((char *) magick,"APP1",4) == 0)
     return(True);
-  if (memcmp(magick,"\034\002",2) == 0)
+  if (LocaleNCompare((char *) magick,"\034\002",2) == 0)
     return(True);
   return(False);
 }
+#endif
 
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -497,6 +500,262 @@ static long parse8BIM(Image *ifile, Image *ofile)
   return outputlen;
 }
 
+static char *super_fgets_w(char **b, int *blen, Image *file)
+{
+  int
+    c,
+    len;
+
+  unsigned char
+    *q;
+
+  len=*blen;
+  for (q=(unsigned char *) (*b); ; q++)
+  {
+    c=ReadBlobLSBShort(file);
+    if (c == ((unsigned short) ~0) || c == '\n')
+      break;
+   if (EOFBlob(file))
+      break;
+   if ((q-(unsigned char *) (*b)+1) >= (int) len)
+      {
+        int
+          tlen;
+
+        tlen=q-(unsigned char *) (*b);
+        len<<=1;
+        ReacquireMemory((void **) b,(len+2));
+        if ((*b) == (char *) NULL)
+          break;
+        q=(unsigned char*) (*b)+tlen;
+      }
+    *q=(unsigned char) c;
+  }
+  *blen=0;
+  if ((*b) != (char *) NULL)
+    {
+      int
+        tlen;
+
+      tlen=q-(unsigned char *) (*b);
+      if (tlen == 0)
+        return (char *) NULL;
+      (*b)[tlen] = '\0';
+      *blen=++tlen;
+    }
+  return (*b);
+}
+
+static long parse8BIMW(Image *ifile, Image *ofile)
+{
+  char
+    brkused,
+    quoted,
+    *line,
+    *token,
+    *newstr,
+    *name;
+
+  int
+    state,
+    next;
+
+  unsigned char
+    dataset;
+
+  unsigned int
+    recnum;
+
+  int
+    inputlen = BUFFER_SZ;
+
+  long
+    savedolen = 0L,
+    outputlen = 0L;
+
+  ExtendedSignedIntegralType
+    savedpos,
+    currentpos;
+
+  TokenInfo
+    token_info;
+
+  dataset = 0;
+  recnum = 0;
+  line = (char *) AcquireMemory(inputlen);
+  name = token = (char *)NULL;
+  savedpos = 0;
+  while(super_fgets_w(&line,&inputlen,ifile)!=NULL)
+  {
+    state=0;
+    next=0;
+
+    token = (char *) AcquireMemory(inputlen);
+    newstr = (char *) AcquireMemory(inputlen);
+    while (Tokenizer(&token_info, 0, token, inputlen, line,
+          (char *) "", (char *) "=",
+      (char *) "\"", 0, &brkused,&next,&quoted)==0)
+    {
+      if (state == 0)
+        {
+          int
+            state,
+            next;
+
+          char
+            brkused,
+            quoted;
+
+          state=0;
+          next=0;
+          while(Tokenizer(&token_info, 0, newstr, inputlen, token, (char *) "",
+            (char *) "#", (char *) "", 0, &brkused, &next, &quoted)==0)
+          {
+            switch (state)
+            {
+              case 0:
+                if (strcmp(newstr,"8BIM")==0)
+                  dataset = 255;
+                else
+                  dataset = (unsigned char) atoi(newstr);
+                break;
+              case 1:
+                recnum = atoi(newstr);
+                break;
+              case 2:
+                name = (char *) AcquireMemory(strlen(newstr)+1);
+                if (name)
+                  strcpy(name,newstr);
+                break;
+            }
+            state++;
+          }
+        }
+      else
+        if (state == 1)
+          {
+            int
+              next;
+
+            unsigned long
+              len;
+
+            char
+              brkused,
+              quoted;
+
+            next=0;
+            len = strlen(token);
+            while (Tokenizer(&token_info,0, newstr, inputlen, token, (char *) "",
+              (char *) "&", (char *) "", 0, &brkused, &next, &quoted)==0)
+            {
+              if (brkused && next > 0)
+                {
+                  char
+                    *s = &token[next-1];
+
+                  len -= convertHTMLcodes(s, strlen(s));
+                }
+            }
+
+            if (dataset == 255)
+              {
+                unsigned char
+                  nlen = 0;
+
+                int
+                  i;
+
+                if (savedolen > 0)
+                  {
+                    long diff = outputlen - savedolen;
+                    currentpos = TellBlob(ofile);
+                    SeekBlob(ofile,savedpos,SEEK_SET);
+                    WriteBlobMSBLong(ofile,diff);
+                    SeekBlob(ofile,currentpos,SEEK_SET);
+                    savedolen = 0L;
+                  }
+                if (outputlen & 1)
+                  {
+                    WriteBlobByte(ofile,0x00);
+                    outputlen++;
+                  }
+                WriteBlobString(ofile,"8BIM");
+                WriteBlobMSBShort(ofile,recnum);
+                outputlen += 6;
+                if (name)
+                  nlen = strlen(name);
+                WriteBlobByte(ofile,nlen);
+                outputlen++;
+                for (i=0; i<nlen; i++)
+                  WriteBlobByte(ofile,name[i]);
+                outputlen += nlen;
+                if (!(nlen&1))
+                  {
+                    WriteBlobByte(ofile,0x00);
+                    outputlen++;
+                  }
+                if (recnum != IPTC_ID)
+                  {
+                    WriteBlobMSBLong(ofile, len);
+                    outputlen += 4;
+
+                    next=0;
+                    outputlen += len;
+                    while (len--)
+                      WriteBlobByte(ofile,token[next++]);
+
+                    if (outputlen & 1)
+                      {
+                        WriteBlobByte(ofile,0x00);
+                        outputlen++;
+                      }
+                  }
+                else
+                  {
+                    /* patch in a fake length for now and fix it later */
+                    savedpos = TellBlob(ofile);
+                    WriteBlobMSBLong(ofile,0xFFFFFFFFUL);
+                    outputlen += 4;
+                    savedolen = outputlen;
+                  }
+              }
+            else
+              {
+                if (len <= 0x7FFF)
+                  {
+                    WriteBlobByte(ofile,0x1c);
+                    WriteBlobByte(ofile,dataset);
+                    WriteBlobByte(ofile,recnum & 255);
+                    WriteBlobMSBShort(ofile,len);
+                    outputlen += 5;
+                    next=0;
+                    outputlen += len;
+                    while (len--)
+                      WriteBlobByte(ofile,token[next++]);
+                  }
+              }
+          }
+      state++;
+    }
+    LiberateMemory((void **) &token);
+    LiberateMemory((void **) &newstr);
+    LiberateMemory((void **) &name);
+  }
+  LiberateMemory((void **) &line);
+  if (savedolen > 0)
+    {
+      long diff = outputlen - savedolen;
+
+      currentpos = TellBlob(ofile);
+      SeekBlob(ofile,savedpos,SEEK_SET);
+      WriteBlobMSBLong(ofile,diff);
+      SeekBlob(ofile,currentpos,SEEK_SET);
+      savedolen = 0L;
+    }
+  return outputlen;
+}
+
 /* some defines for the different JPEG block types */
 #define M_SOF0  0xC0            /* Start Of Frame N */
 #define M_SOF1  0xC1            /* N indicates which compression process */
@@ -817,6 +1076,12 @@ static Image *ReadMETAImage(const ImageInfo *image_info,
           if (length & 1)
             WriteBlobByte(buff,0x0);
         }
+      else if (LocaleCompare(image_info->magick,"8BIMWTEXT") == 0)
+        {
+          length=parse8BIMW(image, buff);
+          if (length & 1)
+            WriteBlobByte(buff,0x0);
+        }
       else
         {
           for ( ; ; )
@@ -912,13 +1177,46 @@ static Image *ReadMETAImage(const ImageInfo *image_info,
         }
       else
         {
+#ifdef SLOW_METHOD
           for ( ; ; )
           {
+            /* Really - really slow - FIX ME PLEASE!!!! */
             c=ReadBlobByte(image);
             if (c == EOF)
               break;
             WriteBlobByte(buff,c);
           }
+#else
+#define MaxBufferSize  65541
+          char
+            *buffer;
+
+          ExtendedSignedIntegralType
+            count;
+
+          size_t
+            i,
+            length;
+
+          buffer=(char *) AcquireMemory(MaxBufferSize);
+          if (buffer != (char *) NULL)
+            {
+              i=0;
+              while ((length=ReadBlob(image,MaxBufferSize,buffer)) != 0)
+              {
+                count=0;
+                for (i=0; i < length; i+=count)
+                {
+                  count=WriteBlob(buff,length-i,buffer+i);
+                  if (count <= 0)
+                    break;
+                }
+                if (i < length)
+                  break;
+              }
+              LiberateMemory((void **) &buffer);
+            }
+#endif
         }
       image->generic_profile[i].info = buff->blob->data;
       image->generic_profile[i].length=GetBlobSize(buff);
@@ -972,6 +1270,9 @@ static Image *ReadMETAImage(const ImageInfo *image_info,
           if (length & 1)
             WriteBlobByte(buff,0x0);
         }
+      else if (LocaleCompare(image_info->magick,"IPTCWTEXT") == 0)
+        {
+        }
       else
         {
           for ( ; ; )
@@ -1029,7 +1330,6 @@ ModuleExport void RegisterMETAImage(void)
   entry=SetMagickInfo("8BIM");
   entry->decoder=(DecoderHandler) ReadMETAImage;
   entry->encoder=(EncoderHandler) WriteMETAImage;
-  entry->magick=(MagickHandler) IsMETA;
   entry->adjoin=False;
   entry->seekable_stream=True;
   entry->description=AllocateString("Photoshop resource format");
@@ -1039,17 +1339,24 @@ ModuleExport void RegisterMETAImage(void)
   entry=SetMagickInfo("8BIMTEXT");
   entry->decoder=(DecoderHandler) ReadMETAImage;
   entry->encoder=(EncoderHandler) WriteMETAImage;
-  entry->magick=(MagickHandler) IsMETA;
   entry->adjoin=False;
   entry->seekable_stream=True;
-  entry->description=AllocateString("Photoshop resource format");
+  entry->description=AllocateString("Photoshop resource text format");
+  entry->module=AllocateString("META");
+  (void) RegisterMagickInfo(entry);
+
+  entry=SetMagickInfo("8BIMWTEXT");
+  entry->decoder=(DecoderHandler) ReadMETAImage;
+  entry->encoder=(EncoderHandler) WriteMETAImage;
+  entry->adjoin=False;
+  entry->seekable_stream=True;
+  entry->description=AllocateString("Photoshop resource wide text format");
   entry->module=AllocateString("META");
   (void) RegisterMagickInfo(entry);
 
   entry=SetMagickInfo("APP1");
   entry->decoder=(DecoderHandler) ReadMETAImage;
   entry->encoder=(EncoderHandler) WriteMETAImage;
-  entry->magick=(MagickHandler) IsMETA;
   entry->adjoin=False;
   entry->seekable_stream=True;
   entry->description=AllocateString("Raw application information");
@@ -1059,13 +1366,30 @@ ModuleExport void RegisterMETAImage(void)
   entry=SetMagickInfo("APP1JPEG");
   entry->decoder=(DecoderHandler) ReadMETAImage;
   entry->encoder=(EncoderHandler) WriteMETAImage;
-  entry->magick=(MagickHandler) IsMETA;
   entry->adjoin=False;
   entry->seekable_stream=True;
   entry->description=AllocateString("Raw JPEG binary data");
   entry->module=AllocateString("META");
   (void) RegisterMagickInfo(entry);
 
+  entry=SetMagickInfo("EXIF");
+  entry->decoder=(DecoderHandler) ReadMETAImage;
+  entry->encoder=(EncoderHandler) WriteMETAImage;
+  entry->adjoin=False;
+  entry->seekable_stream=True;
+  entry->description=AllocateString("Exif digital camera binary data");
+  entry->module=AllocateString("META");
+  (void) RegisterMagickInfo(entry);
+
+  entry=SetMagickInfo("XMP");
+  entry->decoder=(DecoderHandler) ReadMETAImage;
+  entry->encoder=(EncoderHandler) WriteMETAImage;
+  entry->adjoin=False;
+  entry->seekable_stream=True;
+  entry->description=AllocateString("Adobe XML metadata");
+  entry->module=AllocateString("META");
+  (void) RegisterMagickInfo(entry);
+
   entry=SetMagickInfo("ICM");
   entry->decoder=(DecoderHandler) ReadMETAImage;
   entry->encoder=(EncoderHandler) WriteMETAImage;
@@ -1087,7 +1411,6 @@ ModuleExport void RegisterMETAImage(void)
   entry=SetMagickInfo("IPTC");
   entry->decoder=(DecoderHandler) ReadMETAImage;
   entry->encoder=(EncoderHandler) WriteMETAImage;
-  entry->magick=(MagickHandler) IsMETA;
   entry->adjoin=False;
   entry->seekable_stream=True;
   entry->description=AllocateString("IPTC Newsphoto");
@@ -1097,10 +1420,18 @@ ModuleExport void RegisterMETAImage(void)
   entry=SetMagickInfo("IPTCTEXT");
   entry->decoder=(DecoderHandler) ReadMETAImage;
   entry->encoder=(EncoderHandler) WriteMETAImage;
-  entry->magick=(MagickHandler) IsMETA;
   entry->adjoin=False;
   entry->seekable_stream=True;
-  entry->description=AllocateString("IPTC Newsphoto");
+  entry->description=AllocateString("IPTC Newsphoto text format");
+  entry->module=AllocateString("META");
+  (void) RegisterMagickInfo(entry);
+
+  entry=SetMagickInfo("IPTCWTEXT");
+  entry->decoder=(DecoderHandler) ReadMETAImage;
+  entry->encoder=(EncoderHandler) WriteMETAImage;
+  entry->adjoin=False;
+  entry->seekable_stream=True;
+  entry->description=AllocateString("IPTC Newsphoto text format");
   entry->module=AllocateString("META");
   (void) RegisterMagickInfo(entry);
 }
@@ -1128,10 +1459,14 @@ ModuleExport void UnregisterMETAImage(void)
 {
   (void) UnregisterMagickInfo("8BIM");
   (void) UnregisterMagickInfo("8BIMTEXT");
+  (void) UnregisterMagickInfo("8BIMWTEXT");
+  (void) UnregisterMagickInfo("ICC");
+  (void) UnregisterMagickInfo("ICCTEXT");
   (void) UnregisterMagickInfo("APP1");
   (void) UnregisterMagickInfo("ICM");
   (void) UnregisterMagickInfo("ICC");
-  (void) UnregisterMagickInfo("IPTC");
+  (void) UnregisterMagickInfo("EXIF");
+  (void) UnregisterMagickInfo("XMP");
 }
 
 /*
@@ -1369,8 +1704,9 @@ static tag_spec tags[] = {
   { 115, (char *) "Source" },
   { 116, (char *) "Copyright String" },
   { 120, (char *) "Caption" },
-  { 121, (char *) "Local Caption" },
+  { 121, (char *) "Image Orientation" },
   { 122, (char *) "Caption Writer" },
+  { 131, (char *) "Local Caption" },
   { 200, (char *) "Custom Field 1" },
   { 201, (char *) "Custom Field 2" },
   { 202, (char *) "Custom Field 3" },
@@ -1775,6 +2111,8 @@ static unsigned int WriteMETAImage(const ImageInfo *image_info,Image *image)
         ThrowWriterException(FileOpenError,"UnableToOpenFile",image);
       (void) WriteBlob(image,image->iptc_profile.length,
         (char *) image->iptc_profile.info);
+      CloseBlob(image);
+      return(True);
     }
   if (LocaleCompare(image_info->magick,"IPTC") == 0)
     {
@@ -1791,8 +2129,12 @@ static unsigned int WriteMETAImage(const ImageInfo *image_info,Image *image)
       length=image->iptc_profile.length;
       length=GetIPTCStream(&info,length);
       if (length == 0)
-        ThrowWriterException(CoderError,"NoIPTCInfoWasFound",image);
+        {
+          ThrowWriterException(CoderError,"NoIPTCInfoWasFound",image);
+        }
       (void) WriteBlob(image,length,info);
+      CloseBlob(image);
+      return(True);
     }
   if (LocaleCompare(image_info->magick,"8BIMTEXT") == 0)
     {
@@ -1806,11 +2148,19 @@ static unsigned int WriteMETAImage(const ImageInfo *image_info,Image *image)
         ThrowWriterException(FileOpenError,"UnableToOpenFile",image);
       buff=AllocateImage((ImageInfo *) NULL);
       if (buff == (Image *) NULL)
-        ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed",image);
+        {
+          ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed",image);
+        }
       AttachBlob(buff->blob,image->iptc_profile.info,image->iptc_profile.length);
       format8BIM(buff,image);
       DetachBlob(buff->blob);
       DestroyImage(buff);
+      CloseBlob(image);
+      return(True);
+    }
+  if (LocaleCompare(image_info->magick,"8BIMWTEXT") == 0)
+    {
+      return(False);
     }
   if (LocaleCompare(image_info->magick,"IPTCTEXT") == 0)
     {
@@ -1835,77 +2185,46 @@ static unsigned int WriteMETAImage(const ImageInfo *image_info,Image *image)
         ThrowWriterException(FileOpenError,"UnableToOpenFile",image);
       buff=AllocateImage((ImageInfo *) NULL);
       if (buff == (Image *) NULL)
-        ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed",image);
+        {
+          ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed",image);
+        }
       AttachBlob(buff->blob,info,length);
       formatIPTC(buff,image);
       DetachBlob(buff->blob);
       DestroyImage(buff);
+      CloseBlob(image);
+      return(True);
     }
-  if (LocaleCompare(image_info->magick,"APP1") == 0)
+  if (LocaleCompare(image_info->magick,"IPTCWTEXT") == 0)
+    {
+      return(False);
+    }
+  if ((LocaleCompare(image_info->magick,"APP1") == 0) ||
+      (LocaleCompare(image_info->magick,"EXIF") == 0) ||
+      (LocaleCompare(image_info->magick,"XMP") == 0))
     {
       /*
         Write APP1 image.
       */
       for (i=0; i < (int) image->generic_profiles; i++)
       {
-        if ((LocaleCompare(image->generic_profile[i].name,"APP1") == 0) &&
-            (image->generic_profile[i].length != 0))
+        char
+          *name;
+
+        long
+          length;
+
+        length=image->generic_profile[i].length;
+        if (length == 0)
+          ThrowWriterException(CoderError,"NoAPP1DataIsAvailable",image);
+        name=image->generic_profile[i].name;
+        if (LocaleCompare(name,image_info->magick) == 0)
           {
-            unsigned char
-              *p;
-            /*
-              Open image file.
-            */
             status=OpenBlob(image_info,image,WriteBinaryBlobMode,&image->exception);
             if (status == False)
               ThrowWriterException(FileOpenError,"UnableToOpenFile",image);
-            p=(unsigned char *) image->generic_profile[i].info;
-            /* We used to do lossless embedding of IPTC into JPEG's at the
-               point of writing out the data using the APP1 mechanism, but
-               changed it to the read side instead since it was easier to
-               figure out how to access it at that point
-             */
-#if 1
-            /* if (p[0]!=0xff || p[1]!=M_SOI || p[2]!=0xff) */
-              {
-                (void) WriteBlob(image,(int) image->generic_profile[i].length,
-                  (char *)p);
-              }
-#else
-            /* else */
-              {
-                Image
-                  *jpeg,
-                  *iptc;
-
-                int
-                  result;
-
-                iptc=AllocateImage((ImageInfo *) NULL);
-                jpeg=AllocateImage((ImageInfo *) NULL);
-                if ((iptc == (Image *) NULL) || (jpeg == (Image *) NULL))
-                  ThrowWriterException(ResourceLimitError,
-                    "MemoryAllocationFailed",image);
-                if ((image->iptc_profile.info == (unsigned char *) NULL) ||
-                    (image->iptc_profile.length <= 0))
-                  ThrowWriterException(CoderError,"NoIPTCProfileAvailable",
-                    image);
-                AttachBlob(iptc->blob,image->iptc_profile.info,
-                  image->iptc_profile.length);
-                if ((p == (unsigned char *) NULL) ||
-                    (image->generic_profile[i].length <= 0))
-                  ThrowWriterException(CoderError,"NoJPEGProfileAvailable",
-                    image);
-                AttachBlob(jpeg->blob,p,image->generic_profile[i].length);
-                result=jpeg_embed(jpeg,image,iptc);
-                DetachBlob(jpeg->blob);
-                DestroyImage(jpeg);
-                DetachBlob(iptc->blob);
-                DestroyImage(iptc);
-                if (result == 0)
-                  ThrowWriterException(CoderError,"JpegEmbeddingFailed",image);
-              }
-#endif
+            (void) WriteBlob(image,(int) length,
+              (char *) image->generic_profile[i].info);
             CloseBlob(image);
             return(True);
           }
@@ -1925,7 +2244,8 @@ static unsigned int WriteMETAImage(const ImageInfo *image_info,Image *image)
         ThrowWriterException(FileOpenError,"UnableToOpenFile",image);
       (void) WriteBlob(image,image->color_profile.length,
         (char *) image->color_profile.info);
+      CloseBlob(image);
+      return(True);
     }
-  CloseBlob(image);
-  return(True);
+  return(False);
 }
