@@ -52,14 +52,15 @@
 /*
   Include declarations.
 */
-#include "studio.h"
-#include "attribute.h"
-#include "blob.h"
-#include "list.h"
-#include "magick.h"
-#include "monitor.h"
-#include "static.h"
-#include "utility.h"
+#include "magick/studio.h"
+#include "magick/attribute.h"
+#include "magick/blob.h"
+#include "magick/error.h"
+#include "magick/list.h"
+#include "magick/magick.h"
+#include "magick/monitor.h"
+#include "magick/static.h"
+#include "magick/utility.h"
 #if defined(HasZLIB)
 #include "zlib.h"
 #endif
@@ -139,12 +140,154 @@ static unsigned int IsMIFF(const unsigned char *magick,const size_t length)
 %      reading.  A null image is returned if there is a memory shortage or
 %      if the image cannot be read.
 %
-%    o image_info: Specifies a pointer to an ImageInfo structure.
+%    o image_info: The image info.
 %
 %    o exception: return any errors or warnings in this structure.
 %
 %
 */
+
+static inline void ReadRunlengthPacket(Image *image,unsigned char *pixels,
+  size_t *length,PixelPacket *pixel,IndexPacket *index)
+{
+  Quantum
+    quantum;
+
+  register unsigned char
+    *p;
+
+  p=pixels;
+  if (image->storage_class == PseudoClass)
+    {
+      *index=0;
+      switch (image->depth)
+      {
+        case 32:
+        {
+          *index=ConstrainColormapIndex(image,
+            (*p << 24) | (*(p+1) << 16) | (*(p+2) << 8) | *(p+3));
+          p+=4;
+          break;
+        }
+        case 16:
+        {
+          *index=ConstrainColormapIndex(image,(*p << 8) | *(p+1));
+          p+=2;
+          break;
+        }
+        case 8:
+        {
+          *index=ConstrainColormapIndex(image,*p);
+          p++;
+          break;
+        }
+        default:
+          ThrowException(&image->exception,CorruptImageError,
+            "ImageDepthNotSupported",image->filename);
+      }
+      *pixel=image->colormap[*index];
+      *length=(*p++)+1;
+      return;
+    }
+  switch (image->depth)
+  {
+    case 32:
+    {
+      quantum=(*p << 24) | (*(p+1) << 16) | (*(p+2) << 8) | *(p+3);
+      p+=4;
+      pixel->red=quantum >> (image->depth-QuantumDepth);
+      quantum=(*p << 24) | (*(p+1) << 16) | (*(p+2) << 8) | *(p+3);
+      p+=4;
+      pixel->green=quantum >> (image->depth-QuantumDepth);
+      quantum=(*p << 24) | (*(p+1) << 16) | (*(p+2) << 8) | *(p+3);
+      p+=4;
+      pixel->blue=quantum >> (image->depth-QuantumDepth);
+      if (image->colorspace == CMYKColorspace)
+        {
+          quantum=(*p << 24) | (*(p+1) << 16) | (*(p+2) << 8) | *(p+3);
+          p+=4;
+          pixel->opacity=quantum >> (image->depth-QuantumDepth);
+          if (image->matte)
+            {
+              quantum=(*p << 24) | (*(p+1) << 16) | (*(p+2) << 8) | *(p+3);
+              p+=4;
+              *index=(IndexPacket) (quantum >> (image->depth-QuantumDepth));
+            }
+          break;
+        }
+      if (image->matte)
+        {
+          quantum=(*p << 24) | (*(p+1) << 16) | (*(p+2) << 8) | *(p+3);
+          p+=4;
+          pixel->opacity=quantum >> (image->depth-QuantumDepth);
+        }
+      break;
+    }
+    case 16:
+    {
+      quantum=(*p << 8) | *(p+1);
+      p+=2;
+      pixel->red=quantum >> (image->depth-QuantumDepth);
+      quantum=(*p << 8) | *(p+1);
+      p+=2;
+      pixel->green=quantum >> (image->depth-QuantumDepth);
+      quantum=(*p << 8) | *(p+1);
+      p+=2;
+      pixel->blue=quantum >> (image->depth-QuantumDepth);
+      if (image->colorspace == CMYKColorspace)
+        {
+          quantum=(*p << 8) | *(p+1);
+          p+=2;
+          pixel->opacity=quantum >> (image->depth-QuantumDepth);
+          if (image->matte)
+            {
+              quantum=(*p << 8) | *(p+1);
+              p+=2;
+              *index=(IndexPacket) (quantum >> (image->depth-QuantumDepth));
+            }
+          break;
+        }
+      if (image->matte)
+        {
+          quantum=(*p << 8) | *(p+1);
+          p+=2;
+          pixel->opacity=quantum >> (image->depth-QuantumDepth);
+        }
+      break;
+    }
+    case 8:
+    {
+      quantum=(*p++);
+      pixel->red=ScaleCharToQuantum(quantum);
+      quantum=(*p++);
+      pixel->green=ScaleCharToQuantum(quantum);
+      quantum=(*p++);
+      pixel->blue=ScaleCharToQuantum(quantum);
+      if (image->colorspace == CMYKColorspace)
+        {
+          quantum=(*p++);
+          pixel->opacity=ScaleCharToQuantum(quantum);
+          if (image->matte)
+            {
+              quantum=(*p++);
+              *index=ScaleCharToQuantum(quantum);
+            }
+          break;
+        }
+      if (image->matte)
+        {
+          quantum=(*p++);
+          pixel->opacity=ScaleCharToQuantum(quantum);
+        }
+      break;
+    }
+    default:
+      (void) ThrowException(&image->exception,CorruptImageError,
+        "ImageDepthNotSupported",image->filename);
+  }
+  *length=(*p++)+1;
+}
+
 static Image *ReadMIFFImage(const ImageInfo *image_info,
   ExceptionInfo *exception)
 {
@@ -172,8 +315,7 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,
 
   int
     c,
-    code,
-    length;
+    code;
 
   long
     y;
@@ -197,6 +339,9 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,
   register unsigned char
     *p;
 
+  size_t
+    length;
+
   unsigned char
     *compress_pixels,
     *pixels;
@@ -270,7 +415,7 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,
             c=ReadBlobByte(image);
             if ((c == EOF) || (c == '}'))
               break;
-            if ((p-comment+1) >= (int) length)
+            if ((p-comment+1) >= (long) length)
               {
                 *p='\0';
                 length<<=1;
@@ -308,7 +453,7 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,
             p=values;
             while ((c != '}') && (c != EOF))
             {
-              if ((p-values+1) >= (int) length)
+              if ((p-values+1) >= (long) length)
                 {
                   *p='\0';
                   length<<=1;
@@ -743,8 +888,8 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,
         image->iptc_profile.info=(unsigned char *)
           AcquireMemory(image->iptc_profile.length);
         if (image->iptc_profile.info == (unsigned char *) NULL)
-          ThrowReaderException(CorruptImageError,
-            "UnableToReadiPTCProfile",image);
+          ThrowReaderException(CorruptImageError,"UnableToReadIPTCProfile",
+            image);
         (void) ReadBlob(image,image->iptc_profile.length,
           image->iptc_profile.info);
       }
@@ -805,26 +950,26 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,
                 for (i=0; i < (long) image->colors; i++)
                 {
                   pixel=(*p << 8) | *(p+1);
-                  image->colormap[i].red=pixel;
+                  image->colormap[i].red=ScaleShortToQuantum(pixel);
                   p+=2;
                   pixel=(*p << 8) | *(p+1);
-                  image->colormap[i].green=pixel;
+                  image->colormap[i].green=ScaleShortToQuantum(pixel);
                   p+=2;
                   pixel=(*p << 8) | *(p+1);
-                  image->colormap[i].blue=pixel;
+                  image->colormap[i].blue=ScaleShortToQuantum(pixel);
                   p+=2;
                 }
               else
                 for (i=0; i < (long) image->colors; i++)
                 {
                   pixel=(*p << 24) | (*(p+1) << 16) | (*(p+2) << 8) | *(p+3);
-                  image->colormap[i].red=pixel;
+                  image->colormap[i].red=ScaleLongToQuantum(pixel);
                   p+=4;
                   pixel=(*p << 24) | (*(p+1) << 16) | (*(p+2) << 8) | *(p+3);
-                  image->colormap[i].green=pixel;
+                  image->colormap[i].green=ScaleLongToQuantum(pixel);
                   p+=4;
                   pixel=(*p << 24) | (*(p+1) << 16) | (*(p+2) << 8) | *(p+3);
-                  image->colormap[i].blue=pixel;
+                  image->colormap[i].blue=ScaleLongToQuantum(pixel);
                   p+=4;
                 }
             LiberateMemory((void **) &colormap);
@@ -836,16 +981,16 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,
     /*
       Allocate image pixels.
     */
+    packet_size=image->depth/8;
     if (image->storage_class == DirectClass)
       packet_size=3*image->depth/8;
-    else
-      packet_size=image->depth/8;
     if (image->colorspace == CMYKColorspace)
       packet_size+=image->depth/8;
     if (image->matte)
       packet_size+=image->depth/8;
     if (image->compression == RLECompression)
-      packet_size+=image->depth/8;
+      packet_size++;
+    length=packet_size*image->columns;
     pixels=(unsigned char *) AcquireMemory(packet_size*image->columns);
     length=(size_t) (1.01*packet_size*image->columns+600);
     compress_pixels=(unsigned char *) AcquireMemory(length);
@@ -892,7 +1037,7 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,
             if (zip_info.avail_in == 0)
               {
                 zip_info.next_in=compress_pixels;
-                length=(int) (1.01*packet_size*image->columns+12);
+                length=(long) (1.01*packet_size*image->columns+12);
                 if (version != 0)
                   length=ReadBlobMSBLong(image);
                 zip_info.avail_in=ReadBlob(image,length,zip_info.next_in);
@@ -958,93 +1103,12 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,
               (void) memset(&pixel,0,sizeof(PixelPacket));
               pixel.opacity=TransparentOpacity;
             }
-          p=pixels;
           for (x=0; x < (long) image->columns; x++)
           {
             if (length == 0)
               {
-                if (image->storage_class != DirectClass)
-                  {
-                    index=ReadBlobByte(image);
-                    if (image->depth > 8)
-                      index=(index << 8)+ReadBlobByte(image);
-                    if (image->depth > 16)
-                      {
-                        index=(index << 8)+ReadBlobByte(image);
-                        index=(index << 8)+ReadBlobByte(image);
-                      }
-                    if (index >= image->colors)
-                      {
-                        ThrowException(&image->exception,CorruptImageError,
-                          "InvalidColormapIndex",image->filename);
-                        index=0;
-                      }
-                    pixel=image->colormap[index];
-                  }
-                else
-                  {
-                    if (image->depth <= 8)
-                      {
-                        pixel.red=ScaleCharToQuantum(ReadBlobByte(image));
-                        pixel.green=ScaleCharToQuantum(ReadBlobByte(image));
-                        pixel.blue=ScaleCharToQuantum(ReadBlobByte(image));
-                        if (image->colorspace == CMYKColorspace)
-                          {
-                            pixel.opacity=
-                              ScaleCharToQuantum(ReadBlobByte(image));
-                            if (image->matte)
-                              index=ScaleCharToQuantum(ReadBlobByte(image));
-                          }
-                        else
-                          if (image->matte)
-                            pixel.opacity=
-                              ScaleCharToQuantum(ReadBlobByte(image));
-                      }
-                    else
-                      if (image->depth <= 16)
-                        {
-                          pixel.red=ReadBlobMSBShort(image) >>
-                            (image->depth-QuantumDepth);
-                          pixel.green=ReadBlobMSBShort(image) >>
-                            (image->depth-QuantumDepth);
-                          pixel.blue=ReadBlobMSBShort(image) >>
-                            (image->depth-QuantumDepth);
-                          if (image->colorspace == CMYKColorspace)
-                            {
-                              pixel.opacity=(ReadBlobMSBShort(image) >>
-                                (image->depth-QuantumDepth));
-                              if (image->matte)
-                                index=(ReadBlobMSBShort(image) >>
-                                  (image->depth-QuantumDepth));
-                            }
-                          else
-                            if (image->matte)
-                              pixel.opacity=(ReadBlobMSBShort(image) >>
-                                (image->depth-QuantumDepth));
-                        }
-                      else
-                        {
-                          pixel.red=(Quantum) (ReadBlobMSBLong(image) >>
-                            (image->depth-QuantumDepth));
-                          pixel.green=(Quantum) (ReadBlobMSBLong(image) >>
-                            (image->depth-QuantumDepth));
-                          pixel.blue=(Quantum) (ReadBlobMSBLong(image) >>
-                            (image->depth-QuantumDepth));
-                          if (image->colorspace == CMYKColorspace)
-                            {
-                              pixel.opacity=(Quantum) (ReadBlobMSBLong(image) >>
-                                (image->depth-QuantumDepth));
-                              if (image->matte)
-                                index=(IndexPacket) (ReadBlobMSBLong(image) >>
-                                  (image->depth-QuantumDepth));
-                            }
-                          else
-                            if (image->matte)
-                              pixel.opacity=(Quantum) (ReadBlobMSBLong(image) >>
-                                (image->depth-QuantumDepth));
-                        }
-                  }
-                length=ReadBlobByte(image)+1;
+                (void) ReadBlob(image,packet_size,pixels);
+                ReadRunlengthPacket(image,pixels,&length,&pixel,&index);
               }
             length--;
             if ((image->storage_class == PseudoClass) ||
@@ -1073,7 +1137,7 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,
       }
     if (EOFBlob(image))
       {
-        ThrowException(exception,CorruptImageError,"UnexpectedEndOfFile",
+        (void) ThrowException(exception,CorruptImageError,"UnexpectedEndOfFile",
           image->filename);
         break;
       }
@@ -1213,124 +1277,147 @@ ModuleExport void UnregisterMIFFImage(void)
 %      False is returned if there is a memory shortage or if the image file
 %      fails to write.
 %
-%    o image_info: Specifies a pointer to an ImageInfo structure.
+%    o image_info: The image info.
 %
-%    o image: A pointer to a Image structure.
+%    o image: The image.
 %
 %
 */
 
-static unsigned int WriteMIFFImage(const ImageInfo *image_info,Image *image)
+static inline size_t WriteRunlengthPacket(Image *image,unsigned char *pixels,
+  size_t length,PixelPacket pixel,IndexPacket index)
 {
-#define WriteRunlengthPacket(image,pixel,length,q,index) \
-{ \
-  if (image->storage_class != DirectClass) \
-    { \
-      if (image->depth > 16) \
-        { \
-          *q++=(unsigned char) (index >> 24); \
-          *q++=(unsigned char) (index >> 16); \
-        } \
-      if (image->depth > 8) \
-        *q++=(unsigned char) (index >> 8); \
-      *q++=(unsigned char) index; \
-    } \
-  else \
-    { \
-      if (image->depth <= 8) \
-        { \
-          *q++=ScaleQuantumToChar(pixel.red); \
-          *q++=ScaleQuantumToChar(pixel.green); \
-          *q++=ScaleQuantumToChar(pixel.blue); \
-          if (image->colorspace == CMYKColorspace) \
-            { \
-              *q++=ScaleQuantumToChar(pixel.opacity); \
-              if (image->matte) \
-                *q++=ScaleQuantumToChar(index); \
-            } \
-          else \
-            if (image->matte) \
-              *q++=ScaleQuantumToChar(pixel.opacity); \
-        } \
-      else \
-        if (image->depth <= 16) \
-          { \
-            value=ScaleQuantumToShort(pixel.red); \
-            *q++=(unsigned char) (value >> 8); \
-            *q++=(unsigned char) value; \
-            value=ScaleQuantumToShort(pixel.green); \
-            *q++=(unsigned char) (value >> 8); \
-            *q++=(unsigned char) value; \
-            value=ScaleQuantumToShort(pixel.blue); \
-            *q++=(unsigned char) (value >> 8); \
-            *q++=(unsigned char) value; \
-            if (image->colorspace == CMYKColorspace) \
-              { \
-                value=ScaleQuantumToShort(pixel.opacity); \
-                *q++=(unsigned char) (value >> 8); \
-                *q++=(unsigned char) value; \
-                if (image->matte) \
-                  { \
-                    value=ScaleQuantumToShort(index); \
-                    *q++=(unsigned char) (value >> 8); \
-                    *q++=(unsigned char) value; \
-                  } \
-              } \
-            else \
-              if (image->matte) \
-                { \
-                  value=ScaleQuantumToShort(pixel.opacity); \
-                  *q++=(unsigned char) (value >> 8); \
-                  *q++=(unsigned char) value; \
-                } \
-          } \
-        else \
-          { \
-            value=ScaleQuantumToLong(pixel.red); \
-            *q++=(unsigned char) (value >> 24); \
-            *q++=(unsigned char) (value >> 16); \
-            *q++=(unsigned char) (value >> 8); \
-            *q++=(unsigned char) value; \
-            value=ScaleQuantumToShort(pixel.green); \
-            *q++=(unsigned char) (value >> 24); \
-            *q++=(unsigned char) (value >> 16); \
-            *q++=(unsigned char) (value >> 8); \
-            *q++=(unsigned char) value; \
-            value=ScaleQuantumToShort(pixel.blue); \
-            *q++=(unsigned char) (value >> 24); \
-            *q++=(unsigned char) (value >> 16); \
-            *q++=(unsigned char) (value >> 8); \
-            *q++=(unsigned char) value; \
-            if (image->colorspace == CMYKColorspace) \
-              { \
-                value=ScaleQuantumToShort(pixel.opacity); \
-                *q++=(unsigned char) (value >> 24); \
-                *q++=(unsigned char) (value >> 16); \
-                *q++=(unsigned char) (value >> 8); \
-                *q++=(unsigned char) value; \
-                if (image->matte) \
-                  { \
-                    value=ScaleQuantumToShort(index); \
-                    *q++=(unsigned char) (value >> 24); \
-                    *q++=(unsigned char) (value >> 16); \
-                    *q++=(unsigned char) (value >> 8); \
-                    *q++=(unsigned char) value; \
-                  } \
-              } \
-            else \
-              if (image->matte) \
-                { \
-                  value=ScaleQuantumToShort(pixel.opacity); \
-                  *q++=(unsigned char) (value >> 24); \
-                  *q++=(unsigned char) (value >> 16); \
-                  *q++=(unsigned char) (value >> 8); \
-                  *q++=(unsigned char) value; \
-                } \
-          } \
-    } \
-  *q++=(unsigned char) length; \
+  register unsigned char
+    *q;
+
+  unsigned long
+    value;
+
+  q=pixels;
+  if (image->storage_class != DirectClass)
+    {
+      switch (image->depth)
+      {
+        case 32:
+        {
+          *q++=(unsigned char) (index >> 24);
+          *q++=(unsigned char) (index >> 16);
+        }
+        case 16:
+          *q++=(unsigned char) (index >> 8);
+        default:
+          (void) ThrowException(&image->exception,CorruptImageError,
+            "ImageDepthNotSupported",image->filename);
+        case 8:
+          *q++=(unsigned char) index;
+      }
+      *q++=(unsigned char) length;
+      return(q-pixels);
+    }
+  switch (image->depth)
+  {
+    case 32:
+    {
+      value=ScaleQuantumToLong(pixel.red);
+      *q++=(unsigned char) (value >> 24);
+      *q++=(unsigned char) (value >> 16);
+      *q++=(unsigned char) (value >> 8);
+      *q++=(unsigned char) value;
+      value=ScaleQuantumToLong(pixel.green);
+      *q++=(unsigned char) (value >> 24);
+      *q++=(unsigned char) (value >> 16);
+      *q++=(unsigned char) (value >> 8);
+      *q++=(unsigned char) value;
+      value=ScaleQuantumToLong(pixel.blue);
+      *q++=(unsigned char) (value >> 24);
+      *q++=(unsigned char) (value >> 16);
+      *q++=(unsigned char) (value >> 8);
+      *q++=(unsigned char) value;
+      if (image->colorspace == CMYKColorspace)
+        {
+          value=ScaleQuantumToLong(pixel.opacity);
+          *q++=(unsigned char) (value >> 24);
+          *q++=(unsigned char) (value >> 16);
+          *q++=(unsigned char) (value >> 8);
+          *q++=(unsigned char) value;
+          if (image->matte)
+            {
+              value=ScaleQuantumToLong(index);
+              *q++=(unsigned char) (value >> 24);
+              *q++=(unsigned char) (value >> 16);
+              *q++=(unsigned char) (value >> 8);
+              *q++=(unsigned char) value;
+            }
+          break;
+        }
+      if (image->matte)
+        {
+          value=ScaleQuantumToLong(pixel.opacity);
+          *q++=(unsigned char) (value >> 24);
+          *q++=(unsigned char) (value >> 16);
+          *q++=(unsigned char) (value >> 8);
+          *q++=(unsigned char) value;
+        }
+      break;
+    }
+    case 16:
+    {
+      value=ScaleQuantumToShort(pixel.red);
+      *q++=(unsigned char) (value >> 8);
+      *q++=(unsigned char) value;
+      value=ScaleQuantumToShort(pixel.green);
+      *q++=(unsigned char) (value >> 8);
+      *q++=(unsigned char) value;
+      value=ScaleQuantumToShort(pixel.blue);
+      *q++=(unsigned char) (value >> 8);
+      *q++=(unsigned char) value;
+      if (image->colorspace == CMYKColorspace)
+        {
+          value=ScaleQuantumToShort(pixel.opacity);
+          *q++=(unsigned char) (value >> 8);
+          *q++=(unsigned char) value;
+          if (image->matte)
+            {
+              value=ScaleQuantumToShort(index);
+              *q++=(unsigned char) (value >> 8);
+              *q++=(unsigned char) value;
+            }
+          break;
+        }
+      if (image->matte)
+        {
+          value=ScaleQuantumToShort(pixel.opacity);
+          *q++=(unsigned char) (value >> 8);
+          *q++=(unsigned char) value;
+        }
+      break;
+    }
+    default:
+      (void) ThrowException(&image->exception,CorruptImageError,
+        "ImageDepthNotSupported",image->filename);
+    case 8:
+    {
+      *q++=ScaleQuantumToChar(pixel.red);
+      *q++=ScaleQuantumToChar(pixel.green);
+      *q++=ScaleQuantumToChar(pixel.blue);
+      if (image->colorspace == CMYKColorspace)
+        {
+          *q++=ScaleQuantumToChar(pixel.opacity);
+          if (image->matte)
+            *q++=ScaleQuantumToChar(index);
+          break;
+        }
+      if (image->matte)
+        *q++=ScaleQuantumToChar(pixel.opacity);
+      break;
+    }
+  }
+  *q++=(unsigned char) length;
+  return(q-pixels);
 }
 
+static unsigned int WriteMIFFImage(const ImageInfo *image_info,Image *image)
+{
 #if defined(HasBZLIB)
   bz_stream
     bzip_info;
@@ -1385,8 +1472,7 @@ static unsigned int WriteMIFFImage(const ImageInfo *image_info,Image *image)
 
   unsigned long
     packet_size,
-    scene,
-    value;
+    scene;
 
 #if defined(HasZLIB)
   z_stream
@@ -1416,10 +1502,13 @@ static unsigned int WriteMIFFImage(const ImageInfo *image_info,Image *image)
     if (((image_info->colorspace != UndefinedColorspace) ||
          (image->colorspace != CMYKColorspace)) &&
          (image_info->colorspace != CMYKColorspace))
-      (void) TransformRGBImage(image,image->colorspace);
+      (void) SetImageColorspace(image,RGBColorspace);
     else
       if (image->colorspace != CMYKColorspace)
-        (void) RGBTransformImage(image,CMYKColorspace);
+        (void) SetImageColorspace(image,CMYKColorspace);
+    if ((image->storage_class == PseudoClass) &&
+        (image->colors > (1UL < image->depth)))
+      image->storage_class=DirectClass;
     packet_size=image->depth/8;
     if (image->storage_class == DirectClass)
       packet_size=3*image->depth/8;
@@ -1667,26 +1756,14 @@ static unsigned int WriteMIFFImage(const ImageInfo *image_info,Image *image)
           Write colormap to file.
         */
         q=colormap;
-        if (image->depth <= 8)
-          for (i=0; i < (long) image->colors; i++)
+        for (i=0; i < (long) image->colors; i++)
+        {
+          switch (image->depth)
           {
-            *q++=ScaleQuantumToChar(image->colormap[i].red);
-            *q++=ScaleQuantumToChar(image->colormap[i].green);
-            *q++=ScaleQuantumToChar(image->colormap[i].blue);
-          }
-        else
-          if (image->depth <= 16)
-            for (i=0; i < (long) image->colors; i++)
-            {
-              *q++=ScaleQuantumToShort(image->colormap[i].red) >> 8;
-              *q++=ScaleQuantumToShort(image->colormap[i].red);
-              *q++=ScaleQuantumToShort(image->colormap[i].green) >> 8;
-              *q++=ScaleQuantumToShort(image->colormap[i].green);
-              *q++=ScaleQuantumToShort(image->colormap[i].blue) >> 8;
-              *q++=ScaleQuantumToShort(image->colormap[i].blue);
-            }
-          else
-            for (i=0; i < (long) image->colors; i++)
+            default:
+              ThrowWriterException(CorruptImageError,"ImageDepthNotSupported",
+                image)
+            case 32:
             {
               *q++=image->colormap[i].red >> 24;
               *q++=image->colormap[i].red >> 16;
@@ -1701,6 +1778,25 @@ static unsigned int WriteMIFFImage(const ImageInfo *image_info,Image *image)
               *q++=image->colormap[i].blue >> 8;
               *q++=image->colormap[i].blue;
             }
+            case 16:
+            {
+              *q++=ScaleQuantumToShort(image->colormap[i].red) >> 8;
+              *q++=ScaleQuantumToShort(image->colormap[i].red);
+              *q++=ScaleQuantumToShort(image->colormap[i].green) >> 8;
+              *q++=ScaleQuantumToShort(image->colormap[i].green);
+              *q++=ScaleQuantumToShort(image->colormap[i].blue) >> 8;
+              *q++=ScaleQuantumToShort(image->colormap[i].blue);
+              break;
+            }
+            case 8:
+            {
+              *q++=ScaleQuantumToChar(image->colormap[i].red);
+              *q++=ScaleQuantumToChar(image->colormap[i].green);
+              *q++=ScaleQuantumToChar(image->colormap[i].blue);
+              break;
+            }
+          }
+        }
         (void) WriteBlob(image,packet_size*image->colors,colormap);
         LiberateMemory((void **) &colormap);
       }
@@ -1848,7 +1944,7 @@ static unsigned int WriteMIFFImage(const ImageInfo *image_info,Image *image)
             else
               {
                 if (x > 0)
-                  WriteRunlengthPacket(image,pixel,length,q,index);
+                  q+=WriteRunlengthPacket(image,q,length,pixel,index);
                 length=0;
               }
             if (image->storage_class == PseudoClass)
@@ -1856,7 +1952,7 @@ static unsigned int WriteMIFFImage(const ImageInfo *image_info,Image *image)
             pixel=(*p);
             p++;
           }
-          WriteRunlengthPacket(image,pixel,length,q,index);
+          q+=WriteRunlengthPacket(image,q,length,pixel,index);
           (void) WriteBlob(image,q-pixels,pixels);
           break;
         }
