@@ -53,15 +53,16 @@
 /*
   Include declarations.
 */
-#include "studio.h"
-#include "attribute.h"
-#include "blob.h"
-#include "cache.h"
-#include "list.h"
-#include "magick.h"
-#include "monitor.h"
-#include "static.h"
-#include "utility.h"
+#include "magick/studio.h"
+#include "magick/attribute.h"
+#include "magick/blob.h"
+#include "magick/error.h"
+#include "magick/cache.h"
+#include "magick/list.h"
+#include "magick/magick.h"
+#include "magick/monitor.h"
+#include "magick/static.h"
+#include "magick/utility.h"
 
 /*
   Forward declarations.
@@ -134,7 +135,7 @@ static unsigned int IsMPC(const unsigned char *magick,const size_t length)
 %      reading.  A null image is returned if there is a memory shortage or
 %      if the image cannot be read.
 %
-%    o image_info: Specifies a pointer to an ImageInfo structure.
+%    o image_info: The image info.
 %
 %    o exception: return any errors or warnings in this structure.
 %
@@ -815,7 +816,7 @@ static Image *ReadMPCImage(const ImageInfo *image_info,ExceptionInfo *exception)
       }
     if (EOFBlob(image))
       {
-        ThrowException(exception,CorruptImageError,"UnexpectedEndOfFile",
+        (void) ThrowException(exception,CorruptImageError,"UnexpectedEndOfFile",
           image->filename);
         break;
       }
@@ -827,7 +828,7 @@ static Image *ReadMPCImage(const ImageInfo *image_info,ExceptionInfo *exception)
     */
     status=PersistCache(image,cache_filename,True,&offset,exception);
     if (status == False)
-      ThrowReaderException(CacheError,"UnableToPeristPixelCache",image);
+      ThrowReaderException(CacheError,"UnableToPersistPixelCache",image);
     /*
       Proceed to next image.
     */
@@ -948,9 +949,9 @@ ModuleExport void UnregisterMPCImage(void)
 %      False is returned if there is a memory shortage or if the image file
 %      fails to write.
 %
-%    o image_info: Specifies a pointer to an ImageInfo structure.
+%    o image_info: The image info.
 %
-%    o image: A pointer to a Image structure.
+%    o image: The image.
 %
 %
 */
@@ -1292,7 +1293,7 @@ static unsigned int WriteMPCImage(const ImageInfo *image_info,Image *image)
     */
     status=PersistCache(image,cache_filename,False,&offset,&image->exception);
     if (status == False)
-      ThrowWriterException(CacheError,"UnableToPeristPixelCache",image);
+      ThrowWriterException(CacheError,"UnableToPersistPixelCache",image);
     if (image->next == (Image *) NULL)
       break;
     image=SyncNextImageInList(image);
