@@ -198,6 +198,13 @@ static Image *ReadMPEGImage(const ImageInfo *image_info,
   /*
     Free resources.
   */
+  for (i++; ; i++)
+  {
+    FormatString(clone_info->filename,"%.1024s%ld.ppm",clone_info->unique,i);
+    if (IsAccessible(clone_info->filename) == False)
+      break;
+    (void) remove(clone_info->filename);
+  }
   DestroyImageInfo(clone_info);
   return(images);
 }
