@@ -53,15 +53,16 @@
 /*
   Include declarations.
 */
-#include "studio.h"
-#include "attribute.h"
-#include "blob.h"
-#include "list.h"
-#include "magick.h"
-#include "paint.h"
-#include "quantize.h"
-#include "static.h"
-#include "utility.h"
+#include "magick/studio.h"
+#include "magick/attribute.h"
+#include "magick/blob.h"
+#include "magick/error.h"
+#include "magick/list.h"
+#include "magick/magick.h"
+#include "magick/paint.h"
+#include "magick/quantize.h"
+#include "magick/static.h"
+#include "magick/utility.h"
 
 /*
   Define declarations.
@@ -412,7 +413,7 @@ static int FindColor(PixelPacket *pixel)
 %      reading.  A null image is returned if there is a memory shortage or
 %      if the image cannot be read.
 %
-%    o image_info: Specifies a pointer to an ImageInfo structure.
+%    o image_info: The image info.
 %
 %    o exception: return any errors or warnings in this structure.
 %
@@ -544,7 +545,6 @@ static Image *ReadPALMImage(const ImageInfo *image_info,
     {
     image->storage_class = DirectClass;
     image->depth = 0;
-    SetImageType(image, TrueColorType);
     }
 
   one_row = (unsigned char *) AcquireMemory(bytes_per_row);
@@ -737,9 +737,9 @@ ModuleExport void UnregisterPALMImage(void)
 %      False is returned is there is a memory shortage or if the image file
 %      fails to write.
 %
-%    o image_info: Specifies a pointer to an ImageInfo structure.
+%    o image_info: The image info.
 %
-%    o image:  A pointer to a Image structure.
+%    o image:  The image.
 %
 %
 */
@@ -807,7 +807,7 @@ static unsigned int WritePALMImage(const ImageInfo *image_info,Image *image)
   count = GetNumberColors(image, NULL, &exception);
   for (bits_per_pixel=1;  (1UL << bits_per_pixel) < count;  bits_per_pixel*=2);
   if (bits_per_pixel < 16)
-    TransformRGBImage(image,image->colorspace);
+    (void) SetImageColorspace(image,RGBColorspace);
   if (bits_per_pixel < 8)
     {
     if (IsGrayImage(image, &exception))   /* gray scale */
