@@ -52,14 +52,16 @@
 /*
   Include declarations.
 */
-#include "studio.h"
-#include "blob.h"
-#include "gem.h"
-#include "list.h"
-#include "magick.h"
-#include "monitor.h"
-#include "static.h"
-#include "utility.h"
+#include "magick/studio.h"
+#include "magick/blob.h"
+#include "magick/error.h"
+#include "magick/command.h"
+#include "magick/gem.h"
+#include "magick/list.h"
+#include "magick/magick.h"
+#include "magick/monitor.h"
+#include "magick/static.h"
+#include "magick/utility.h"
 
 /*
   Forward declarations.
@@ -292,7 +294,7 @@ static unsigned int DecodeImage(Image *image,unsigned char *luma,
       r++;
     if ((row > image->rows) || (r == (PCDTable *) NULL))
       {
-        ThrowException(&image->exception,CorruptImageWarning,"SkipToSyncByte",
+        (void) ThrowException(&image->exception,CorruptImageWarning,"SkipToSyncByte",
           image->filename);
         while ((sum & 0x00fff000) != 0x00fff000)
           PCDGetBits(8);
@@ -382,7 +384,7 @@ static unsigned int IsPCD(const unsigned char *magick,const size_t length)
 %      reading.  A null image is returned if there is a memory shortage or
 %      if the image cannot be read.
 %
-%    o image_info: Specifies a pointer to an ImageInfo structure.
+%    o image_info: The image info.
 %
 %    o exception: return any errors or warnings in this structure.
 %
@@ -732,7 +734,7 @@ static Image *ReadPCDImage(const ImageInfo *image_info,ExceptionInfo *exception)
   LiberateMemory((void **) &chroma1);
   LiberateMemory((void **) &luma);
   if (EOFBlob(image))
-    ThrowException(exception,CorruptImageError,"UnexpectedEndOfFile",
+    (void) ThrowException(exception,CorruptImageError,"UnexpectedEndOfFile",
       image->filename);
   CloseBlob(image);
   if (!image_info->ping)
@@ -868,9 +870,9 @@ ModuleExport void UnregisterPCDImage(void)
 %      False is returned is there is a memory shortage or if the image file
 %      fails to write.
 %
-%    o image_info: Specifies a pointer to an ImageInfo structure.
+%    o image_info: The image info.
 %
-%    o image:  A pointer to a Image structure.
+%    o image:  The image.
 %
 %
 */
@@ -942,7 +944,7 @@ static unsigned int WritePCDTile(const ImageInfo *image_info,Image *image,
       tile_image=bordered_image;
     }
   (void) TransformImage(&tile_image,(char *) NULL,tile_geometry);
-  (void) RGBTransformImage(tile_image,YCCColorspace);
+  (void) TransformRGBImage(tile_image,YCCColorspace);
   downsample_image=ResizeImage(tile_image,tile_image->columns/2,
     tile_image->rows/2,TriangleFilter,1.0,&image->exception);
   if (downsample_image == (Image *) NULL)
@@ -1025,7 +1027,7 @@ static unsigned int WritePCDImage(const ImageInfo *image_info,Image *image)
   status=OpenBlob(image_info,pcd_image,WriteBinaryBlobMode,&image->exception);
   if (status == False)
     ThrowWriterException(FileOpenError,"UnableToOpenFile",pcd_image);
-  (void) TransformRGBImage(pcd_image,RGBColorspace);
+  (void) SetImageColorspace(pcd_image,RGBColorspace);
   /*
     Write PCD image header.
   */
