@@ -52,13 +52,14 @@
 /*
   Include declarations.
 */
-#include "studio.h"
-#include "attribute.h"
-#include "blob.h"
-#include "magick.h"
-#include "monitor.h"
-#include "static.h"
-#include "utility.h"
+#include "magick/studio.h"
+#include "magick/attribute.h"
+#include "magick/blob.h"
+#include "magick/error.h"
+#include "magick/magick.h"
+#include "magick/monitor.h"
+#include "magick/static.h"
+#include "magick/utility.h"
 
 /*
   Forward declarations.
@@ -191,9 +192,9 @@ ModuleExport void UnregisterPCLImage(void)
 %      False is returned is there is a memory shortage or if the image file
 %      fails to write.
 %
-%    o image_info: Specifies a pointer to an ImageInfo structure.
+%    o image_info: The image info.
 %
-%    o image:  A pointer to a Image structure.
+%    o image:  The image.
 %
 %
 %
@@ -234,7 +235,7 @@ static unsigned int WritePCLImage(const ImageInfo *image_info,Image *image)
   status=OpenBlob(image_info,image,WriteBinaryBlobMode,&image->exception);
   if (status == False)
     ThrowWriterException(FileOpenError,"UnableToOpenFile",image);
-  (void) TransformRGBImage(image,image->colorspace);
+  (void) SetImageColorspace(image,RGBColorspace);
   /*
     Initialize the printer.
   */
