@@ -52,17 +52,19 @@
 /*
   Include declarations.
 */
-#include "studio.h"
-#include "attribute.h"
-#include "blob.h"
-#include "compress.h"
-#include "delegate.h"
-#include "list.h"
-#include "magick.h"
-#include "monitor.h"
-#include "static.h"
-#include "utility.h"
-#include "version.h"
+#include "magick/studio.h"
+#include "magick/attribute.h"
+#include "magick/blob.h"
+#include "magick/error.h"
+#include "magick/compress.h"
+#include "magick/delegate.h"
+#include "magick/list.h"
+#include "magick/magick.h"
+#include "magick/monitor.h"
+#include "magick/resource.h"
+#include "magick/static.h"
+#include "magick/utility.h"
+#include "magick/version.h"
 #if defined(HasTIFF)
 #define CCITTParam  "-1"
 #else
@@ -122,6 +124,9 @@ static unsigned int Huffman2DEncodeImage(const ImageInfo *image_info,
   ImageInfo
     *clone_info;
 
+  int
+    file;
+
   long
     count;
 
@@ -155,7 +160,7 @@ static unsigned int Huffman2DEncodeImage(const ImageInfo *image_info,
   if (huffman_image == (Image *) NULL)
     return(False);
   SetImageType(huffman_image,BilevelType);
-  TemporaryFilename(filename);
+  file=AcquireUniqueFileResource(filename);
   FormatString(huffman_image->filename,"tiff:%s",filename);
   clone_info=CloneImageInfo(image_info);
   clone_info->compression=Group4Compression;
@@ -164,10 +169,12 @@ static unsigned int Huffman2DEncodeImage(const ImageInfo *image_info,
   DestroyImage(huffman_image);
   if (status == False)
     return(False);
-  tiff=TIFFOpen(filename,"rb");
-  if (tiff == (TIFF *) NULL)
+  tiff=(TIFF *) NULL;
+  if (file != -1)
+    tiff=TIFFFdOpen(file,filename,"rb");
+  if ((file == -1) || (tiff == (TIFF *) NULL))
     {
-      (void) remove(filename);
+      (void) LiberateUniqueFileResource(filename);
       ThrowBinaryException(FileOpenError,"UnableToOpenFile",
         image_info->filename)
     }
@@ -199,7 +206,7 @@ static unsigned int Huffman2DEncodeImage(const ImageInfo *image_info,
   }
   LiberateMemory((void **) &buffer);
   TIFFClose(tiff);
-  (void) remove(filename);
+  (void) LiberateUniqueFileResource(filename);
   return(True);
 }
 #else
@@ -208,7 +215,8 @@ static unsigned int Huffman2DEncodeImage(const ImageInfo *image_info,
 {
   assert(image != (Image *) NULL);
   assert(image->signature == MagickSignature);
-  ThrowBinaryException(CoderError,"TIFFLibraryIsNotAvailable",image->filename);
+  ThrowBinaryException(MissingDelegateError,"TIFFLibraryIsNotAvailable",
+    image->filename);
 }
 #endif
 
@@ -275,7 +283,7 @@ static unsigned int IsPDF(const unsigned char *magick,const size_t offset)
 %      reading.  A null image is returned if there is a memory shortage or
 %      if the image cannot be read.
 %
-%    o image_info: Specifies a pointer to an ImageInfo structure.
+%    o image_info: The image info.
 %
 %    o exception: return any errors or warnings in this structure.
 %
@@ -283,7 +291,7 @@ static unsigned int IsPDF(const unsigned char *magick,const size_t offset)
 */
 static Image *ReadPDFImage(const ImageInfo *image_info,ExceptionInfo *exception)
 {
-#define MediaBox  "/MediaBox"
+#define MediaBox  "MediaBox"
 #define RenderPostscriptText  "  Rendering postscript...  "
 
   char
@@ -313,15 +321,15 @@ static Image *ReadPDFImage(const ImageInfo *image_info,ExceptionInfo *exception)
 
   int
     count,
-    status;
+    status,
+    unique_file;
 
   RectangleInfo
     box,
     page;
 
   register char
-    *p,
-    *q;
+    *p;
 
   register long
     c;
@@ -329,9 +337,6 @@ static Image *ReadPDFImage(const ImageInfo *image_info,ExceptionInfo *exception)
   SegmentInfo
     bounds;
 
-  unsigned int
-    portrait;
-
   unsigned long
     height,
     width;
@@ -362,10 +367,15 @@ static Image *ReadPDFImage(const ImageInfo *image_info,ExceptionInfo *exception)
   /*
     Open temporary output file.
   */
-  TemporaryFilename(postscript_filename);
-  file=fopen(postscript_filename,"wb");
-  if (file == (FILE *) NULL)
-    ThrowReaderException(FileOpenError,"UnableToWriteFile",image);
+  file=(FILE *) NULL;
+  unique_file=AcquireUniqueFileResource(postscript_filename);
+  if (unique_file != -1)
+    file=fdopen(unique_file,"wb");
+  if ((unique_file == -1) || (file == (FILE *) NULL))
+    {
+      (void) strncpy(image->filename,postscript_filename,MaxTextExtent-1);
+      ThrowReaderException(FileOpenError,"UnableToCreateTemporaryFile",image);
+    }
   /*
     Set the page density.
   */
@@ -389,9 +399,10 @@ static Image *ReadPDFImage(const ImageInfo *image_info,ExceptionInfo *exception)
   /*
     Determine page geometry from the PDF media box.
   */
-  memset(&page,0,sizeof(RectangleInfo));
+  count=0;
   memset(&box,0,sizeof(RectangleInfo));
-  portrait=True;
+  memset(&bounds,0,sizeof(SegmentInfo));
+  memset(&page,0,sizeof(RectangleInfo));
   for (p=command; (c=ReadBlobByte(image)) != EOF; )
   {
     (void) fputc(c,file);
@@ -401,22 +412,18 @@ static Image *ReadPDFImage(const ImageInfo *image_info,ExceptionInfo *exception)
       Note PDF elements.
     */
     *p++=(char) c;
-    if ((c != '\n') && (c != '\r') && ((p-command) < (MaxTextExtent-1)))
+    if ((c != '/') && ((p-command) < (MaxTextExtent-1)))
       continue;
     *p='\0';
     p=command;
     /*
       Note region defined by media box.
     */
-    if (LocaleNCompare(command,"/Rotate 90",10) == 0)
-      portrait=False;
-    q=strstr(command,MediaBox);
-    if (q == (char *) NULL)
-      continue;
-    count=sscanf(q,"/MediaBox [%lf %lf %lf %lf",&bounds.x1,&bounds.y1,
-      &bounds.x2,&bounds.y2);
+    if (LocaleNCompare(MediaBox,command,strlen(MediaBox)) == 0)
+      count=sscanf(command,"MediaBox [%lf %lf %lf %lf",&bounds.x1,&bounds.y1,
+        &bounds.x2,&bounds.y2);
     if (count != 4)
-      count=sscanf(q,"/MediaBox[%lf %lf %lf %lf",&bounds.x1,&bounds.y1,
+      count=sscanf(command,"MediaBox[%lf %lf %lf %lf",&bounds.x1,&bounds.y1,
         &bounds.x2,&bounds.y2);
     if (count != 4)
       continue;
@@ -437,7 +444,7 @@ static Image *ReadPDFImage(const ImageInfo *image_info,ExceptionInfo *exception)
     Render postscript with the Ghostscript delegate.
   */
   if ((page.width == 0) || (page.height == 0))
-    (void) ParsePageGeometry(image,PSPageGeometry,&page);
+    (void) ParseAbsoluteGeometry(PSPageGeometry,&page);
   if (image_info->page != (char *) NULL)
     (void) ParseAbsoluteGeometry(image_info->page,&page);
   page.width=(unsigned long)
@@ -448,39 +455,40 @@ static Image *ReadPDFImage(const ImageInfo *image_info,ExceptionInfo *exception)
   if (ferror(file))
     {
       (void) fclose(file);
+      (void) LiberateUniqueFileResource(postscript_filename);
       ThrowReaderException(CorruptImageError,"AnErrorHasOccurredWritingToFile",
         image)
     }
   (void) fclose(file);
   CloseBlob(image);
+  DestroyImage(image);
   *options='\0';
-  if (image_info->number_scenes != 0)
-    FormatString(options,"-dFirstPage=%lu -dLastPage=%lu",
-      image_info->scene+1,image_info->scene+image_info->number_scenes);
-  if (image_info->authenticate != (char *) NULL)
-    FormatString(options+strlen(options)," -sPDFPassword=%.1024s",
-      image_info->authenticate);
-  (void) strncpy(filename,image_info->filename,MaxTextExtent-1);
   clone_info=CloneImageInfo(image_info);
-  TemporaryFilename(clone_info->filename);
+  if (clone_info->number_scenes != 0)
+    FormatString(options,"-dFirstPage=%lu -dLastPage=%lu",
+      clone_info->scene+1,clone_info->scene+clone_info->number_scenes);
+  if (clone_info->authenticate != (char *) NULL)
+    FormatString(options+strlen(options)," -sPDFPassword=%.1024s",
+      clone_info->authenticate);
+  (void) strncpy(filename,clone_info->filename,MaxTextExtent-1);
+  (void) AcquireUniqueFilename(clone_info->filename);
   FormatString(command,delegate_info->commands,clone_info->antialias ? 4 : 1,
     clone_info->antialias ? 4 : 1,geometry,density,options,clone_info->filename,
     postscript_filename);
   (void) MagickMonitor(RenderPostscriptText,0,8,&image->exception);
   status=InvokePostscriptDelegate(clone_info->verbose,command);
+  clone_info->blob=(void *) NULL;
+  clone_info->length=0;
+  image=ReadImage(clone_info,exception);
   (void) MagickMonitor(RenderPostscriptText,7,8,&image->exception);
-  if (status)
+  (void) LiberateUniqueFileResource(postscript_filename);
+  (void) LiberateUniqueFileResource(clone_info->filename);
+  DestroyImageInfo(clone_info);
+  if (image == (Image *) NULL)
     {
       (void) remove(postscript_filename);
       ThrowReaderException(DelegateError,"PostscriptDelegateFailed",image)
     }
-  DestroyImage(image);
-  clone_info->blob=(void *) NULL;
-  clone_info->length=0;
-  image=ReadImage(clone_info,exception);
-  (void) remove(postscript_filename);
-  (void) remove(clone_info->filename);
-  DestroyImageInfo(clone_info);
   if (image == (Image *) NULL)
     ThrowReaderException(DelegateError,"DelegateFailed",image);
   do
@@ -488,21 +496,6 @@ static Image *ReadPDFImage(const ImageInfo *image_info,ExceptionInfo *exception)
     (void) strcpy(image->magick,"PDF");
     (void) strncpy(image->filename,filename,MaxTextExtent-1);
     image->page=page;
-    if (!image_info->ping && !portrait)
-      {
-        Image
-          *rotate_image;
-
-        /*
-          Rotate image.
-        */
-        rotate_image=RotateImage(image,90,exception);
-        if (rotate_image != (Image *) NULL)
-          {
-            DestroyImage(image);
-            image=rotate_image;
-          }
-      }
     next_image=SyncNextImageInList(image);
     if (next_image != (Image *) NULL)
       image=next_image;
@@ -609,9 +602,9 @@ ModuleExport void UnregisterPDFImage(void)
 %      False is returned is there is a memory shortage or if the image file
 %      fails to write.
 %
-%    o image_info: Specifies a pointer to an ImageInfo structure.
+%    o image_info: The image info.
 %
-%    o image:  A pointer to a Image structure.
+%    o image:  The image.
 %
 %
 */
@@ -747,7 +740,7 @@ static unsigned int WritePDFImage(const ImageInfo *image_info,Image *image)
     case JPEGCompression:
     {
       compression=RLECompression;
-      ThrowException(&image->exception,MissingDelegateError,
+      (void) ThrowException(&image->exception,MissingDelegateError,
         "JPEGLibraryIsNotAvailable",image->filename);
       break;
     }
@@ -756,7 +749,7 @@ static unsigned int WritePDFImage(const ImageInfo *image_info,Image *image)
     case LZWCompression:
     {
       compression=RLECompression;
-      ThrowException(&image->exception,MissingDelegateError,
+      (void) ThrowException(&image->exception,MissingDelegateError,
         "LZWEncodingNotEnabled",image->filename);
       break;
     }
@@ -765,7 +758,7 @@ static unsigned int WritePDFImage(const ImageInfo *image_info,Image *image)
     case ZipCompression:
     {
       compression=RLECompression;
-      ThrowException(&image->exception,MissingDelegateError,
+      (void) ThrowException(&image->exception,MissingDelegateError,
         "ZipLibraryIsNotAvailable",image->filename);
       break;
     }
@@ -1546,6 +1539,7 @@ static unsigned int WritePDFImage(const ImageInfo *image_info,Image *image)
             jpeg_image=CloneImage(tile_image,0,0,True,&image->exception);
             if (jpeg_image == (Image *) NULL)
               ThrowWriterException(CoderError,image->exception.reason,image);
+            (void) strcpy(jpeg_image->magick,"JPEG");
             blob=ImageToBlob(image_info,jpeg_image,&length,&image->exception);
             (void) WriteBlob(image,length,blob);
             DestroyImage(jpeg_image);
@@ -1643,6 +1637,7 @@ static unsigned int WritePDFImage(const ImageInfo *image_info,Image *image)
             jpeg_image=CloneImage(tile_image,0,0,True,&image->exception);
             if (jpeg_image == (Image *) NULL)
               ThrowWriterException(CoderError,image->exception.reason,image);
+            (void) strcpy(jpeg_image->magick,"JPEG");
             blob=ImageToBlob(image_info,jpeg_image,&length,&image->exception);
             (void) WriteBlob(image,length,blob);
             DestroyImage(jpeg_image);
