@@ -52,14 +52,16 @@
 /*
   Include declarations.
 */
-#include "studio.h"
-#include "blob.h"
-#include "list.h"
-#include "log.h"
-#include "magick.h"
-#include "monitor.h"
-#include "static.h"
-#include "utility.h"
+#include "magick/studio.h"
+#include "magick/blob.h"
+#include "magick/error.h"
+#include "magick/list.h"
+#include "magick/log.h"
+#include "magick/magick.h"
+#include "magick/monitor.h"
+#include "magick/resource.h"
+#include "magick/static.h"
+#include "magick/utility.h"
 
 /*
   ImageMagick Macintosh PICT Methods.
@@ -329,7 +331,7 @@ static unsigned int
 %    o status:  Method DecodeImage returns True if all the pixels are
 %      uncompressed without error, otherwise False.
 %
-%    o image_info: Specifies a pointer to an ImageInfo structure.
+%    o image_info: The image info.
 %
 %    o blob,image: The address of a structure of type Image.
 %
@@ -497,7 +499,7 @@ static unsigned char *DecodeImage(const ImageInfo *image_info,Image *blob,
       scanline_length=ReadBlobByte(blob);
     if (scanline_length >= row_bytes)
       {
-        ThrowException(&image->exception,CorruptImageError,
+        (void) ThrowException(&image->exception,CorruptImageError,
           "UnableToUncompressImage","scanline length exceeds row bytes");
         break;
       }
@@ -724,8 +726,6 @@ static unsigned int IsPICT(const unsigned char *magick,const size_t length)
     return(False);
   if (memcmp(magick+522,"\000\021\002\377\014\000",6) == 0)
     return(True);
-  if (memcmp(magick+522,"\021\001",2) == 0)
-    return(True);
   return(False);
 }
 
@@ -756,7 +756,7 @@ static unsigned int IsPICT(const unsigned char *magick,const size_t length)
 %      reading.  A null image is returned if there is a memory shortage or
 %      if the image cannot be read.
 %
-%    o image_info: Specifies a pointer to an ImageInfo structure.
+%    o image_info: The image info.
 %
 %    o exception: return any errors or warnings in this structure.
 %
@@ -849,9 +849,8 @@ static Image *ReadPICTImage(const ImageInfo *image_info,
   /*
     Interpret PICT opcodes.
   */
-  code=0;
   jpeg=False;
-  for ( ; ; )
+  for (code=0; !EOFBlob(image); )
   {
     if (image_info->ping && (image_info->number_scenes != 0))
       if (image->scene >= (image_info->scene+image_info->number_scenes-1))
@@ -868,8 +867,9 @@ static Image *ReadPICTImage(const ImageInfo *image_info,
     else
       {
         if (IsEventLogging())
-          (void) LogMagickEvent(CoderEvent,GetMagickModule(),"  %04X %.1024s: %.1024s",code,
-            codes[code].name,codes[code].description);
+          (void) LogMagickEvent(CoderEvent,GetMagickModule(),
+            "  %04X %.1024s: %.1024s",code,codes[code].name,
+            codes[code].description);
         switch (code)
         {
           case 0x01:
@@ -1281,6 +1281,9 @@ static Image *ReadPICTImage(const ImageInfo *image_info,
         ImageInfo
           *clone_info;
 
+        int
+          unique_file;
+
         /*
           Embedded JPEG.
         */
@@ -1288,10 +1291,17 @@ static Image *ReadPICTImage(const ImageInfo *image_info,
         clone_info=CloneImageInfo(image_info);
         clone_info->blob=(void *) NULL;
         clone_info->length=0;
-        TemporaryFilename(clone_info->filename);
-        file=fopen(clone_info->filename,"wb");
-        if (file == (FILE *) NULL)
-          ThrowReaderException(FileOpenError,"UnableToWriteFile",image);
+        file=(FILE *) NULL;
+        unique_file=AcquireUniqueFileResource(clone_info->filename);
+        if (unique_file != -1)
+          file=fopen(clone_info->filename,"wb");
+        if ((unique_file == -1) || (file == (FILE *) NULL))
+          {
+            (void) strncpy(image->filename,clone_info->filename,
+              MaxTextExtent-1);
+            ThrowReaderException(FileOpenError,"UnableToCreateTemporaryFile",
+              image);
+          }
         length=ReadBlobMSBLong(image);
         for (i=0; i < 6; i++)
           (void) ReadBlobMSBLong(image);
@@ -1306,7 +1316,7 @@ static Image *ReadPICTImage(const ImageInfo *image_info,
         (void) fclose(file);
         tile_image=ReadImage(clone_info,exception);
         DestroyImageInfo(clone_info);
-        (void) remove(clone_info->filename);
+        (void) LiberateUniqueFileResource(clone_info->filename);
         if (tile_image == (Image *) NULL)
           continue;
         FormatString(geometry,"%lux%lu",Max(image->columns,tile_image->columns),
@@ -1342,7 +1352,7 @@ static Image *ReadPICTImage(const ImageInfo *image_info,
       }
   }
   if (EOFBlob(image))
-    ThrowException(exception,CorruptImageError,"UnexpectedEndOfFile",
+    (void) ThrowException(exception,CorruptImageError,"UnexpectedEndOfFile",
       image->filename);
   CloseBlob(image);
   return(image);
@@ -1444,9 +1454,9 @@ ModuleExport void UnregisterPICTImage(void)
 %      False is returned is there is a memory shortage or if the image file
 %      fails to write.
 %
-%    o image_info: Specifies a pointer to an ImageInfo structure.
+%    o image_info: The image info.
 %
-%    o image:  A pointer to a Image structure.
+%    o image:  The image.
 %
 %
 */
@@ -1525,7 +1535,7 @@ static unsigned int WritePICTImage(const ImageInfo *image_info,Image *image)
   status=OpenBlob(image_info,image,WriteBinaryBlobMode,&image->exception);
   if (status == False)
     ThrowWriterException(FileOpenError,"UnableToOpenFile",image);
-  (void) TransformRGBImage(image,image->colorspace);
+  (void) SetImageColorspace(image,RGBColorspace);
   /*
     Initialize image info.
   */
@@ -1581,6 +1591,8 @@ static unsigned int WritePICTImage(const ImageInfo *image_info,Image *image)
       (packed_scanline == (unsigned char *) NULL) ||
       (scanline == (unsigned char *) NULL))
     ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed",image);
+  (void) memset(scanline,0,row_bytes);
+  (void) memset(packed_scanline,0,row_bytes+MaxCount);
   /*
     Write header, header size, size bounding box, version, and reserved.
   */
