@@ -52,13 +52,14 @@
 /*
   Include declarations.
 */
-#include "studio.h"
-#include "blob.h"
-#include "magick.h"
-#include "monitor.h"
-#include "signature.h"
-#include "static.h"
-#include "utility.h"
+#include "magick/studio.h"
+#include "magick/blob.h"
+#include "magick/error.h"
+#include "magick/magick.h"
+#include "magick/monitor.h"
+#include "magick/signature.h"
+#include "magick/static.h"
+#include "magick/utility.h"
 
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -85,7 +86,7 @@
 %      creating it. A null image is returned if there is a memory shortage
 %      or if the image cannot be read.
 %
-%    o image_info: Specifies a pointer to an ImageInfo structure.
+%    o image_info: The image info.
 %
 %    o exception: return any errors or warnings in this structure.
 %
@@ -100,9 +101,9 @@ static void inline PlasmaPixel(Image *image,double x,double y)
   q=GetImagePixels(image,(long) ceil(x-0.5),(long) ceil(y-0.5),1,1);
   if (q == (PixelPacket *) NULL)
     return;
-  q->red=(Quantum) ((double) MaxRGB*GetRandomValue()+0.5);
-  q->green=(Quantum) ((double) MaxRGB*GetRandomValue()+0.5);
-  q->blue=(Quantum) ((double) MaxRGB*GetRandomValue()+0.5);
+  q->red=(Quantum) ((double) MaxRGB*rand()/RAND_MAX+0.5);
+  q->green=(Quantum) ((double) MaxRGB*rand()/RAND_MAX+0.5);
+  q->blue=(Quantum) ((double) MaxRGB*rand()/RAND_MAX+0.5);
   (void) SyncImagePixels(image);
 }
 
