@@ -52,14 +52,15 @@
 /*
   Include declarations.
 */
-#include "studio.h"
-#include "attribute.h"
-#include "blob.h"
-#include "list.h"
-#include "magick.h"
-#include "monitor.h"
-#include "static.h"
-#include "utility.h"
+#include "magick/studio.h"
+#include "magick/attribute.h"
+#include "magick/blob.h"
+#include "magick/error.h"
+#include "magick/list.h"
+#include "magick/magick.h"
+#include "magick/monitor.h"
+#include "magick/static.h"
+#include "magick/utility.h"
 
 /*
   Forward declarations.
@@ -130,7 +131,7 @@ static unsigned int IsPNM(const unsigned char *magick,const size_t length)
 %      reading.  A null image is returned if there is a memory shortage or
 %      if the image cannot be read.
 %
-%    o image_info: Specifies a pointer to an ImageInfo structure.
+%    o image_info: The image info.
 %
 %    o exception: return any errors or warnings in this structure.
 %
@@ -374,7 +375,7 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
             index=!PNMInteger(image,2);
             if (index >= image->colors)
               {
-                ThrowException(&image->exception,CorruptImageError,
+                (void) ThrowException(&image->exception,CorruptImageError,
                   "InvalidColormapIndex",image->filename);
                 index=0;
               }
@@ -412,7 +413,7 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
             index=intensity;
             if (index >= image->colors)
               {
-                ThrowException(&image->exception,CorruptImageError,
+                (void) ThrowException(&image->exception,CorruptImageError,
                   "InvalidColormapIndex",image->filename);
                 index=0;
               }
@@ -500,7 +501,7 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
                 break;
         }
         if (EOFBlob(image))
-          ThrowException(exception,CorruptImageError,"UnexpectedEndOfFile",
+          (void) ThrowException(exception,CorruptImageError,"UnexpectedEndOfFile",
             image->filename);
         break;
       }
@@ -532,7 +533,7 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
               index=(*p++);
               if (index >= image->colors)
                 {
-                  ThrowException(&image->exception,CorruptImageError,
+                  (void) ThrowException(&image->exception,CorruptImageError,
                     "invalid colormap index",image->filename);
                   index=0;
                 }
@@ -546,7 +547,7 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
               p+=2;
               if (index >= image->colors)
                 {
-                  ThrowException(&image->exception,CorruptImageError,
+                  (void) ThrowException(&image->exception,CorruptImageError,
                     "InvalidColormapIndex",image->filename);
                   index=0;
                 }
@@ -562,7 +563,7 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
         }
         LiberateMemory((void **) &pixels);
         if (EOFBlob(image))
-          ThrowException(exception,CorruptImageError,"UnexpectedEndOfFile",
+          (void) ThrowException(exception,CorruptImageError,"UnexpectedEndOfFile",
             image->filename);
         break;
       }
@@ -634,7 +635,7 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
         handler=SetMonitorHandler((MonitorHandler) NULL);
         (void) SetMonitorHandler(handler);
         if (EOFBlob(image))
-          ThrowException(exception,CorruptImageError,"UnexpectedEndOfFile",
+          (void) ThrowException(exception,CorruptImageError,"UnexpectedEndOfFile",
             image->filename);
         break;
       }
@@ -797,9 +798,9 @@ ModuleExport void UnregisterPNMImage(void)
 %      False is returned is there is a memory shortage or if the image file
 %      fails to write.
 %
-%    o image_info: Specifies a pointer to an ImageInfo structure.
+%    o image_info: The image info.
 %
-%    o image:  A pointer to a Image structure.
+%    o image:  The image.
 %
 %
 */
@@ -851,7 +852,7 @@ static unsigned int WritePNMImage(const ImageInfo *image_info,Image *image)
     /*
       Write PNM file header.
     */
-    (void) TransformRGBImage(image,image->colorspace);
+    (void) SetImageColorspace(image,RGBColorspace);
     format=6;
     if (LocaleCompare(image_info->magick,"PGM") == 0)
       format=5;
