@@ -52,14 +52,17 @@
 /*
   Include declarations.
 */
-#include "studio.h"
-#include "attribute.h"
-#include "blob.h"
-#include "list.h"
-#include "magick.h"
-#include "monitor.h"
-#include "static.h"
-#include "utility.h"
+#include "magick/studio.h"
+#include "magick/attribute.h"
+#include "magick/blob.h"
+#include "magick/error.h"
+#include "magick/command.h"
+#include "magick/list.h"
+#include "magick/magick.h"
+#include "magick/monitor.h"
+#include "magick/resource.h"
+#include "magick/static.h"
+#include "magick/utility.h"
 
 /*
   Constant declarations.
@@ -159,9 +162,9 @@ ModuleExport void UnregisterPREVIEWImage(void)
 %      False is returned is there is a memory shortage or if the image file
 %      fails to write.
 %
-%    o image_info: Specifies a pointer to an ImageInfo structure.
+%    o image_info: The image info.
 %
-%    o image:  A pointer to a Image structure.
+%    o image:  The image.
 %
 %
 */
@@ -227,7 +230,7 @@ static unsigned int WritePreviewImage(const ImageInfo *image_info,Image *image)
   if (status == False)
     ThrowWriterException(FileOpenError,"UnableToOpenFile",image);
   CloseBlob(image);
-  (void) TransformRGBImage(image,image->colorspace);
+  (void) SetImageColorspace(image,RGBColorspace);
   clone_info=CloneImageInfo(image_info);
   clone_info->quality=0;
   colors=2;
@@ -517,9 +520,14 @@ static unsigned int WritePreviewImage(const ImageInfo *image_info,Image *image)
         char
           filename[MaxTextExtent];
 
+        int
+          file;
+
         clone_info->quality=(unsigned int) (percentage+13.0);
         FormatString(factor,"%lu",clone_info->quality);
-        TemporaryFilename(filename);
+        file=AcquireUniqueFileResource(filename);
+        if (file != -1)
+          (void) close(file);
         FormatString(preview_image->filename,"jpeg:%.1024s",filename);
         status=WriteImage(clone_info,preview_image);
         if (status != False)
@@ -530,13 +538,13 @@ static unsigned int WritePreviewImage(const ImageInfo *image_info,Image *image)
             (void) strncpy(clone_info->filename,preview_image->filename,
               MaxTextExtent-1);
             quality_image=ReadImage(clone_info,&image->exception);
-            (void) remove(preview_image->filename);
             if (quality_image != (Image *) NULL)
               {
                 DestroyImage(preview_image);
                 preview_image=quality_image;
               }
           }
+        (void) LiberateUniqueFileResource(preview_image->filename);
         if ((GetBlobSize(preview_image)/1024) >= 1024)
           FormatString(label,"quality %.1024s\n%gmb ",factor,
             (double) GetBlobSize(preview_image)/1024.0/1024.0);
