@@ -52,15 +52,17 @@
 /*
   Include declarations.
 */
-#include "studio.h"
-#include "attribute.h"
-#include "blob.h"
-#include "compress.h"
-#include "list.h"
-#include "magick.h"
-#include "monitor.h"
-#include "static.h"
-#include "utility.h"
+#include "magick/studio.h"
+#include "magick/attribute.h"
+#include "magick/blob.h"
+#include "magick/error.h"
+#include "magick/compress.h"
+#include "magick/list.h"
+#include "magick/magick.h"
+#include "magick/monitor.h"
+#include "magick/resource.h"
+#include "magick/static.h"
+#include "magick/utility.h"
 #if defined(HasTIFF)
 #define CCITTParam  "-1"
 #else
@@ -119,6 +121,9 @@ static unsigned int Huffman2DEncodeImage(const ImageInfo *image_info,
   ImageInfo
     *clone_info;
 
+  int
+    unique_file;
+
   long
     count,
     j;
@@ -153,7 +158,7 @@ static unsigned int Huffman2DEncodeImage(const ImageInfo *image_info,
   if (huffman_image == (Image *) NULL)
     return(False);
   SetImageType(huffman_image,BilevelType);
-  TemporaryFilename(filename);
+  unique_file=AcquireUniqueFileResource(filename);
   FormatString(huffman_image->filename,"tiff:%s",filename);
   clone_info=CloneImageInfo(image_info);
   clone_info->compression=Group4Compression;
@@ -162,10 +167,12 @@ static unsigned int Huffman2DEncodeImage(const ImageInfo *image_info,
   DestroyImage(huffman_image);
   if (status == False)
     return(False);
-  tiff=TIFFOpen(filename,"rb");
-  if (tiff == (TIFF *) NULL)
+  tiff=(TIFF *) NULL;
+  if (unique_file != -1)
+    tiff=TIFFFdOpen(unique_file,filename,"rb");
+  if ((unique_file == -1) || (tiff == (TIFF *) NULL))
     {
-      (void) remove(filename);
+      (void) LiberateUniqueFileResource(filename);
       ThrowBinaryException(FileOpenError,"UnableToOpenFile",
         image_info->filename)
     }
@@ -181,7 +188,7 @@ static unsigned int Huffman2DEncodeImage(const ImageInfo *image_info,
   if (buffer == (unsigned char *) NULL)
     {
       TIFFClose(tiff);
-      (void) remove(filename);
+      (void) LiberateUniqueFileResource(filename);
       ThrowBinaryException(ResourceLimitError,"MemoryAllocationFailed",
         (char *) NULL)
     }
@@ -201,7 +208,7 @@ static unsigned int Huffman2DEncodeImage(const ImageInfo *image_info,
   }
   LiberateMemory((void **) &buffer);
   TIFFClose(tiff);
-  (void) remove(filename);
+  (void) LiberateUniqueFileResource(filename);
   return(True);
 }
 #else
@@ -210,7 +217,8 @@ static unsigned int Huffman2DEncodeImage(const ImageInfo *image_info,
 {
   assert(image != (Image *) NULL);
   assert(image->signature == MagickSignature);
-  ThrowBinaryException(CoderError,"TIFFLibraryIsNotAvailable",image->filename);
+  ThrowBinaryException(MissingDelegateError,"TIFFLibraryIsNotAvailable",
+    image->filename);
 }
 #endif
 
@@ -306,7 +314,7 @@ ModuleExport void UnregisterPS2Image(void)
 %    o status: Method WritePS2Image return True if the image is printed.
 %      False is returned if the image file cannot be opened for printing.
 %
-%    o image_info: Specifies a pointer to an ImageInfo structure.
+%    o image_info: The image info.
 %
 %    o image: The address of a structure of type Image;  returned from
 %      ReadImage.
@@ -567,7 +575,7 @@ static unsigned int WritePS2Image(const ImageInfo *image_info,Image *image)
     case JPEGCompression:
     {
       compression=RLECompression;
-      ThrowException(&image->exception,MissingDelegateError,
+      (void) ThrowException(&image->exception,MissingDelegateError,
         "JPEGLibraryIsNotAvailable",image->filename);
       break;
     }
@@ -576,7 +584,7 @@ static unsigned int WritePS2Image(const ImageInfo *image_info,Image *image)
     case LZWCompression:
     {
       compression=RLECompression;
-      ThrowException(&image->exception,MissingDelegateError,
+      (void) ThrowException(&image->exception,MissingDelegateError,
         "LZWEncodingNotEnabled",image->filename);
       break;
     }
@@ -585,7 +593,7 @@ static unsigned int WritePS2Image(const ImageInfo *image_info,Image *image)
     case ZipCompression:
     {
       compression=RLECompression;
-      ThrowException(&image->exception,MissingDelegateError,
+      (void) ThrowException(&image->exception,MissingDelegateError,
         "ZipLibraryIsNotAvailable",image->filename);
       break;
     }
