@@ -52,15 +52,17 @@
 /*
   Include declarations.
 */
-#include "studio.h"
-#include "attribute.h"
-#include "blob.h"
-#include "compress.h"
-#include "list.h"
-#include "magick.h"
-#include "monitor.h"
-#include "static.h"
-#include "utility.h"
+#include "magick/studio.h"
+#include "magick/attribute.h"
+#include "magick/blob.h"
+#include "magick/error.h"
+#include "magick/compress.h"
+#include "magick/list.h"
+#include "magick/magick.h"
+#include "magick/monitor.h"
+#include "magick/resource.h"
+#include "magick/static.h"
+#include "magick/utility.h"
 #if defined(HasTIFF)
 #define CCITTParam  "-1"
 #else
@@ -120,6 +122,9 @@ static unsigned int Huffman2DEncodeImage(const ImageInfo *image_info,
   ImageInfo
     *clone_info;
 
+  int
+    unique_file;
+
   long
     count,
     j;
@@ -154,7 +159,7 @@ static unsigned int Huffman2DEncodeImage(const ImageInfo *image_info,
   if (huffman_image == (Image *) NULL)
     return(False);
   SetImageType(huffman_image,BilevelType);
-  TemporaryFilename(filename);
+  unique_file=AcquireUniqueFileResource(filename);
   FormatString(huffman_image->filename,"tiff:%s",filename);
   clone_info=CloneImageInfo(image_info);
   clone_info->compression=Group4Compression;
@@ -163,10 +168,12 @@ static unsigned int Huffman2DEncodeImage(const ImageInfo *image_info,
   DestroyImage(huffman_image);
   if (status == False)
     return(False);
-  tiff=TIFFOpen(filename,"rb");
-  if (tiff == (TIFF *) NULL)
+  tiff=(TIFF *) NULL;
+  if (unique_file != -1)
+    tiff=TIFFFdOpen(unique_file,filename,"rb");
+  if ((unique_file == -1) || (tiff == (TIFF *) NULL))
     {
-      (void) remove(filename);
+      (void) LiberateUniqueFileResource(filename);
       ThrowBinaryException(FileOpenError,"UnableToOpenFile",
         image_info->filename)
     }
@@ -182,7 +189,7 @@ static unsigned int Huffman2DEncodeImage(const ImageInfo *image_info,
   if (buffer == (unsigned char *) NULL)
     {
       TIFFClose(tiff);
-      (void) remove(filename);
+      (void) LiberateUniqueFileResource(filename);
       ThrowBinaryException(ResourceLimitError,"MemoryAllocationFailed",
         (char *) NULL)
     }
@@ -202,7 +209,7 @@ static unsigned int Huffman2DEncodeImage(const ImageInfo *image_info,
   }
   LiberateMemory((void **) &buffer);
   TIFFClose(tiff);
-  (void) remove(filename);
+  (void) LiberateUniqueFileResource(filename);
   return(True);
 }
 #else
@@ -211,7 +218,8 @@ static unsigned int Huffman2DEncodeImage(const ImageInfo *image_info,
 {
   assert(image != (Image *) NULL);
   assert(image->signature == MagickSignature);
-  ThrowBinaryException(CoderError,"TIFFLibraryIsNotAvailable",image->filename)
+  ThrowBinaryException(MissingDelegateError,"TIFFLibraryIsNotAvailable",
+    image->filename)
 }
 #endif
 
@@ -305,7 +313,7 @@ ModuleExport void UnregisterPS3Image(void)
 %    o status: Method WritePS3Image return True if the image is printed.
 %      False is returned if the image file cannot be opened for printing.
 %
-%    o image_info: Specifies a pointer to an ImageInfo structure.
+%    o image_info: The image info.
 %
 %    o image: The address of a structure of type Image;  returned from
 %      ReadImage.
@@ -390,7 +398,7 @@ static unsigned int WritePS3Image(const ImageInfo *image_info,Image *image)
     case JPEGCompression:
     {
       compression=RLECompression;
-      ThrowException(&image->exception,MissingDelegateError,
+      (void) ThrowException(&image->exception,MissingDelegateError,
         "JPEGLibraryIsNotAvailable",image->filename);
       break;
     }
@@ -399,7 +407,7 @@ static unsigned int WritePS3Image(const ImageInfo *image_info,Image *image)
     case LZWCompression:
     {
       compression=RLECompression;
-      ThrowException(&image->exception,MissingDelegateError,
+      (void) ThrowException(&image->exception,MissingDelegateError,
         "LZWEncodingNotEnabled",image->filename);
       break;
     }
@@ -408,7 +416,7 @@ static unsigned int WritePS3Image(const ImageInfo *image_info,Image *image)
     case ZipCompression:
     {
       compression=RLECompression;
-      ThrowException(&image->exception,CoderError,
+      (void) ThrowException(&image->exception,CoderError,
         "ZipLibraryIsNotAvailable",image->filename);
       break;
     }
@@ -600,7 +608,7 @@ static unsigned int WritePS3Image(const ImageInfo *image_info,Image *image)
           Allocate pixel array.
         */
         number_pixels=(ExtendedSignedIntegralType) image->columns*image->rows;
-        if ((4*number_pixels*4) != (size_t) (4*number_pixels))
+        if ((4*number_pixels) != (size_t) (4*number_pixels))
           ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed",
             image);
         length=4*number_pixels;
@@ -868,7 +876,8 @@ static unsigned int ZLIBEncodeImage(Image *image,const size_t length,
 {
   assert(image != (Image *) NULL);
   assert(image->signature == MagickSignature);
-  ThrowBinaryException(CoderError,"ZipLibraryIsNotAvailable",image->filename);
+  ThrowBinaryException(MissingDelegateError,"ZipLibraryIsNotAvailable",
+    image->filename);
   return(False);
 }
 #endif
