@@ -53,14 +53,15 @@
 /*
   Include declarations.
 */
-#include "studio.h"
-#include "attribute.h"
-#include "blob.h"
-#include "list.h"
-#include "log.h"
-#include "magick.h"
-#include "static.h"
-#include "utility.h"
+#include "magick/studio.h"
+#include "magick/attribute.h"
+#include "magick/blob.h"
+#include "magick/error.h"
+#include "magick/list.h"
+#include "magick/log.h"
+#include "magick/magick.h"
+#include "magick/static.h"
+#include "magick/utility.h"
 
 /*
   Forward declarations.
@@ -330,7 +331,7 @@ static unsigned int IsPSD(const unsigned char *magick,const size_t length)
 %      reading.  A null image is returned if there is a memory shortage or
 %      if the image cannot be read.
 %
-%    o image_info: Specifies a pointer to an ImageInfo structure.
+%    o image_info: The image info.
 %
 %    o exception: return any errors or warnings in this structure.
 %
@@ -1247,6 +1248,7 @@ static Image *ReadPSDImage(const ImageInfo *image_info,ExceptionInfo *exception)
           image->next=layer_info[0].image;
           layer_info[0].image->previous=image;
 #else
+    DestroyImage(image);
     returnImage = layer_info[0].image;  
 #endif
           LiberateMemory((void **) &layer_info);
@@ -1479,9 +1481,9 @@ ModuleExport void UnregisterPSDImage(void)
 %      False is returned is there is a memory shortage or if the image file
 %      fails to write.
 %
-%    o image_info: Specifies a pointer to an ImageInfo structure.
+%    o image_info: The image info.
 %
-%    o image:  A pointer to a Image structure.
+%    o image:  The image.
 %
 %
 */
@@ -1684,14 +1686,13 @@ static unsigned int WritePSDImage(const ImageInfo *image_info,Image *image)
        (image->colorspace != CMYKColorspace)) &&
        (image_info->colorspace != CMYKColorspace))
     {
-      (void) TransformRGBImage(image,image->colorspace);
+      (void) SetImageColorspace(image,RGBColorspace);
       (void) WriteBlobMSBShort(image,
         image->storage_class == PseudoClass ? 2 : 3);
     }
   else
     {
-      if (image->colorspace != CMYKColorspace)
-        (void) RGBTransformImage(image,CMYKColorspace);
+      (void) SetImageColorspace(image,CMYKColorspace);
       (void) WriteBlobMSBShort(image,4);
     }
   if ((image->storage_class == DirectClass) || (image->colors > 256))
