@@ -52,13 +52,15 @@
 /*
   Include declarations.
 */
-#include "studio.h"
-#include "blob.h"
-#include "list.h"
-#include "magick.h"
-#include "monitor.h"
-#include "static.h"
-#include "utility.h"
+#include "magick/studio.h"
+#include "magick/blob.h"
+#include "magick/error.h"
+#include "magick/list.h"
+#include "magick/magick.h"
+#include "magick/monitor.h"
+#include "magick/resource.h"
+#include "magick/static.h"
+#include "magick/utility.h"
 
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -123,7 +125,7 @@ static unsigned int IsPWP(const unsigned char *magick,const size_t length)
 %      reading.  A null image is returned if there is a memory shortage or
 %      if the image cannot be read.
 %
-%    o image_info: Specifies a pointer to an ImageInfo structure.
+%    o image_info: The image info.
 %
 %    o exception: return any errors or warnings in this structure.
 %
@@ -143,7 +145,8 @@ static Image *ReadPWPImage(const ImageInfo *image_info,ExceptionInfo *exception)
     *clone_info;
 
   int
-    c;
+    c,
+    unique_file;
 
   MonitorHandler
     handler;
@@ -183,7 +186,7 @@ static Image *ReadPWPImage(const ImageInfo *image_info,ExceptionInfo *exception)
   clone_info=CloneImageInfo(image_info);
   clone_info->blob=(void *) NULL;
   clone_info->length=0;
-  TemporaryFilename(clone_info->filename);
+  unique_file=AcquireUniqueFileResource(clone_info->filename);
   image=(Image *) NULL;
   for ( ; ; )
   {
@@ -202,8 +205,10 @@ static Image *ReadPWPImage(const ImageInfo *image_info,ExceptionInfo *exception)
     /*
       Dump SFW image to a temporary file.
     */
-    file=fopen(clone_info->filename,"wb");
-    if (file == (FILE *) NULL)
+    file=(FILE *) NULL;
+    if (unique_file != -1)
+      file=fdopen(unique_file,"wb");
+    if ((unique_file == -1) || (file == (FILE *) NULL))
       ThrowReaderException(FileOpenError,"UnableToWriteFile",image);
     (void) fwrite("SFW94A",1,6,file);
     filesize=65535L*magick[2]+256L*magick[1]+magick[0];
@@ -239,12 +244,12 @@ static Image *ReadPWPImage(const ImageInfo *image_info,ExceptionInfo *exception)
     if (status == False)
       break;
   }
-  (void) remove(clone_info->filename);
+  (void) LiberateUniqueFileResource(clone_info->filename);
   DestroyImageInfo(clone_info);
   CloseBlob(pwp_image);
   DestroyImage(pwp_image);
   if (EOFBlob(image))
-    ThrowException(exception,CorruptImageError,"UnexpectedEndOfFile",
+    (void) ThrowException(exception,CorruptImageError,"UnexpectedEndOfFile",
       image->filename);
   CloseBlob(image);
   return(image);
