@@ -52,13 +52,14 @@
 /*
   Include declarations.
 */
-#include "studio.h"
-#include "blob.h"
-#include "list.h"
-#include "magick.h"
-#include "monitor.h"
-#include "static.h"
-#include "utility.h"
+#include "magick/studio.h"
+#include "magick/blob.h"
+#include "magick/error.h"
+#include "magick/list.h"
+#include "magick/magick.h"
+#include "magick/monitor.h"
+#include "magick/static.h"
+#include "magick/utility.h"
 
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -123,7 +124,7 @@ static unsigned int IsSCT(const unsigned char *magick,const size_t length)
 %      reading.  A null image is returned if there is a memory shortage or
 %      if the image cannot be read.
 %
-%    o image_info: Specifies a pointer to an ImageInfo structure.
+%    o image_info: The image info.
 %
 %    o exception: return any errors or warnings in this structure.
 %
@@ -247,7 +248,7 @@ static Image *ReadSCTImage(const ImageInfo *image_info,ExceptionInfo *exception)
         break;
   }
   if (EOFBlob(image))
-    ThrowException(exception,CorruptImageError,"UnexpectedEndOfFile",
+    (void) ThrowException(exception,CorruptImageError,"UnexpectedEndOfFile",
       image->filename);
   CloseBlob(image);
   return(image);
