@@ -858,7 +858,7 @@ static Image *ReadTIFFImage(const ImageInfo *image_info,
             }
             case 16:
             {
-              for (x=(long) image->columns; x > 0; x--)
+              for (x=(long) image->columns-1; x >= 0; x--)
                 {
 #if (QuantumDepth < 16)
                   *r++=(((unsigned int)(*(p) << 8) | (*(p+1)))/257);
@@ -1006,7 +1006,7 @@ static Image *ReadTIFFImage(const ImageInfo *image_info,
           p=pixels+image->columns*i-1;
           if (!TIFFReadRGBAStrip(tiff,y,pixels))
             break;
-          for (x=(long) image->columns; x > 0; x--)
+          for (x=(long) image->columns-1; x >= 0; x--)
           {
             q->red=ScaleCharToQuantum(TIFFGetR(*p));
             q->green=ScaleCharToQuantum(TIFFGetG(*p));
@@ -1155,7 +1155,7 @@ static Image *ReadTIFFImage(const ImageInfo *image_info,
           if (q == (PixelPacket *) NULL)
             break;
           q+=image->columns-1;
-          for (x=(long) image->columns; x > 0; x--)
+          for (x=(long) image->columns-1; x >= 0; x--)
           {
             q->red=ScaleCharToQuantum(TIFFGetR(*p));
             q->green=ScaleCharToQuantum(TIFFGetG(*p));
