@@ -52,14 +52,15 @@
 /*
   Include declarations.
 */
-#include "studio.h"
-#include "blob.h"
-#include "draw.h"
-#include "list.h"
-#include "magick.h"
-#include "render.h"
-#include "static.h"
-#include "utility.h"
+#include "magick/studio.h"
+#include "magick/blob.h"
+#include "magick/error.h"
+#include "magick/drawing_wand.h"
+#include "magick/list.h"
+#include "magick/magick.h"
+#include "magick/render.h"
+#include "magick/static.h"
+#include "magick/utility.h"
 
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -165,7 +166,7 @@ static unsigned int IsTTF(const unsigned char *magick,const size_t length)
 %      reading.  A null image is returned if there is a memory shortage or
 %      if the image cannot be read.
 %
-%    o image_info: Specifies a pointer to an ImageInfo structure.
+%    o image_info: The image info.
 %
 %    o exception: return any errors or warnings in this structure.
 %
@@ -184,12 +185,12 @@ static Image *ReadTTFImage(const ImageInfo *image_info,ExceptionInfo *exception)
       "$\243^\250*\265\371%!\247:/;.,?<> "
       "\342\352\356\373\364\344\353\357\366\374\377\340\371\351\350\347 ";
 
-  DrawContext
-    context;
-
   DrawInfo
     *draw_info;
 
+  DrawingWand
+    *wand;
+
   Image
     *image;
 
@@ -245,32 +246,32 @@ static Image *ReadTTFImage(const ImageInfo *image_info,ExceptionInfo *exception)
   draw_info=CloneDrawInfo(image_info,(DrawInfo *) NULL);
   draw_info->font=AllocateString(image->filename);
   draw_info->fill=image_info->pen;
-  context=DrawAllocateContext(draw_info,image);
-  (void) DrawPushGraphicContext(context);
-  (void) DrawSetViewbox(context,0,0,image->columns,image->rows);
-  (void) DrawSetFont(context,image_info->filename);
-  (void) DrawSetFontSize(context,18);
-  (void) DrawAnnotation(context,10,y,Text);
+  wand=DrawAllocateWand(draw_info,image);
+  (void) DrawPushGraphicContext(wand);
+  (void) DrawSetViewbox(wand,0,0,image->columns,image->rows);
+  (void) DrawSetFont(wand,image_info->filename);
+  (void) DrawSetFontSize(wand,18);
+  (void) DrawAnnotation(wand,10,y,Text);
   y+=20*MultilineCensus((char *) Text)+20;
   for (i=12; i <= 72; i+=6)
   {
     y+=i+12;
-    (void) DrawSetFontSize(context,18);
+    (void) DrawSetFontSize(wand,18);
     (void) FormatString(buffer,"%ld",i);
-    (void) DrawAnnotation(context,10,y,(const unsigned char *) buffer);
-    (void) DrawSetFontSize(context,i);
-    (void) DrawAnnotation(context,50,y,(const unsigned char *)
+    (void) DrawAnnotation(wand,10,y,(const unsigned char *) buffer);
+    (void) DrawSetFontSize(wand,i);
+    (void) DrawAnnotation(wand,50,y,(const unsigned char *)
       "That which does not destroy me, only makes me stronger.");
     if (i >= 24)
       i+=6;
   }
-  (void) DrawPopGraphicContext(context);
-  (void) DrawRender(context);
+  (void) DrawPopGraphicContext(wand);
+  (void) DrawRender(wand);
   /*
     Free resources.
   */
   DestroyDrawInfo(draw_info);
-  DrawDestroyContext(context);
+  DestroyDrawingWand(wand);
   CloseBlob(image);
   return(image);
 }
