@@ -53,12 +53,14 @@
 /*
   Include declarations.
 */
-#include "studio.h"
-#include "blob.h"
-#include "list.h"
-#include "magick.h"
-#include "static.h"
-#include "utility.h"
+#include "magick/studio.h"
+#include "magick/blob.h"
+#include "magick/error.h"
+#include "magick/list.h"
+#include "magick/magick.h"
+#include "magick/static.h"
+#include "magick/resource.h"
+#include "magick/utility.h"
 #if defined(HasXML)
 #  if defined(WIN32)
 #    if defined(__MINGW32__)
@@ -98,7 +100,7 @@
 %      reading. A null image is returned if there is a memory shortage or if
 %      the image cannot be read.
 %
-%    o image_info: Specifies a pointer to an ImageInfo structure.
+%    o image_info: The image info.
 %
 %    o exception: return any errors or warnings in this structure.
 %
@@ -143,6 +145,9 @@ static Image *ReadURLImage(const ImageInfo *image_info,ExceptionInfo *exception)
   ImageInfo
     *clone_info;
 
+  int
+    unique_file;
+
   void
     *context;
 
@@ -150,12 +155,15 @@ static Image *ReadURLImage(const ImageInfo *image_info,ExceptionInfo *exception)
   clone_info=CloneImageInfo(image_info);
   clone_info->blob=(void *) NULL;
   clone_info->length=0;
-  TemporaryFilename(clone_info->filename);
-  file=fopen(clone_info->filename,"wb");
-  if (file == (FILE *) NULL)
+  file=(FILE *) NULL;
+  unique_file=AcquireUniqueFileResource(clone_info->filename);
+  if (unique_file != -1)
+    file=fdopen(unique_file,"wb");
+  if ((unique_file == -1) || (file == (FILE *) NULL))
     {
       DestroyImageInfo(clone_info);
-      ThrowReaderException(FileOpenError,"UnableToOpenFile",image)
+      (void) strncpy(image->filename,clone_info->filename,MaxTextExtent-1);
+      ThrowReaderException(FileOpenError,"UnableToCreateTemporaryFile",image);
     }
   (void) strncpy(filename,image_info->magick,MaxTextExtent-1);
   (void) strcat(filename,":");
@@ -193,21 +201,18 @@ static Image *ReadURLImage(const ImageInfo *image_info,ExceptionInfo *exception)
         }
     }
   (void) fclose(file);
-  if (!IsAccessible(clone_info->filename))
-    ThrowException(exception,CoderError,"NoDataReturned",filename);
-  else
-    {
-      *clone_info->magick='\0';
-      image=ReadImage(clone_info,exception);
-    }
-  (void) remove(clone_info->filename);
+  *clone_info->magick='\0';
+  image=ReadImage(clone_info,exception);
+  (void) LiberateUniqueFileResource(clone_info->filename);
   DestroyImageInfo(clone_info);
+  if (image == (Image *) NULL)
+    (void) ThrowException(exception,CoderError,"NoDataReturned",filename);
   return(image);
 }
 #else
 static Image *ReadURLImage(const ImageInfo *image_info,ExceptionInfo *exception)
 {
-  ThrowException(exception,CoderError,
+  (void) ThrowException(exception,CoderError,
     "ImageMagick must be linked with XML library to support URLs",
     image_info->filename);
   return((Image *) NULL);
