@@ -52,13 +52,14 @@
 /*
   Include declarations.
 */
-#include "studio.h"
-#include "blob.h"
-#include "list.h"
-#include "magick.h"
-#include "monitor.h"
-#include "static.h"
-#include "utility.h"
+#include "magick/studio.h"
+#include "magick/blob.h"
+#include "magick/error.h"
+#include "magick/list.h"
+#include "magick/magick.h"
+#include "magick/monitor.h"
+#include "magick/static.h"
+#include "magick/utility.h"
 
 /*
   Forward declarations.
@@ -92,7 +93,7 @@ static unsigned int
 %      reading.  A null image is returned if there is a memory shortage or
 %      if the image cannot be read.
 %
-%    o image_info: Specifies a pointer to an ImageInfo structure.
+%    o image_info: The image info.
 %
 %    o exception: return any errors or warnings in this structure.
 %
@@ -176,9 +177,10 @@ static Image *ReadUYVYImage(const ImageInfo *image_info,
       if (!MagickMonitor(LoadImageTag,y,image->rows,exception))
         break;
   }
-  (void) TransformRGBImage(image,YCbCrColorspace);
+  image->colorspace=YCbCrColorspace;
+  (void) SetImageColorspace(image,RGBColorspace);
   if (EOFBlob(image))
-    ThrowException(exception,CorruptImageError,"UnexpectedEndOfFile",
+    (void) ThrowException(exception,CorruptImageError,"UnexpectedEndOfFile",
       image->filename);
   CloseBlob(image);
   return(image);
@@ -280,9 +282,9 @@ ModuleExport void UnregisterUYVYImage(void)
 %      False is returned is there is a memory shortage or if the image file
 %      fails to write.
 %
-%    o image_info: Specifies a pointer to an ImageInfo structure.
+%    o image_info: The image info.
 %
-%    o image:  A pointer to a Image structure.
+%    o image:  The image.
 %      Implicit assumption: number of columns is even.
 %
 */
@@ -291,6 +293,9 @@ static unsigned int WriteUYVYImage(const ImageInfo *image_info,Image *image)
   DoublePixelPacket
     pixel;
 
+  Image
+    *uyvy_image;
+
   long
     y;
 
@@ -314,19 +319,18 @@ static unsigned int WriteUYVYImage(const ImageInfo *image_info,Image *image)
   status=OpenBlob(image_info,image,WriteBinaryBlobMode,&image->exception);
   if (status == False)
     ThrowWriterException(FileOpenError,"UnableToOpenFile",image);
-  (void) TransformRGBImage(image,image->colorspace);
-  /*
-    Convert to YUV, at full resolution.
-  */
-  (void) RGBTransformImage(image,YCbCrColorspace);
   /*
     Accumulate two pixels, then output.
   */
+  uyvy_image=CloneImage(image,0,0,True,&image->exception);
+  if (uyvy_image == (Image *) NULL)
+    ThrowWriterException(ResourceLimitError,image->exception.reason,image);
+  (void) SetImageColorspace(uyvy_image,YCbCrColorspace);
   full=False;
   memset(&pixel,0,sizeof(DoublePixelPacket));
   for (y=0; y < (long) image->rows; y++)
   {
-    p=AcquireImagePixels(image,0,y,image->columns,1,&image->exception);
+    p=AcquireImagePixels(uyvy_image,0,y,image->columns,1,&image->exception);
     if (p == (const PixelPacket *) NULL)
       break;
     for (x=0; x < (long) image->columns; x++)
@@ -350,7 +354,7 @@ static unsigned int WriteUYVYImage(const ImageInfo *image_info,Image *image)
       if (!MagickMonitor(SaveImageTag,y,image->rows,&image->exception))
         break;
   }
-  (void) TransformRGBImage(image,YCbCrColorspace);
+  DestroyImage(uyvy_image);
   CloseBlob(image);
   return(True);
 }
