@@ -52,14 +52,15 @@
 /*
   Include declarations.
 */
-#include "studio.h"
-#include "attribute.h"
-#include "blob.h"
-#include "list.h"
-#include "magick.h"
-#include "monitor.h"
-#include "static.h"
-#include "utility.h"
+#include "magick/studio.h"
+#include "magick/attribute.h"
+#include "magick/blob.h"
+#include "magick/error.h"
+#include "magick/list.h"
+#include "magick/magick.h"
+#include "magick/monitor.h"
+#include "magick/static.h"
+#include "magick/utility.h"
 
 /*
   Forward declarations.
@@ -131,7 +132,7 @@ static unsigned int IsVIFF(const unsigned char *magick,const size_t length)
 %      reading.  A null image is returned if there is a memory shortage or if
 %      the image cannot be read.
 %
-%    o image_info: Specifies a pointer to an ImageInfo structure.
+%    o image_info: The image info.
 %
 %    o exception: return any errors or warnings in this structure.
 %
@@ -479,7 +480,7 @@ static Image *ReadVIFFImage(const ImageInfo *image_info,
         break;
       }
       default:
-        ThrowReaderException(CoderError,"ColormapTypeIsNotSupported",image)
+        ThrowReaderException(CoderError,"ColormapTypeNotSupported",image)
     }
     /*
       Initialize image structure.
@@ -707,7 +708,7 @@ static Image *ReadVIFFImage(const ImageInfo *image_info,
       SyncImage(image);
     if (EOFBlob(image))
       {
-        ThrowException(exception,CorruptImageError,"UnexpectedEndOfFile",
+        (void) ThrowException(exception,CorruptImageError,"UnexpectedEndOfFile",
           image->filename);
         break;
       }
@@ -832,9 +833,9 @@ ModuleExport void UnregisterVIFFImage(void)
 %      False is returned is there is a memory shortage or if the image file
 %      fails to write.
 %
-%    o image_info: Specifies a pointer to an ImageInfo structure.
+%    o image_info: The image info.
 %
-%    o image:  A pointer to a Image structure.
+%    o image:  The image.
 %
 %
 */
@@ -948,7 +949,7 @@ static unsigned int WriteVIFFImage(const ImageInfo *image_info,Image *image)
     /*
       Initialize VIFF image structure.
     */
-    (void) TransformRGBImage(image,image->colorspace);
+    (void) SetImageColorspace(image,RGBColorspace);
     viff_info.identifier=(char) 0xab;
     viff_info.file_type=1;
     viff_info.release=1;
