@@ -52,12 +52,13 @@
 /*
   Include declarations.
 */
-#include "studio.h"
-#include "blob.h"
-#include "magick.h"
-#include "static.h"
-#include "utility.h"
-#include "xwindow.h"
+#include "magick/studio.h"
+#include "magick/blob.h"
+#include "magick/error.h"
+#include "magick/magick.h"
+#include "magick/static.h"
+#include "magick/utility.h"
+#include "magick/xwindow.h"
 
 /*
   Forward declarations.
@@ -85,7 +86,7 @@ static unsigned int
 %
 %  A description of each parameter follows:
 %
-%    o image_info: Specifies a pointer to an ImageInfo structure.
+%    o image_info: The image info.
 %
 %    o exception: return any errors or warnings in this structure.
 %
@@ -102,7 +103,7 @@ static Image *ReadXImage(const ImageInfo *image_info,ExceptionInfo *exception)
 #else
 static Image *ReadXImage(const ImageInfo *image_info,ExceptionInfo *exception)
 {
-  ThrowException(exception,MissingDelegateError,"XWindowLibraryIsNotAvailable",
+  (void) ThrowException(exception,MissingDelegateError,"XWindowLibraryIsNotAvailable",
     image_info->filename);
   return((Image *) NULL);
 }
@@ -193,9 +194,9 @@ ModuleExport void UnregisterXImage(void)
 %      the X server.  False is returned is there is a memory shortage or if
 %      the image file fails to write.
 %
-%    o image_info: Specifies a pointer to an ImageInfo structure.
+%    o image_info: The image info.
 %
-%    o image:  A pointer to a Image structure.
+%    o image:  The image.
 %
 %
 */
@@ -221,7 +222,7 @@ static unsigned int WriteXImage(const ImageInfo *image_info,Image *image)
   */
   display=XOpenDisplay(image_info->server_name);
   if (display == (Display *) NULL)
-    ThrowWriterException(ResourceLimitError,"UnableToOpenXServer",image);
+    ThrowWriterException(XServerError,"UnableToOpenXServer",image);
   /*
     Set our forgiving error handler.
   */
