@@ -52,13 +52,14 @@
 /*
   Include declarations.
 */
-#include "studio.h"
-#include "blob.h"
-#include "list.h"
-#include "magick.h"
-#include "monitor.h"
-#include "static.h"
-#include "utility.h"
+#include "magick/studio.h"
+#include "magick/blob.h"
+#include "magick/error.h"
+#include "magick/list.h"
+#include "magick/magick.h"
+#include "magick/monitor.h"
+#include "magick/static.h"
+#include "magick/utility.h"
 
 /*
   Forward declarations.
@@ -92,7 +93,7 @@ static unsigned int
 %      reading.  A null image is returned if there is a memory shortage or
 %      if the image cannot be read.
 %
-%    o image_info: Specifies a pointer to an ImageInfo structure.
+%    o image_info: The image info.
 %
 %    o exception: return any errors or warnings in this structure.
 %
@@ -347,12 +348,13 @@ static Image *ReadYUVImage(const ImageInfo *image_info,ExceptionInfo *exception)
         break;
     }
     DestroyImage(resize_image);
-    (void) TransformRGBImage(image,YCbCrColorspace);
+    image->colorspace=YCbCrColorspace;
+    (void) SetImageColorspace(image,RGBColorspace);
     if (interlace == PartitionInterlace)
       (void) strncpy(image->filename,image_info->filename,MaxTextExtent-1);
     if (EOFBlob(image))
       {
-        ThrowException(exception,CorruptImageError,"UnexpectedEndOfFile",
+        (void) ThrowException(exception,CorruptImageError,"UnexpectedEndOfFile",
           image->filename);
         break;
       }
@@ -478,9 +480,9 @@ ModuleExport void UnregisterYUVImage(void)
 %      False is returned is there is a memory shortage or if the image file
 %      fails to write.
 %
-%    o image_info: Specifies a pointer to an ImageInfo structure.
+%    o image_info: The image info.
 %
-%    o image:  A pointer to a Image structure.
+%    o image:  The image.
 %
 %
 */
@@ -568,14 +570,14 @@ static unsigned int WriteYUVImage(const ImageInfo *image_info,Image *image)
       Sample image to an even width and height, if necessary.
     */
     image->depth=8;
-    (void) TransformRGBImage(image,image->colorspace);
+    (void) SetImageColorspace(image,RGBColorspace);
     width=image->columns+(image->columns & (horizontal_factor-1));
     height=image->rows+(image->rows & (vertical_factor-1));
     yuv_image=ResizeImage(image,width,height,TriangleFilter,1.0,
       &image->exception);
     if (yuv_image == (Image *) NULL)
       ThrowWriterException(ResourceLimitError,image->exception.reason,image);
-    (void) RGBTransformImage(yuv_image,YCbCrColorspace);
+    (void) SetImageColorspace(yuv_image,YCbCrColorspace);
     /*
       Downsample image.
     */
@@ -583,7 +585,7 @@ static unsigned int WriteYUVImage(const ImageInfo *image_info,Image *image)
       height/vertical_factor,TriangleFilter,1.0,&image->exception);
     if (chroma_image == (Image *) NULL)
       ThrowWriterException(ResourceLimitError,image->exception.reason,image);
-    (void) RGBTransformImage(chroma_image,YCbCrColorspace);
+    (void) SetImageColorspace(chroma_image,YCbCrColorspace);
     if (interlace == NoInterlace)
       {
         /*
