@@ -67,9 +67,24 @@
 #if defined(__MINGW32__)
 #  undef interface  /* Remove interface define */
 #endif
-#include "freetype/freetype.h"
-#include "freetype/ftglyph.h"
-#include "freetype/ftoutln.h"
+#if defined(HAVE_FT2BUILD_H)
+#  include <ft2build.h>
+#endif
+#if defined(FT_FREETYPE_H)
+#  include FT_FREETYPE_H
+#else
+#  include <freetype/freetype.h>
+#endif
+#if defined(FT_GLYPH_H)
+#  include FT_GLYPH_H
+#else
+#  include <freetype/ftglyph.h>
+#endif
+#if defined(FT_OUTLINE_H)
+#  include FT_OUTLINE_H
+#else
+#  include <freetype/ftoutln.h>
+#endif
 #endif
 
 /*
@@ -1179,7 +1194,7 @@ static unsigned int RenderFreetype(Image *image,const DrawInfo *draw_info,
   (void) CloneString(&clone_info->primitive,"path '");
   pattern=draw_info->fill_pattern;
   if (!image->matte)
-	  SetImageOpacity(image,OpaqueOpacity);
+    SetImageOpacity(image,OpaqueOpacity);
   for (i=0; i < (long) length; i++)
   {
     glyph.id=FT_Get_Char_Index(face,text[i]);
