@@ -1213,7 +1213,7 @@ MagickExport unsigned int IsGrayImage(const Image *image,
         p=AcquireImagePixels(image,0,y,image->columns,1,exception);
         if (p == (const PixelPacket *) NULL)
           return(False);
-        for (x=(long) image->columns; x > 0; x--)
+        for (x=(long) image->columns-1; x >= 0; x--)
         {
           if (!IsGray(*p))
             return(False);
@@ -1285,7 +1285,7 @@ MagickExport unsigned int IsMonochromeImage(const Image *image,
         p=AcquireImagePixels(image,0,y,image->columns,1,exception);
         if (p == (const PixelPacket *) NULL)
           return(False);
-        for (x=(long) image->columns; x > 0; x--)
+        for (x=(long) image->columns-1; x >= 0; x--)
         {
           if (!IsGray(*p))
             return(False);
