@@ -229,7 +229,7 @@ MagickExport unsigned int RGBTransformImage(Image *image,
         q=GetImagePixels(image,0,y,image->columns,1);
         if (q == (PixelPacket *) NULL)
           break;
-        for (x=(long) image->columns; x > 0; x--)
+        for (x=(long) image->columns-1; x >= 0; x--)
         {
           TransformHSL(q->red,q->green,q->blue,&hue,&saturation,&luminosity);
           q->red=(Quantum) (MaxRGB*hue+0.5);
@@ -263,7 +263,7 @@ MagickExport unsigned int RGBTransformImage(Image *image,
         q=GetImagePixels(image,0,y,image->columns,1);
         if (q == (PixelPacket *) NULL)
           break;
-        for (x=(long) image->columns; x > 0; x--)
+        for (x=(long) image->columns-1; x >= 0; x--)
         {
           TransformHWB(q->red,q->green,q->blue,&hue,&whiteness,&blackness);
           q->red=(Quantum) (MaxRGB*hue+0.5);
@@ -1154,7 +1154,7 @@ MagickExport unsigned int TransformRGBImage(Image *image,
         q=GetImagePixels(image,0,y,image->columns,1);
         if (q == (PixelPacket *) NULL)
           break;
-        for (x=(long) image->columns; x > 0; x--)
+        for (x=(long) image->columns-1; x >= 0; x--)
         {
           hue=(double) q->red/MaxRGB;
           saturation=(double) q->green/MaxRGB;
@@ -1188,7 +1188,7 @@ MagickExport unsigned int TransformRGBImage(Image *image,
         q=GetImagePixels(image,0,y,image->columns,1);
         if (q == (PixelPacket *) NULL)
           break;
-        for (x=(long) image->columns; x > 0; x--)
+        for (x=(long) image->columns-1; x >= 0; x--)
         {
           hue=(double) q->red/MaxRGB;
           whiteness=(double) q->green/MaxRGB;
