@@ -9,10 +9,15 @@ extern "C" {
 #endif
 
 extern MagickExport unsigned int
+  AnimateImageCommand(ImageInfo *,const int,char **,char **,ExceptionInfo *),
   CompositeImageCommand(ImageInfo *,const int,char **,char **,ExceptionInfo *),
   ConvertImageCommand(ImageInfo *,const int,char **,char **,ExceptionInfo *),
+  DisplayImageCommand(ImageInfo *,const int,char **,char **,ExceptionInfo *),
   IdentifyImageCommand(ImageInfo *,const int,char **,char **,ExceptionInfo *),
+  ImportImageCommand(ImageInfo *,const int,char **,char **,ExceptionInfo *),
+  MogrifyImage(const ImageInfo *,const int,char **,Image **),
   MogrifyImageCommand(ImageInfo *,const int,char **,char **,ExceptionInfo *),
+  MogrifyImages(const ImageInfo *,const int,char **,Image **),
   MontageImageCommand(ImageInfo *,const int,char **,char **,ExceptionInfo *);
 
 #if defined(__cplusplus) || defined(c_plusplus)
