@@ -53,8 +53,9 @@
 /*
   Include declarations.
 */
-#include "studio.h"
-#include "monitor.h"
+#include "magick/studio.h"
+#include "magick/error.h"
+#include "magick/monitor.h"
 
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -203,8 +204,8 @@ MagickExport Image *FrameImage(const Image *image,const FrameInfo *frame_info,
     CloneImage(image,frame_info->width,frame_info->height,True,exception);
   if (frame_image == (Image *) NULL)
     return(False);
-  SetImageType(frame_image,frame_image->matte_color.opacity !=
-    OpaqueOpacity ? TrueColorMatteType : TrueColorType);
+  frame_image->storage_class=DirectClass;
+  frame_image->matte|=frame_image->matte_color.opacity != OpaqueOpacity;
   /*
     Initialize 3D effects color.
   */
@@ -440,7 +441,7 @@ MagickExport unsigned int RaiseImage(Image *image,
       foreground=0;
       background=MaxRGB;
     }
-  SetImageType(image,TrueColorType);
+  image->storage_class=DirectClass;
   for (y=0; y < (long) raise_info->height; y++)
   {
     q=GetImagePixels(image,0,y,image->columns,1);
