@@ -58,10 +58,13 @@
 /*
   Include declarations.
 */
-#include "studio.h"
-#include "blob.h"
-#include "delegate.h"
-#include "utility.h"
+#include "magick/studio.h"
+#include "magick/blob.h"
+#include "magick/delegate.h"
+#include "magick/error.h"
+#include "magick/resource.h"
+#include "magick/semaphore.h"
+#include "magick/utility.h"
 
 /*
   Define declarations.
@@ -197,20 +200,20 @@ MagickExport char *GetDelegateCommand(const ImageInfo *image_info,Image *image,
   delegate_info=GetDelegateInfo(decode,encode,exception);
   if (delegate_info == (const DelegateInfo *) NULL)
     {
-      ThrowException(exception,DelegateError,"NoTagFound",
+      (void) ThrowException(exception,DelegateError,"NoTagFound",
         decode ? decode : encode);
       return((char *) NULL);
     }
   commands=StringToList(delegate_info->commands);
   if (commands == (char **) NULL)
     {
-      ThrowException(exception,ResourceLimitError,"MemoryAllocationFailed",
-        decode ? decode : encode);
+      (void) ThrowException(exception,ResourceLimitError,
+        "MemoryAllocationFailed",decode ? decode : encode);
       return((char *) NULL);
     }
   command=TranslateText(image_info,image,commands[0]);
   if (command == (char *) NULL)
-    ThrowException(exception,ResourceLimitError,"MemoryAllocationFailed",
+    (void) ThrowException(exception,ResourceLimitError,"MemoryAllocationFailed",
       commands[0]);
   /*
     Free resources.
@@ -362,7 +365,8 @@ MagickExport unsigned int InvokeDelegate(ImageInfo *image_info,Image *image,
     i;
 
   unsigned int
-    status;
+    status,
+    temporary;
 
   /*
     Get delegate.
@@ -371,16 +375,36 @@ MagickExport unsigned int InvokeDelegate(ImageInfo *image_info,Image *image,
   assert(image_info->signature == MagickSignature);
   assert(image != (Image *) NULL);
   assert(image->signature == MagickSignature);
+  temporary=(*image->filename == '\0');
+  if (temporary)
+    if (!AcquireUniqueFilename(image->filename))
+      {
+        (void) ThrowException(exception,FileOpenError,
+          "UnableToCreateTemporaryFile",image->filename);
+        return(False);
+      }
   (void) strncpy(filename,image->filename,MaxTextExtent-1);
   delegate_info=GetDelegateInfo(decode,encode,exception);
   if (delegate_info == (DelegateInfo *) NULL)
     {
-      ThrowException(exception,DelegateError,"NoTagFound",
+      if (temporary)
+        (void) LiberateUniqueFileResource(image->filename);
+      (void) ThrowException(exception,DelegateError,"NoTagFound",
         decode ? decode : encode);
       return(False);
     }
-  TemporaryFilename(image_info->unique);
-  TemporaryFilename(image_info->zero);
+  if (*image_info->filename == '\0')
+    {
+      if (!AcquireUniqueFilename(image_info->filename))
+        {
+          if (temporary)
+            (void) LiberateUniqueFileResource(image->filename);
+          (void) ThrowException(exception,FileOpenError,
+            "UnableToCreateTemporaryFile",image_info->filename);
+          return(False);
+        }
+      image_info->temporary=True;
+    }
   if (delegate_info->mode != 0)
     if ((decode && (delegate_info->encode != (char *) NULL)) ||
         (encode && (delegate_info->decode != (char *) NULL)))
@@ -398,11 +422,28 @@ MagickExport unsigned int InvokeDelegate(ImageInfo *image_info,Image *image,
         /*
           Delegate requires a particular image format.
         */
+        if (!AcquireUniqueFilename(image_info->unique))
+          {
+            (void) ThrowException(exception,FileOpenError,
+              "UnableToCreateTemporaryFile",image_info->unique);
+            return(False);
+          }
+        if (!AcquireUniqueFilename(image_info->zero))
+          {
+            (void) LiberateUniqueFileResource(image_info->zero);
+            (void) ThrowException(exception,FileOpenError,
+              "UnableToCreateTemporaryFile",image_info->zero);
+            return(False);
+          }
         magick=TranslateText(image_info,image,decode != (char *) NULL ?
           delegate_info->encode : delegate_info->decode);
         if (magick == (char *) NULL)
           {
-            ThrowException(exception,DelegateError,"DelegateFailed",
+            (void) LiberateUniqueFileResource(image_info->unique);
+            (void) LiberateUniqueFileResource(image_info->zero);
+            if (temporary)
+              (void) LiberateUniqueFileResource(image->filename);
+            (void) ThrowException(exception,DelegateError,"DelegateFailed",
               decode ? decode : encode);
             return(False);
           }
@@ -423,14 +464,20 @@ MagickExport unsigned int InvokeDelegate(ImageInfo *image_info,Image *image,
           status=WriteImage(clone_info,p);
           if (status == False)
             {
+              (void) LiberateUniqueFileResource(image_info->unique);
+              (void) LiberateUniqueFileResource(image_info->zero);
+              if (temporary)
+                (void) LiberateUniqueFileResource(image->filename);
               DestroyImageInfo(clone_info);
-              ThrowException(exception,DelegateError,"DelegateFailed",
+              (void) ThrowException(exception,DelegateError,"DelegateFailed",
                 decode ? decode : encode);
               return(False);
             }
           if (clone_info->adjoin)
             break;
         }
+        (void) LiberateUniqueFileResource(image_info->unique);
+        (void) LiberateUniqueFileResource(image_info->zero);
         DestroyImageInfo(clone_info);
       }
   /*
@@ -440,8 +487,10 @@ MagickExport unsigned int InvokeDelegate(ImageInfo *image_info,Image *image,
   commands=StringToList(delegate_info->commands);
   if (commands == (char **) NULL)
     {
-      ThrowException(exception,ResourceLimitError,"MemoryAllocationFailed",
-        decode ? decode : encode);
+      if (temporary)
+        (void) LiberateUniqueFileResource(image->filename);
+      (void) ThrowException(exception,ResourceLimitError,
+        "MemoryAllocationFailed",decode ? decode : encode);
       return(False);
     }
   command=(char *) NULL;
@@ -449,6 +498,19 @@ MagickExport unsigned int InvokeDelegate(ImageInfo *image_info,Image *image,
   for (i=0; commands[i] != (char *) NULL; i++)
   {
     status=True;
+    if (!AcquireUniqueFilename(image_info->unique))
+      {
+        (void) ThrowException(exception,FileOpenError,
+          "UnableToCreateTemporaryFile",image_info->unique);
+        break;
+      }
+    if (!AcquireUniqueFilename(image_info->zero))
+      {
+        (void) LiberateUniqueFileResource(image_info->unique);
+        (void) ThrowException(exception,FileOpenError,
+          "UnableToCreateTemporaryFile",image_info->zero);
+        break;
+      }
     command=TranslateText(image_info,image,commands[i]);
     if (command == (char *) NULL)
       break;
@@ -459,15 +521,21 @@ MagickExport unsigned int InvokeDelegate(ImageInfo *image_info,Image *image,
       (void) ConcatenateString(&command," &");
     status=SystemCommand(image_info->verbose,command);
     LiberateMemory((void **) &command);
-    (void) remove(image_info->zero);
-    (void) remove(image_info->unique);
+    (void) LiberateUniqueFileResource(image_info->unique);
+    (void) LiberateUniqueFileResource(image_info->zero);
     if (status != False)
-      ThrowException(exception,DelegateError,"DelegateFailed",commands[i]);
+      (void) ThrowException(exception,DelegateError,"DelegateFailed",
+        commands[i]);
     LiberateMemory((void **) &commands[i]);
   }
+  /*
+    Free resources.
+  */
   for ( ; commands[i] != (char *) NULL; i++)
     LiberateMemory((void **) &commands[i]);
   LiberateMemory((void **) &commands);
+  if (temporary)
+    (void) LiberateUniqueFileResource(image->filename);
   return(status != False);
 }
 
@@ -548,7 +616,7 @@ MagickExport unsigned int InvokePostscriptDelegate(const unsigned int verbose,
     }
   if (verbose)
     {
-      (void) fputs("gsdll32",stdout);
+      (void) fputs("[ghostscript library]",stdout);
       (void) fputs(strchr(command,' '),stdout);
     }
   status=(gs_func->new_instance)(&interpreter,(void *) NULL);
@@ -558,7 +626,7 @@ MagickExport unsigned int InvokePostscriptDelegate(const unsigned int verbose,
   status=(gs_func->init_with_args)(interpreter,argc-1,argv+1);
   if (status == 0)
     status=(gs_func->run_string)
-     (interpreter,"systemdict /start get exec\n",0,&code);
+      (interpreter,"systemdict /start get exec\n",0,&code);
   (gs_func->exit)(interpreter);
   (gs_func->delete_instance)(interpreter);
   for (i=0; i < argc; i++)
@@ -636,9 +704,15 @@ MagickExport unsigned int ListDelegateInfo(FILE *file,ExceptionInfo *exception)
     commands=StringToList(p->commands);
     if (commands == (char **) NULL)
       continue;
-    (void) fprintf(file,"%8s%c=%c%s  %.55s%s\n",p->decode ? p->decode : "",
-      p->mode <= 0 ? '<' : ' ',p->mode >= 0 ? '>' : ' ',delegate,commands[0],
-      strlen(commands[0]) > 55 ? "..." : "");
+    (void) fprintf(file,"%8s%c=%c%s  ",p->decode ? p->decode : "",
+      p->mode <= 0 ? '<' : ' ',p->mode >= 0 ? '>' : ' ',delegate);
+    Strip(commands[0]);
+    (void) fprintf(file,"%.1024s\n",commands[0]);
+    for (i=1; commands[i] != (char *) NULL; i++)
+    {
+      Strip(commands[i]);
+      (void) fprintf(file,"                     %.1024s\n",commands[i]);
+    }
     for (i=0; commands[i] != (char *) NULL; i++)
       LiberateMemory((void **) &commands[i]);
   }
@@ -736,7 +810,7 @@ static unsigned int ReadConfigureFile(const char *basename,
           if (LocaleCompare(keyword,"file") == 0)
             {
               if (depth > 200)
-                ThrowException(exception,ConfigureError,
+                (void) ThrowException(exception,ConfigureError,
                   "IncludeElementNestedTooDeeply",path);
               else
                 {
