@@ -53,14 +53,16 @@
 /*
   Include declarations.
 */
-#include "studio.h"
-#include "blob.h"
-#include "deprecate.h"
-#include "list.h"
-#include "log.h"
-#include "quantize.h"
-#include "resource.h"
-#include "utility.h"
+#include "magick/studio.h"
+#include "magick/blob.h"
+#include "magick/deprecate.h"
+#include "magick/error.h"
+#include "magick/list.h"
+#include "magick/log.h"
+#include "magick/quantize.h"
+#include "magick/resource.h"
+#include "magick/semaphore.h"
+#include "magick/utility.h"
 
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -142,6 +144,48 @@ MagickExport unsigned int DeleteImageList(Image *images,const long offset)
 %                                                                             %
 %                                                                             %
 %                                                                             %
+%   D e s t r o y B l o b I n f o                                             %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  DestroyBlobInfo() deallocates memory associated with an BlobInfo structure.
+%
+%  The format of the DestroyBlobInfo method is:
+%
+%      void DestroyBlobInfo(BlobInfo *blob)
+%
+%  A description of each parameter follows:
+%
+%    o blob: Specifies a pointer to a BlobInfo structure.
+%
+%
+*/
+MagickExport void DestroyBlobInfo(BlobInfo *blob)
+{
+  assert(blob != (BlobInfo *) NULL);
+  assert(blob->signature == MagickSignature);
+  AcquireSemaphoreInfo(&blob->semaphore);
+  blob->reference_count--;
+  if (blob->reference_count > 0)
+    {
+      LiberateSemaphoreInfo(&blob->semaphore);
+      return;
+    }
+  LiberateSemaphoreInfo(&blob->semaphore);
+  if (blob->mapped)
+    (void) UnmapBlob(blob->data,blob->length);
+  if (blob->semaphore != (SemaphoreInfo *) NULL)
+    DestroySemaphoreInfo(&blob->semaphore);
+  LiberateMemory((void **) &blob);
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
 %   D e s t r o y I m a g e s                                                 %
 %                                                                             %
 %                                                                             %
@@ -171,6 +215,71 @@ MagickExport void DestroyImages(Image *image)
 %                                                                             %
 %                                                                             %
 %                                                                             %
+%   D i s p a t c h I m a g e                                                 %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  DispatchImage() extracts pixel data from an image and returns it to you.
+%  The method returns False on success otherwise True if an error is
+%  encountered.  The data is returned as char, short int, int, long, float,
+%  or double in the order specified by map.
+%
+%  Suppose you want to extract the first scanline of a 640x480 image as
+%  character data in red-green-blue order:
+%
+%      DispatchImage(image,0,0,640,1,"RGB",CharPixel,pixels,exception);
+%
+%  The format of the DispatchImage method is:
+%
+%      unsigned int DispatchImage(const Image *image,const long x_offset,
+%        const long y_offset,const unsigned long columns,
+%        const unsigned long rows,const char *map,const StorageType type,
+%        void *pixels,ExceptionInfo *exception)
+%
+%  A description of each parameter follows:
+%
+%    o image: The image.
+%
+%    o x_offset, y_offset, columns, rows:  These values define the perimeter
+%      of a region of pixels you want to extract.
+%
+%    o map:  This string reflects the expected ordering of the pixel array.
+%      It can be any combination or order of R = red, G = green, B = blue,
+%      A = alpha, C = cyan, Y = yellow, M = magenta, K = black, or
+%      I = intensity (for grayscale).
+%
+%    o type: Define the data type of the pixels.  Float and double types are
+%      normalized to [0..1] otherwise [0..MaxRGB].  Choose from these types:
+%      CharPixel, ShortPixel, IntegerPixel, LongPixel, FloatPixel, or
+%      DoublePixel.
+%
+%    o pixels: This array of values contain the pixel components as defined by
+%      map and type.  You must preallocate this array where the expected
+%      length varies depending on the values of width, height, map, and type.
+%
+%    o exception: Return any errors or warnings in this structure.
+%
+%
+*/
+MagickExport unsigned int DispatchImage(const Image *image,const long x_offset,
+  const long y_offset,const unsigned long columns,const unsigned long rows,
+  const char *map,const StorageType type,void *pixels,ExceptionInfo *exception)
+{
+  unsigned int
+    status;
+
+  status=ExportImagePixels(image,x_offset,y_offset,columns,rows,map,type,pixels,
+    exception);
+  return(status);
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
 +   F u z z y C o l o r M a t c h                                             %
 %                                                                             %
 %                                                                             %
@@ -490,6 +599,38 @@ MagickExport Image *GetPreviousImage(const Image *images)
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %                                                                             %
 %                                                                             %
+%                                                                             %
+%   I d e n t i t y A f f i n e                                               %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  Method IdentityAffine initializes the affine transform to the identity
+%  matrix.
+%
+%  The format of the IdentityAffine method is:
+%
+%      IdentityAffine(AffineMatrix *affine)
+%
+%  A description of each parameter follows:
+%
+%    o affine: A pointer the the affine transform of type AffineMatrix.
+%
+%
+*/
+MagickExport void IdentityAffine(AffineMatrix *affine)
+{
+  assert(affine != (AffineMatrix *) NULL);
+  (void) memset(affine,0,sizeof(AffineMatrix));
+  affine->sx=1.0;
+  affine->sy=1.0;
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
 +     I s S u b i m a g e                                                     %
 %                                                                             %
 %                                                                             %
@@ -922,6 +1063,74 @@ MagickExport Image *SpliceImageList(Image *images,const long offset,
 %                                                                             %
 %                                                                             %
 %                                                                             %
+%  T e m p o r a r y F i l e n a m e                                          %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  TemporaryFilename() replaces the contents of path by a unique path name.
+%
+%  The format of the TemporaryFilename method is:
+%
+%      void TemporaryFilename(char *path)
+%
+%  A description of each parameter follows.
+%
+%   o  path:  Specifies a pointer to an array of characters.  The unique path
+%      name is returned in this array.
+%
+*/
+MagickExport void TemporaryFilename(char *path)
+{
+  (void) LogMagickEvent(DeprecateEvent,GetMagickModule(),"last use: v5.5.6");
+  (void) AcquireUniqueFilename(path);
+  (void) LiberateUniqueFileResource(path);
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                              %
+%                                                                              %
+%                                                                              %
++     T r a n s f o r m C o l o r s p a c e                                    %
+%                                                                              %
+%                                                                              %
+%                                                                              %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  (void) TransformColorspace() converts the image to a specified colorspace.
+%  If the image is already in the requested colorspace, no work is performed.
+%  Note that the current colorspace is stored in the image colorspace member.
+%  The transformation matrices are not necessarily the standard ones: the
+%  weights are rescaled to normalize the range of the transformed values to
+%  be [0..MaxRGB].
+%
+%  The format of the TransformColorspace method is:
+%
+%      unsigned int (void) TransformColorspace(Image *image,
+%        const ColorspaceType colorspace)
+%
+%  A description of each parameter follows:
+%
+%    o image: the image to transform
+%
+%    o colorspace: the desired colorspace.
+%
+%
+*/
+MagickExport unsigned int TransformColorspace(Image *image,
+  const ColorspaceType colorspace)
+{
+  (void) LogMagickEvent(DeprecateEvent,GetMagickModule(),"last use: v5.5.6");
+  return(SetImageColorspace(image,colorspace));
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
 %   U n s h i f t I m a g e L i s t                                           %
 %                                                                             %
 %                                                                             %
