@@ -48,6 +48,8 @@ extern MagickExport int
 extern MagickExport unsigned int
   ChannelThresholdImage(Image *,const char *),
   DeleteImageList(Image *,const long offset),
+  DispatchImage(const Image *,const long,const long,const unsigned long,
+    const unsigned long,const char *,const StorageType,void *,ExceptionInfo *),
   FuzzyColorMatch(const PixelPacket *,const PixelPacket *,const double),
   GetNumberScenes(const Image *),
   GetMagickGeometry(const char *,long *,long *,unsigned long *,unsigned long *),
@@ -61,8 +63,11 @@ extern MagickExport unsigned long
   GetImageListSize(const Image *);
 
 extern MagickExport void
+  DestroyBlobInfo(BlobInfo *),
   DestroyImages(Image *),
-  SetCacheThreshold(const unsigned long);
+  IdentityAffine(AffineMatrix *),
+  SetCacheThreshold(const unsigned long),
+  TemporaryFilename(char *);
 
 #if defined(__cplusplus) || defined(c_plusplus)
 }
