@@ -357,7 +357,7 @@ MagickExport unsigned int BlackThresholdImage(Image *image,
     if (q == (PixelPacket *) NULL)
       break;
     if (IsGray(pixel))
-      for (x=(long) image->columns; x > 0; x--)
+      for (x=(long) image->columns-1; x >= 0; x--)
       {
         if (PixelIntensityToQuantum(q) < pixel.red)
           {
@@ -368,7 +368,7 @@ MagickExport unsigned int BlackThresholdImage(Image *image,
         q++;
       }
     else
-      for (x=(long) image->columns; x > 0; x--)
+      for (x=(long) image->columns-1; x >= 0; x--)
       {
         if (q->red < pixel.red)
           q->red=0;
@@ -809,7 +809,7 @@ MagickExport Image *DespeckleImage(const Image *image,ExceptionInfo *exception)
       if (p == (const PixelPacket *) NULL)
         break;
       j++;
-      for (x=(long) image->columns; x > 0; x--)
+      for (x=(long) image->columns-1; x >= 0; x--)
       {
         switch (layer)
         {
@@ -841,7 +841,7 @@ MagickExport Image *DespeckleImage(const Image *image,ExceptionInfo *exception)
       if (q == (PixelPacket *) NULL)
         break;
       j++;
-      for (x=(long) image->columns; x > 0; x--)
+      for (x=(long) image->columns-1; x >= 0; x--)
       {
         switch (layer)
         {
@@ -1898,7 +1898,7 @@ MagickExport unsigned int RandomChannelThresholdImage(Image *image,const char
         LocaleCompare(channel,"intensity") == 0)
       {
         indexes=GetIndexes(image);
-        for (x=(long) image->columns; x > 0; x--)
+        for (x=(long) image->columns-1; x >= 0; x--)
           {
             double
               intensity;
@@ -1933,7 +1933,7 @@ MagickExport unsigned int RandomChannelThresholdImage(Image *image,const char
         LocaleCompare(channel,"matte") == 0)
       {
         if (image->matte)
-          for (x=(long) image->columns; x > 0; x--)
+          for (x=(long) image->columns-1; x >= 0; x--)
             {
               if (order == 1)
                 {
@@ -2873,7 +2873,7 @@ MagickExport unsigned int WhiteThresholdImage(Image *image,
     if (q == (PixelPacket *) NULL)
       break;
     if (IsGray(pixel))
-      for (x=(long) image->columns; x > 0; x--)
+      for (x=(long) image->columns-1; x >= 0; x--)
       {
         if (PixelIntensityToQuantum(q) > pixel.red)
           {
@@ -2884,7 +2884,7 @@ MagickExport unsigned int WhiteThresholdImage(Image *image,
         q++;
       }
     else
-      for (x=(long) image->columns; x > 0; x--)
+      for (x=(long) image->columns-1; x >= 0; x--)
       {
         if (q->red > pixel.red)
           q->red=MaxRGB;
