@@ -122,7 +122,7 @@ MagickExport unsigned int ContrastImage(Image *image,const unsigned int sharpen)
         q=GetImagePixels(image,0,y,image->columns,1);
         if (q == (PixelPacket *) NULL)
           break;
-        for (x=(long) image->columns; x > 0; x--)
+        for (x=(long) image->columns-1; x >= 0; x--)
         {
           Contrast(sign,&q->red,&q->green,&q->blue);
           q++;
@@ -229,7 +229,7 @@ MagickExport unsigned int EqualizeImage(Image *image)
     p=AcquireImagePixels(image,0,y,image->columns,1,&image->exception);
     if (p == (const PixelPacket *) NULL)
       break;
-    for (x=(long) image->columns; x > 0; x--)
+    for (x=(long) image->columns-1; x >= 0; x--)
     {
       histogram[ScaleQuantumToMap(p->red)].red++;
       histogram[ScaleQuantumToMap(p->green)].green++;
@@ -286,7 +286,7 @@ MagickExport unsigned int EqualizeImage(Image *image)
         q=GetImagePixels(image,0,y,image->columns,1);
         if (q == (PixelPacket *) NULL)
           break;
-        for (x=(long) image->columns; x > 0; x--)
+        for (x=(long) image->columns-1; x >= 0; x--)
         {
           if (low.red != high.red)
             q->red=equalize_map[ScaleQuantumToMap(q->red)].red;
@@ -436,7 +436,7 @@ MagickExport unsigned int GammaImage(Image *image,const char *level)
         q=GetImagePixels(image,0,y,image->columns,1);
         if (q == (PixelPacket *) NULL)
           break;
-        for (x=(long) image->columns; x > 0; x--)
+        for (x=(long) image->columns-1; x >= 0; x--)
         {
           q->red=gamma_map[ScaleQuantumToMap(q->red)].red;
           q->green=gamma_map[ScaleQuantumToMap(q->green)].green;
@@ -603,7 +603,7 @@ MagickExport unsigned int LevelImage(Image *image,const char *levels)
         q=GetImagePixels(image,0,y,image->columns,1);
         if (q == (PixelPacket *) NULL)
           break;
-        for (x=(long) image->columns; x > 0; x--)
+        for (x=(long) image->columns-1; x >= 0; x--)
         {
           q->red=ScaleMapToQuantum(levels_map[ScaleQuantumToMap(q->red)]);
           q->green=ScaleMapToQuantum(levels_map[ScaleQuantumToMap(q->green)]);
@@ -738,7 +738,7 @@ MagickExport unsigned int LevelImageChannel(Image *image,
         q=GetImagePixels(image,0,y,image->columns,1);
         if (q == (PixelPacket *) NULL)
           break;
-        for (x=(long) image->columns; x > 0; x--)
+        for (x=(long) image->columns-1; x >= 0; x--)
         {
           switch (channel)
           {
@@ -907,7 +907,7 @@ MagickExport unsigned int ModulateImage(Image *image,const char *modulate)
         q=GetImagePixels(image,0,y,image->columns,1);
         if (q == (PixelPacket *) NULL)
           break;
-        for (x=(long) image->columns; x > 0; x--)
+        for (x=(long) image->columns-1; x >= 0; x--)
         {
           Modulate(percent_hue,percent_saturation,percent_brightness,
             &q->red,&q->green,&q->blue);
@@ -992,7 +992,7 @@ MagickExport unsigned int NegateImage(Image *image,const unsigned int grayscale)
         q=GetImagePixels(image,0,y,image->columns,1);
         if (q == (PixelPacket *) NULL)
           break;
-        for (x=(long) image->columns; x > 0; x--)
+        for (x=(long) image->columns-1; x >= 0; x--)
         {
           if (grayscale)
             if ((q->red != q->green) || (q->green != q->blue))
@@ -1116,7 +1116,7 @@ MagickExport unsigned int NormalizeImage(Image *image)
     p=AcquireImagePixels(image,0,y,image->columns,1,&image->exception);
     if (p == (const PixelPacket *) NULL)
       break;
-    for (x=(long) image->columns; x > 0; x--)
+    for (x=(long) image->columns-1; x >= 0; x--)
     {
       histogram[ScaleQuantumToMap(p->red)].red++;
       histogram[ScaleQuantumToMap(p->green)].green++;
@@ -1250,7 +1250,7 @@ MagickExport unsigned int NormalizeImage(Image *image)
         q=GetImagePixels(image,0,y,image->columns,1);
         if (q == (PixelPacket *) NULL)
           break;
-        for (x=(long) image->columns; x > 0; x--)
+        for (x=(long) image->columns-1; x >= 0; x--)
         {
           if (low.red != high.red)
             q->red=normalize_map[ScaleQuantumToMap(q->red)].red;
