@@ -53,9 +53,10 @@
 /*
   Include declarations.
 */
-#include "studio.h"
-#include "error.h"
-#include "utility.h"
+#include "magick/studio.h"
+#include "magick/error.h"
+#include "magick/magick.h"
+#include "magick/utility.h"
 
 /*
   Forward declarations.
@@ -614,7 +615,8 @@ MagickExport ErrorHandler SetErrorHandler(ErrorHandler handler)
 %
 %  The format of the SetExceptionInfo method is:
 %
-%      SetExceptionInfo(ExceptionInfo *exception,ExceptionType severity)
+%      unsigned int SetExceptionInfo(ExceptionInfo *exception,
+%        ExceptionType severity)
 %
 %  A description of each parameter follows:
 %
@@ -624,11 +626,12 @@ MagickExport ErrorHandler SetErrorHandler(ErrorHandler handler)
 %
 %
 */
-MagickExport void SetExceptionInfo(ExceptionInfo *exception,
+MagickExport unsigned int SetExceptionInfo(ExceptionInfo *exception,
   ExceptionType severity)
 {
   assert(exception != (ExceptionInfo *) NULL);
   exception->severity=severity;
+  return(True);
 }
 
 /*
@@ -710,12 +713,12 @@ MagickExport WarningHandler SetWarningHandler(WarningHandler handler)
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  ThrowException() throws an exception with the specified severity code,
+%  (void) ThrowException() throws an exception with the specified severity code,
 %  reason, and optional description.
 %
 %  The format of the ThrowException method is:
 %
-%      void ThrowException(ExceptionInfo *exception,
+%      unsigned int (void) ThrowException(ExceptionInfo *exception,
 %        const ExceptionType severity,const char *reason,
 %        const char *description)
 %
@@ -731,25 +734,24 @@ MagickExport WarningHandler SetWarningHandler(WarningHandler handler)
 %
 %
 */
-MagickExport void ThrowException(ExceptionInfo *exception,
+MagickExport unsigned int ThrowException(ExceptionInfo *exception,
   const ExceptionType severity,const char *reason,const char *description)
 {
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickSignature);
+  if (severity <= exception->severity)
+    return(True);
   exception->severity=(ExceptionType) severity;
   exception->error_number=errno;
-  if (reason == (char *) NULL)
-    {
-      if (exception->reason != (char *) NULL)
-        LiberateMemory((void **) &exception->reason);
-    }
-  else
+  if (reason != (char *) NULL)
     (void) CloneString(&exception->reason,reason);
-  if (description == (char *) NULL)
-    {
-      if (exception->description != (char *) NULL)
-        LiberateMemory((void **) &exception->description);
-      return;
-    }
-  (void) CloneString(&exception->description,description);
+  else
+    if (exception->reason != (char *) NULL)
+      LiberateMemory((void **) &exception->reason);
+  if (description != (char *) NULL)
+    (void) CloneString(&exception->description,description);
+  else
+    if (exception->description != (char *) NULL)
+      LiberateMemory((void **) &exception->description);
+  return(True);
 }
