@@ -863,7 +863,7 @@ MagickExport Image *OilPaintImage(const Image *image,const double radius,
     q=SetImagePixels(paint_image,0,y,paint_image->columns,1);
     if ((p == (const PixelPacket *) NULL) || (q == (PixelPacket *) NULL))
       break;
-    for (x=(long) image->columns; x > 0; x--)
+    for (x=(long) image->columns-1; x >= 0; x--)
     {
       /*
         Determine most frequent color.
