@@ -53,9 +53,9 @@
 /*
   Include declarations.
 */
-#include "studio.h"
-#include "gem.h"
-#include "signature.h"
+#include "magick/studio.h"
+#include "magick/gem.h"
+#include "magick/signature.h"
 
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -188,7 +188,7 @@ MagickExport Quantum GenerateNoise(const Quantum pixel,
     sigma,
     value;
 
-  alpha=GetRandomValue();
+  alpha=(double) rand()/RAND_MAX;
   if (alpha == 0.0)
     alpha=1.0;
   switch (noise_type)
@@ -204,7 +204,7 @@ MagickExport Quantum GenerateNoise(const Quantum pixel,
       double
         tau;
 
-      beta=GetRandomValue();
+      beta=(double) rand()/RAND_MAX;
       sigma=sqrt(-2.0*log(alpha))*cos(2.0*MagickPI*beta);
       tau=sqrt(-2.0*log(alpha))*sin(2.0*MagickPI*beta);
       value=(double) pixel+sqrt((double) pixel)*SigmaGaussian*sigma+
@@ -217,7 +217,7 @@ MagickExport Quantum GenerateNoise(const Quantum pixel,
         sigma=MaxRGB;
       else
         sigma=sqrt(-2.0*log(alpha));
-      beta=GetRandomValue();
+      beta=(double) rand()/RAND_MAX;
       value=(double) pixel+pixel*SigmaMultiplicativeGaussian*sigma*
         cos(2.0*MagickPI*beta);
       break;
@@ -257,7 +257,7 @@ MagickExport Quantum GenerateNoise(const Quantum pixel,
 
       for (i=0; alpha > exp(-SigmaPoisson*pixel); i++)
       {
-        beta=GetRandomValue();
+        beta=(double) rand()/RAND_MAX;
         alpha=alpha*beta;
       }
       value=i/SigmaPoisson;
@@ -420,8 +420,6 @@ MagickExport void HSLTransform(const double hue,const double saturation,
   assert(red != (Quantum *) NULL);
   assert(green != (Quantum *) NULL);
   assert(blue != (Quantum *) NULL);
-  v=(luminosity <= 0.5) ? (luminosity*(1.0+saturation)) :
-    (luminosity+saturation-luminosity*saturation);
   if (saturation == 0.0)
     {
       *red=(Quantum) (MaxRGB*luminosity+0.5);
@@ -429,6 +427,8 @@ MagickExport void HSLTransform(const double hue,const double saturation,
       *blue=(Quantum) (MaxRGB*luminosity+0.5);
       return;
     }
+  v=(luminosity <= 0.5) ? (luminosity*(1.0+saturation)) :
+    (luminosity+saturation-luminosity*saturation);
   y=2.0*luminosity-v;
   x=y+(v-y)*(6.0*hue-floor(6.0*hue));
   z=v-(v-y)*(6.0*hue-floor(6.0*hue));
@@ -588,7 +588,7 @@ MagickExport void Hull(const long x_offset,const long y_offset,
     q++;
     r++;
     if (polarity > 0)
-      for (x=0; x < (long) columns; x++)
+      for (x=(long) columns; x > 0; x--)
       {
         v=(*p);
         if (*r >= (v+ScaleCharToQuantum(2)))
@@ -599,7 +599,7 @@ MagickExport void Hull(const long x_offset,const long y_offset,
         r++;
       }
     else
-      for (x=0; x < (long) columns; x++)
+      for (x=(long) columns; x > 0; x--)
       {
         v=(*p);
         if (*r <= (v-(long) ScaleCharToQuantum(2)))
@@ -624,7 +624,7 @@ MagickExport void Hull(const long x_offset,const long y_offset,
     r++;
     s++;
     if (polarity > 0)
-      for (x=0; x < (long) columns; x++)
+      for (x=(long) columns; x > 0; x--)
       {
         v=(*q);
         if ((*s >= (v+ScaleCharToQuantum(2))) && (*r > v))
@@ -636,7 +636,7 @@ MagickExport void Hull(const long x_offset,const long y_offset,
         s++;
       }
     else
-      for (x=0; x < (long) columns; x++)
+      for (x=(long) columns; x > 0; x--)
       {
         v=(*q);
         if ((*s <= (v-(long) ScaleCharToQuantum(2))) && (*r < v))
@@ -659,38 +659,6 @@ MagickExport void Hull(const long x_offset,const long y_offset,
 %                                                                             %
 %                                                                             %
 %                                                                             %
-%   I d e n t i t y A f f i n e                                               %
-%                                                                             %
-%                                                                             %
-%                                                                             %
-%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-%
-%  Method IdentityAffine initializes the affine transform to the identity
-%  matrix.
-%
-%  The format of the IdentityAffine method is:
-%
-%      IdentityAffine(AffineMatrix *affine)
-%
-%  A description of each parameter follows:
-%
-%    o affine: A pointer the the affine transform of type AffineMatrix.
-%
-%
-*/
-MagickExport void IdentityAffine(AffineMatrix *affine)
-{
-  assert(affine != (AffineMatrix *) NULL);
-  (void) memset(affine,0,sizeof(AffineMatrix));
-  affine->sx=1.0;
-  affine->sy=1.0;
-}
-
-/*
-%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-%                                                                             %
-%                                                                             %
-%                                                                             %
 %   I n t e r p o l a t e C o l o r                                           %
 %                                                                             %
 %                                                                             %
