@@ -225,7 +225,7 @@ MagickExport LinkedListInfo *AcquireLinkedList(const size_t maximum_elements)
 
   list_info=(LinkedListInfo *) AcquireMemory(sizeof(*list_info));
   if (list_info == (LinkedListInfo *) NULL)
-    return((void *) NULL);
+    return((LinkedListInfo *) NULL);
   list_info->maximum_elements=maximum_elements == 0 ? (~0) : maximum_elements;
   list_info->elements=0;
   list_info->head=(ElementInfo *) NULL;
@@ -387,14 +387,14 @@ MagickExport void DestroyHashMap(HashMapInfo *hash_info)
     if (list_info != (LinkedListInfo *) NULL)
       {
         ResetLinkedListIterator(list_info);
-        entry=GetNextElementInLinkedList(list_info);
+        entry=(EntryInfo *) GetNextElementInLinkedList(list_info);
         while (entry != (EntryInfo *) NULL)
         {
           if (hash_info->liberate_key != (void (*)(void **)) NULL)
             hash_info->liberate_key((void **) &entry->key);
           if (hash_info->liberate_data != (void (*)(void **)) NULL)
             hash_info->liberate_data((void **) &entry->data);
-          entry=GetNextElementInLinkedList(list_info);
+          entry=(EntryInfo *) GetNextElementInLinkedList(list_info);
         }
       }
     if (list_info != (LinkedListInfo *) NULL)
@@ -503,12 +503,12 @@ MagickExport void *GetEntryFromHashMap(const HashMapInfo *hash_info,
   if (list_info != (LinkedListInfo *) NULL)
     {
       ResetLinkedListIterator(list_info);
-      entry=GetNextElementInLinkedList(list_info);
+      entry=(EntryInfo *) GetNextElementInLinkedList(list_info);
       while (entry != (EntryInfo *) NULL)
       {
         if (entry->hash == hash)
           return(entry->data);
-        entry=GetNextElementInLinkedList(list_info);
+        entry=(EntryInfo *) GetNextElementInLinkedList(list_info);
       }
     }
   return((void *) NULL);
@@ -641,7 +641,7 @@ MagickExport void *GetNextEntryInHashMap(HashMapInfo *hash_info)
             ResetLinkedListIterator(list_info);
             hash_info->head_of_list=True;
           }
-      entry=GetNextElementInLinkedList(list_info);
+      entry=(EntryInfo *) GetNextElementInLinkedList(list_info);
       if (entry != (EntryInfo *) NULL)
         return(entry->key);
       hash_info->head_of_list=False;
@@ -1067,7 +1067,8 @@ MagickExport size_t HashStringType(const void *string)
     hash;
 
   GetSignatureInfo(&signature_info);
-  UpdateSignature(&signature_info,string,strlen(string));
+  UpdateSignature(&signature_info,(unsigned char *) string,
+    strlen((char *) string));
   FinalizeSignature(&signature_info);
   hash=0;
   for (i=0; i < 8; i++)
@@ -1190,7 +1191,7 @@ MagickExport unsigned int PutEntryInHashMap(HashMapInfo *hash_info,void *key,
   else
     {
       ResetLinkedListIterator(list_info);
-      entry=GetNextElementInLinkedList(list_info);
+      entry=(EntryInfo *) GetNextElementInLinkedList(list_info);
       for (i=0; entry != (EntryInfo *) NULL; i++)
       {
         if (entry->hash == next->hash)
@@ -1203,7 +1204,7 @@ MagickExport unsigned int PutEntryInHashMap(HashMapInfo *hash_info,void *key,
             LiberateMemory((void **) &entry);
             break;
           }
-        entry=GetNextElementInLinkedList(list_info);
+        entry=(EntryInfo *) GetNextElementInLinkedList(list_info);
       }
     }
   if (!InsertElementInLinkedList(list_info,0,next))
@@ -1416,12 +1417,12 @@ MagickExport void *RemoveEntryFromHashMap(HashMapInfo *hash_info,const void *key
   if (list_info != (LinkedListInfo *) NULL)
     {
       ResetLinkedListIterator(list_info);
-      entry=GetNextElementInLinkedList(list_info);
+      entry=(EntryInfo *) GetNextElementInLinkedList(list_info);
       for (i=0; entry != (EntryInfo *) NULL; i++)
       {
         if (entry->hash == hash)
           {
-            entry=RemoveElementFromLinkedList(list_info,i);
+            entry=(EntryInfo *) RemoveElementFromLinkedList(list_info,i);
             if (entry == (EntryInfo *) NULL)
               {
                 LiberateSemaphoreInfo(&hash_info->semaphore);
@@ -1435,7 +1436,7 @@ MagickExport void *RemoveEntryFromHashMap(HashMapInfo *hash_info,const void *key
             LiberateSemaphoreInfo(&hash_info->semaphore);
             return(data);
           }
-        entry=GetNextElementInLinkedList(list_info);
+        entry=(EntryInfo *) GetNextElementInLinkedList(list_info);
       }
     }
   LiberateSemaphoreInfo(&hash_info->semaphore);
