@@ -255,7 +255,7 @@ MagickExport unsigned int ListLocaleInfo(FILE *file,ExceptionInfo *exception)
   tag=(const char *) GetNextEntryInHashMap(locale_map);
   while (tag != (const char *) NULL)
   {
-    message=GetEntryFromHashMap(locale_map,tag);
+    message=(const char *) GetEntryFromHashMap(locale_map,tag);
     (void) strncpy(locale,tag,MaxTextExtent-1);
     (void) strncat(locale,message,MaxTextExtent-strlen(locale)-1);
     FormatString(locale,"%.1024s%.1024s",tag,message);
