@@ -500,7 +500,7 @@ static void *LogToBlob(const char *filename,size_t *length,
       register size_t
         i;
 
-      count=0;
+      (void) MagickSeek(file,0,SEEK_SET);
       for (i=0; i < *length; i+=count)
       {
         count=read(file,blob+i,*length-i);
