@@ -360,45 +360,12 @@ static void MagickExitHandler(void)
   DestroyMagick();
 }
 
-static SignalHandler *MagickSignal(int signal_number,SignalHandler *handler)
-{
-#if defined(HAVE_SIGACTION) && defined(HAVE_SIGEMPTYSET)
-  struct sigaction
-    action,
-    last_action;
-
-  action.sa_handler=handler;
-  sigemptyset(&action.sa_mask);
-  action.sa_flags=0;
-  if (signal_number == SIGALRM)
-    {
-#if defined(SA_INTERRUPT)
-      action.sa_flags|=SA_INTERRUPT;
-#endif
-    }
-  else
-    {
-#if defined(SA_RESTART)
-      action.sa_flags|=SA_RESTART;
-#endif
-    }
-  if (sigaction(signal_number,&action,&last_action) < 0)
-    return(SIG_ERR);
-  return(last_action.sa_handler);
-#else
-  return(signal(signal_number,handler));
-#endif
-}
-
 static void MagickSignalHandler(int signal_number)
 {
   DestroyMagick();
   if ((signal_number >= 0) && (signal_number < SIGMAX))
     if (signal_handlers[signal_number] != (SignalHandler *) NULL)
-      MagickSignal(signal_number,signal_handlers[signal_number]);
-#if defined(HAVE_RAISE)
-  raise(signal_number);
-#endif
+      signal_handlers[signal_number](signal_number);
   Exit(signal_number);
 }
 
