@@ -85,8 +85,7 @@ MagickExport void *AcquireMemory(const size_t size)
   void
     *allocation;
 
-  assert(size != 0);
-  allocation=malloc(size);
+  allocation=malloc(size == 0 ? 1UL : size);
   return(allocation);
 }
 
@@ -123,29 +122,19 @@ MagickExport void *AcquireMemory(const size_t size)
 MagickExport void *CloneMemory(void *destination,const void *source,
   const size_t size)
 {
-  register const unsigned char
+  const unsigned char
     *p;
 
-  register unsigned char
+  unsigned char
     *q;
 
-  register long
-    i;
-
   assert(destination != (void *) NULL);
   assert(source != (const void *) NULL);
   p=(const unsigned char *) source;
   q=(unsigned char *) destination;
-  if ((p <= q) || ((p+size) >= q))
+  if (((q+size) < p) || (q > (p+size)))
     return(memcpy(destination,source,size));
-  /*
-    Overlap, copy backwards.
-  */
-  p+=size;
-  q+=size;
-  for (i=(long) (size-1); i >= 0; i--)
-    *--q=(*--p);
-  return(destination);
+  return(memmove(destination,source,size));
 }
 
 /*
