@@ -8,25 +8,6 @@
 extern "C" {
 #endif
 
-typedef struct _CoderInfo
-{
-  const char
-    *tag;
-  
-  void
-    *handle;
-  
-  long
-    load_time;
-
-  unsigned long
-    signature;
-
-  struct _CoderInfo
-    *previous,
-    *next;
-} CoderInfo;
-
 typedef struct _ModuleInfo
 {
   const char
@@ -51,9 +32,6 @@ typedef struct _ModuleInfo
 extern MagickExport char
   *TagToModule(const char *);
 
-extern MagickExport const CoderInfo
-  *GetCoderInfo(const char *,ExceptionInfo *);
-
 extern MagickExport const ModuleInfo
   *GetModuleInfo(const char *,ExceptionInfo *);
 
@@ -66,6 +44,7 @@ extern MagickExport unsigned int
 
 extern MagickExport void
   DestroyModuleInfo(void),
+  *GetModuleBlob(const char *,char *,size_t *,ExceptionInfo *),
   RegisterStaticModules(void);
 
 #if defined(__cplusplus) || defined(c_plusplus)
