@@ -773,7 +773,7 @@ MagickExport Image *MontageImages(const Image *images,
   }
   DestroyImage(tile_image);
   if (texture != (Image *) NULL)
-    LiberateMemory((void **) &texture);
+    DestroyImage(texture);
   LiberateMemory((void **) &master_list);
   DestroyDrawInfo(draw_info);
   DestroyImageInfo(image_info);
