@@ -48,18 +48,19 @@
 %
 %
 */
-
 #if defined(WIN32)
 /*
   Include declarations.
 */
-#include "studio.h"
-#include "utility.h"
-#include "version.h"
+#include "magick/studio.h"
+#include "magick/magick.h"
+#include "magick/timer.h"
+#include "magick/utility.h"
+#include "magick/version.h"
 #if defined(HasLTDL)
 #  include "ltdl.h"
 #endif /* defined(HasLTDL) */
-#include "nt_base.h"
+#include "magick/nt_base.h"
 
 /*
   Static declarations.
@@ -69,10 +70,10 @@ static char
   *lt_slsearchpath = (char *) NULL;
 #endif
 static void
-  *gs_dll_handle = (void *)NULL;
-static GhostscriptVectors
-    gs_vectors;
+  *gs_dll_handle = (void *) NULL;
 
+static GhostscriptVectors
+  gs_vectors;
 
 /*
   External declarations.
@@ -124,8 +125,8 @@ MagickExport void closedir(DIR *entry)
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  DebugString() formats and sends a prtinf like message to the NT debug trace
-%  API, a file, or to the Event Log.
+%  Method DebugString formats and sends a prtinf like message to the NT
+%  debug trace API, a file, or to the Event Log
 %
 %  The format of the DebugString method is:
 %
@@ -136,7 +137,6 @@ MagickExport void closedir(DIR *entry)
 %   o  format:  A string describing the format to use to write the
 %      remaining arguments.
 %
-%
 */
 
 #define IM_DEBUG_WIN32  1
@@ -323,7 +323,7 @@ MagickExport void DebugString(char *format,...)
 BOOL WINAPI DllMain(HINSTANCE hinstDLL,DWORD fdwReason,LPVOID lpvReserved)
 {
   switch ( fdwReason )
-    {
+  {
     case DLL_PROCESS_ATTACH:
       InitializeMagick(NULL);
       break;
@@ -331,11 +331,9 @@ BOOL WINAPI DllMain(HINSTANCE hinstDLL,DWORD fdwReason,LPVOID lpvReserved)
       DestroyMagick();
       break;
     default:
-      {
-        /* Do nothing */
-      }
-    }
-  return TRUE;
+      break;
+  }
+  return(TRUE);
 }
 #endif
 
@@ -350,7 +348,7 @@ BOOL WINAPI DllMain(HINSTANCE hinstDLL,DWORD fdwReason,LPVOID lpvReserved)
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  Exit() calls TerminateProcess for Win95.
+%  Method Exit calls TerminateProcess for Win95.
 %
 %  The format of the Exit method is:
 %
@@ -376,13 +374,59 @@ MagickExport int Exit(int status)
 %                                                                             %
 %                                                                             %
 %                                                                             %
+%   f t r u n c a t e                                                         %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  ftruncate() truncates a file to the specified size.  If the file is longer
+%  than the specified size, it is shortened to the specified size. If the file
+%  is shorter than the specified size, it is extended to the specified size by
+%  filling with zeros.  This is a POSIX compatability function.
+%
+%  The format of the ftruncate method is:
+%
+%      int ftruncate(int file,ExtendedSignedIntegralType length)
+%
+%  A description of each parameter follows:
+%
+%    o status: Zero is returned on successful completion. Otherwise -1
+%      is returned and errno is set to indicate the error.
+%
+%    o file: File descriptor from the _open() call.
+%
+%    o length: Desired file length.
+%
+*/
+MagickExport int ftruncate(int file,ExtendedSignedIntegralType length)
+{
+  int
+    status;
+
+  MagickOffset
+    current_pos;
+
+  status=0;
+  current_pos=MagickTell(file);
+  status=chsize(file,length);
+  if (!status)
+    status=MagickSeek(file,current_pos,SEEK_SET);
+  return(status);
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
 %   I s W i n d o w s 9 5                                                     %
 %                                                                             %
 %                                                                             %
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  IsWindows95() returns true if the system is Windows 95.
+%  Method IsWindows95 returns true if the system is Windows 95.
 %
 %  The format of the IsWindows95 method is:
 %
@@ -419,7 +463,7 @@ MagickExport int IsWindows95()
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  lt_dlclose() unloads the module associated with the passed handle.
+%   lt_dlclose() unloads the module associated with the passed handle.
 %
 %  The format of the lt_dlclose method is:
 %
@@ -430,9 +474,45 @@ MagickExport int IsWindows95()
 %    o handle: Specifies a handle to a previously loaded dynamic module.
 %
 */
-void lt_dlclose(void *handle)
+int lt_dlclose(void *handle)
 {
-  FreeLibrary(handle);
+  return (!(FreeLibrary(handle)));
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%   l t _ d l e r r o r                                                       %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  lt_dlerror() returns a pointer to a string describing the last error
+%  associated with a lt_dl method.  Note that this function is not thread
+%  safe so it should only be used under the protection of a lock.
+%
+%  The format of the lt_dlerror method is:
+%
+%      const char *lt_dlerror(void)
+%
+*/
+const char *lt_dlerror(void)
+{
+  static char
+    last_error[MaxTextExtent];
+
+  char
+    *error;
+
+  *last_error='\0';
+  error=NTGetLastError();
+  if (error)
+    (void) strncpy(last_error,error,MaxTextExtent-1);
+  LiberateMemory((void **) &error);
+  return (last_error);
 }
 
 /*
@@ -446,7 +526,7 @@ void lt_dlclose(void *handle)
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  lt_dlexit() exits the dynamic module loading subsystem.
+%   lt_dlexit() exits the dynamic module loading subsystem.
 %
 %  The format of the lt_dlexit method is:
 %
@@ -469,13 +549,12 @@ int lt_dlexit(void)
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  lt_dlinit() initializes the dynamic module loading subsystem.
+%   Method lt_dlinit initializes the dynamic module loading subsystem.
 %
 %  The format of the lt_dlinit method is:
 %
 %      int lt_dlinit(void)
 %
-%
 */
 int lt_dlinit(void)
 {
@@ -493,21 +572,20 @@ int lt_dlinit(void)
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  lt_dlopen() loads a dynamic module into memory and returns a handle that
-%  can be used to access the various procedures in the module.
+%   Method lt_dlopen loads a dynamic module into memory and returns a handle
+%   that can be used to access the various procedures in the module.
 %
 %  The format of the lt_dlopen method is:
 %
-%      void *lt_dlopen(char *filename)
+%      void *lt_dlopen(const char *filename)
 %
 %  A description of each parameter follows:
 %
 %    o path: Specifies a pointer to string representing dynamic module that
-%      is to be loaded.
-%
+%            is to be loaded.
 %
 */
-void *lt_dlopen(char *filename)
+void *lt_dlopen(const char *filename)
 {
 #define MaxPathElements  31
 
@@ -529,13 +607,10 @@ void *lt_dlopen(char *filename)
 
   handle=(void *) NULL;
   handle=(void *) LoadLibrary(filename);
-
   if (handle != (void *) NULL)
     return(handle);
-
   if (lt_slsearchpath == (char *) NULL)
     return handle;
-
   p=lt_slsearchpath;
   index=0;
   while (index < MaxPathElements)
@@ -573,12 +648,12 @@ void *lt_dlopen(char *filename)
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  lt_dlsetsearchpath() sets the current locations that the subsystem should
-%  look at to find dynamically loadable modules.
+%   Method lt_dlsetsearchpath sets the current locations that the subsystem
+%   should look at to find dynamically loadable modules.
 %
 %  The format of the lt_dlsetsearchpath method is:
 %
-%      long lt_dlsetsearchpath(char *path)
+%      int lt_dlsetsearchpath(const char *path)
 %
 %  A description of each parameter follows:
 %
@@ -586,7 +661,7 @@ void *lt_dlopen(char *filename)
 %            for DLL's that can be dynamically loaded.
 %
 */
-void lt_dlsetsearchpath(char *path)
+int lt_dlsetsearchpath(const char *path)
 {
   if (lt_slsearchpath)
     {
@@ -595,6 +670,7 @@ void lt_dlsetsearchpath(char *path)
     }
   if (path != (char *) NULL)
     lt_slsearchpath=AllocateString(path);
+  return(0);
 }
 
 /*
@@ -608,12 +684,12 @@ void lt_dlsetsearchpath(char *path)
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  lt_dlsym() retrieve the procedure address of the procedure specified by the
-%  passed character string.
+%   Method lt_dlsym retrieve the procedure address of the procedure specified
+%   by the passed character string.
 %
 %  The format of the lt_dlsym method is:
 %
-%      void *lt_dlsym(void *handle,char *name)
+%      void *lt_dlsym(void *handle,const char *name)
 %
 %  A description of each parameter follows:
 %
@@ -622,7 +698,7 @@ void lt_dlsetsearchpath(char *path)
 %    o name: Specifies the procedure entry point to be returned.
 %
 */
-void *lt_dlsym(void *h,char *s)
+void *lt_dlsym(void *h,const char *s)
 {
   LPFNDLLFUNC1
     lpfnDllFunc1;
@@ -645,7 +721,7 @@ void *lt_dlsym(void *h,char *s)
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  mmap() emulates the Unix method of the same name.
+%  Method mmap emulates the Unix method of the same name.
 %
 %  The format of the mmap method is:
 %
@@ -715,7 +791,7 @@ MagickExport void *mmap(char *address,size_t length,int protection,int access,
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  munmap() emulates the Unix method with the same name.
+%  Method munmap emulates the Unix method with the same name.
 %
 %  The format of the munmap method is:
 %
@@ -750,8 +826,8 @@ MagickExport int munmap(void *map,size_t length)
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  NTElapsedTime() returns the elapsed time (in seconds) since the last call
-%  to StartTimer().
+%  Method NTElapsedTime returns the elapsed time (in seconds) since the last
+%  call to StartTimer().
 %
 %  The format of the ElapsedTime method is:
 %
@@ -789,7 +865,8 @@ MagickExport double NTElapsedTime(void)
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  NTErrorHandler() displays an error reason and then terminates the program.
+%  Method NTErrorHandler displays an error reason and then terminates
+%  the program.
 %
 %  The format of the NTErrorHandler method is:
 %
@@ -849,7 +926,7 @@ MagickExport void NTErrorHandler(const ExceptionType error,const char *reason,
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  NTGetExecutionPath() returns the execution path of a program.
+%  Method NTGetExecutionPath returns the execution path of a program.
 %
 %  The format of the GetExecutionPath method is:
 %
@@ -874,7 +951,7 @@ MagickExport unsigned int NTGetExecutionPath(char *path)
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  NTGetLastError() returns the last error that occurred.
+%   Method NTGetLastError returns the last error that occurred.
 %
 %  The format of the NTGetLastError method is:
 %
@@ -901,7 +978,7 @@ char *NTGetLastError(void)
     reason=AllocateString("An unknown error occurred");
   else
     {
-      reason=AllocateString(buffer);
+      reason=AllocateString((const char *) buffer);
       LocalFree(buffer);
     }
   return(reason);
@@ -918,8 +995,8 @@ char *NTGetLastError(void)
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  NTGhostscriptDLL() obtains the path to the latest Ghostscript DLL.  The
-%  method returns False if a value is not obtained.
+%   Method NTGhostscriptDLL obtains the path to the latest Ghostscript DLL.
+%   The method returns False if a value is not obtained.
 %
 %  The format of the NTGhostscriptDLL method is:
 %
@@ -962,8 +1039,8 @@ char *NTGetLastError(void)
  * Store results starting at pver + 1 + offset.
  * Returns total number of versions in pver.
  */
-static int NTGhostscriptProductVersions(int *pver,int offset,
-  const char *gs_productfamily)
+static int NTGhostscriptProductVersions(int *pver, int offset,
+    const char *gs_productfamily)
 {
   HKEY
     hkey,
@@ -1055,8 +1132,8 @@ static int NTGhostscriptEnumerateVersions(int *pver)
  * name, ptr, plen and return values are the same as in gp_getenv();
  */
 
-static int  NTGetRegistryValue(HKEY hkeyroot,const char *key,const char *name,
-  char *ptr,int *plen)
+static int  NTGetRegistryValue(HKEY hkeyroot, const char *key, const char *name,
+    char *ptr, int *plen)
 {
   HKEY
     hkey;
@@ -1093,8 +1170,8 @@ static int  NTGetRegistryValue(HKEY hkeyroot,const char *key,const char *name,
   return 1;  /* not found */
 }
 
-static int NTGhostscriptGetProductString(int gs_revision,const char *name,
-  char *ptr,int len,const char *gs_productfamily)
+static int NTGhostscriptGetProductString(int gs_revision, const char *name,
+    char *ptr, int len, const char *gs_productfamily)
 {
   /* If using Win32, look in the registry for a value with
    * the given name.  The registry value will be under the key
@@ -1139,8 +1216,7 @@ static int NTGhostscriptGetProductString(int gs_revision,const char *name,
   return FALSE;
 }
 
-static int NTGhostscriptGetString(int gs_revision,const char *name,char *ptr,
-  int len)
+static int NTGhostscriptGetString(int gs_revision, const char *name, char *ptr, int len)
 {
   if (NTGhostscriptGetProductString(gs_revision, name, ptr, len, GS_PRODUCT_AFPL))
     return TRUE;
@@ -1151,7 +1227,7 @@ static int NTGhostscriptGetString(int gs_revision,const char *name,char *ptr,
   return FALSE;
 }
 
-static int NTGetLatestGhostscript(void)
+static int NTGetLatestGhostscript( void )
 {
   int
     count,
@@ -1167,7 +1243,7 @@ static int NTGetLatestGhostscript(void)
   NTGhostscriptEnumerateVersions(&count);
   if (count < 1)
     return FALSE;
-  ver = (int *)AcquireMemory((count+1)*sizeof(int));
+  ver = (int *) AcquireMemory((count+1)*sizeof(int));
   if (ver == (int *)NULL)
     return FALSE;
   ver[0] = count+1;
@@ -1196,8 +1272,8 @@ static int NTGetLatestGhostscript(void)
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  NTGhostscriptDLL() obtains the path to the latest Ghostscript DLL.  The
-%  method returns False if a value is not obtained.
+%   Method NTGhostscriptDLL obtains the path to the latest Ghostscript DLL.
+%   The method returns False if a value is not obtained.
 %
 %  The format of the NTGhostscriptDLL method is:
 %
@@ -1210,7 +1286,7 @@ static int NTGetLatestGhostscript(void)
 %    o path_length: Allocation size of path buffer.
 %%
 */
-MagickExport int NTGhostscriptDLL(char *path,int path_length)
+MagickExport int NTGhostscriptDLL(char *path, int path_length)
 {
   int
     gsver;
@@ -1241,23 +1317,22 @@ MagickExport int NTGhostscriptDLL(char *path,int path_length)
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  NTGhostscriptDLLVectors() returns a GhostscriptVectors structure containing
-%  function vectors to invoke Ghostscript DLL functions. A null pointer is
-%  returned if there is an error with loading the DLL or retrieving the
-^  function vectors.
+%   Method NTGhostscriptDLLVectors returns a GhostscriptVectors structure
+%   containing function vectors to invoke Ghostscript DLL functions. A null
+%   pointer is returned if there is an error with loading the DLL or
+%   retrieving the function vectors.
 %
 %  The format of the NTGhostscriptDLLVectors method is:
 %
 %      const GhostscriptVectors *NTGhostscriptDLLVectors( void )
 %
-%
+%%
 */
-MagickExport const GhostscriptVectors *NTGhostscriptDLLVectors(void)
+MagickExport const GhostscriptVectors *NTGhostscriptDLLVectors( void )
 {
   if (NTGhostscriptLoadDLL())
-    return &gs_vectors;
-
-  return (GhostscriptVectors*) NULL;
+    return(&gs_vectors);
+  return((GhostscriptVectors*) NULL);
 }
 
 /*
@@ -1271,8 +1346,8 @@ MagickExport const GhostscriptVectors *NTGhostscriptDLLVectors(void)
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  NTGhostscriptEXE() obtains the path to the latest Ghostscript executable.
-%  The method returns False if a value is not obtained.
+%   Method NTGhostscriptEXE obtains the path to the latest Ghostscript
+%   executable.  The method returns False if a value is not obtained.
 %
 %  The format of the NTGhostscriptEXE method is:
 %
@@ -1284,9 +1359,8 @@ MagickExport const GhostscriptVectors *NTGhostscriptDLLVectors(void)
 %
 %    o path_length: Length of buffer
 %
-%
 */
-MagickExport int NTGhostscriptEXE(char *path,int path_length)
+MagickExport int NTGhostscriptEXE(char *path, int path_length)
 {
   int
     gsver;
@@ -1326,8 +1400,8 @@ MagickExport int NTGhostscriptEXE(char *path,int path_length)
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  NTGhostscriptFonts() obtains the path to the Ghostscript fonts.  The
-%  method returns False if a value is not obtained.
+%   Method NTGhostscriptFonts obtains the path to the Ghostscript fonts.
+%   The method returns False if a value is not obtained.
 %
 %  The format of the NTGhostscriptFonts method is:
 %
@@ -1339,9 +1413,8 @@ MagickExport int NTGhostscriptEXE(char *path,int path_length)
 %
 %    o path_length: Length of buffer
 %
-%
 */
-MagickExport int NTGhostscriptFonts(char *path,int path_length)
+MagickExport int NTGhostscriptFonts(char *path, int path_length)
 {
   int
     gsver;
@@ -1379,8 +1452,8 @@ MagickExport int NTGhostscriptFonts(char *path,int path_length)
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  NTGhostscriptLoadDLL() attempts to load the Ghostscript DLL and returns
-%  True if it succeeds.
+%   Method NTGhostscriptLoadDLL attempts to load the Ghostscript DLL
+%   and returns True if it succeeds.
 %
 %  The format of the NTGhostscriptLoadDLL method is:
 %
@@ -1396,21 +1469,26 @@ MagickExport int NTGhostscriptLoadDLL(void)
   if (gs_dll_handle != (void *) NULL)
     return True;
 
-  if (!NTGhostscriptDLL(dll_path,sizeof(dll_path)))
+  if(!NTGhostscriptDLL(dll_path,sizeof(dll_path)))
     return False;
 
   gs_dll_handle = lt_dlopen(dll_path);
   if (gs_dll_handle == (void *) NULL)
     return False;
 
-  memset((void*)&gs_vectors, 0, sizeof(GhostscriptVectors));
-
-  gs_vectors.exit=lt_dlsym(gs_dll_handle,"gsapi_exit");
-  gs_vectors.init_with_args=lt_dlsym(gs_dll_handle,"gsapi_init_with_args");
-  gs_vectors.new_instance=lt_dlsym(gs_dll_handle,"gsapi_new_instance");
-  gs_vectors.run_string=lt_dlsym(gs_dll_handle,"gsapi_run_string");
-  gs_vectors.delete_instance=lt_dlsym(gs_dll_handle,"gsapi_delete_instance");
-
+  memset((void *) &gs_vectors,0,sizeof(GhostscriptVectors));
+  gs_vectors.exit=(int (MagickDLLCall *)
+    (gs_main_instance*))lt_dlsym(gs_dll_handle,"gsapi_exit");
+  gs_vectors.init_with_args=(int (MagickDLLCall *)
+    (gs_main_instance *,int,char **))
+    (lt_dlsym(gs_dll_handle,"gsapi_init_with_args"));
+  gs_vectors.new_instance=(int (MagickDLLCall *) (gs_main_instance **,void *))
+    (lt_dlsym(gs_dll_handle,"gsapi_new_instance"));
+  gs_vectors.run_string=(int (MagickDLLCall *)
+    (gs_main_instance *,const char *,int,int *))
+    (lt_dlsym(gs_dll_handle,"gsapi_run_string"));
+  gs_vectors.delete_instance=(void (MagickDLLCall *) (gs_main_instance *))
+    (lt_dlsym(gs_dll_handle,"gsapi_delete_instance"));
   if ((gs_vectors.exit==NULL) ||
       (gs_vectors.init_with_args==NULL) ||
       (gs_vectors.new_instance==NULL) ||
@@ -1432,13 +1510,13 @@ MagickExport int NTGhostscriptLoadDLL(void)
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  NTGhostscriptUnLoadDLL() unloads the Ghostscript DLL if it is loaded.
+%   Method NTGhostscriptUnLoadDLL unloads the Ghostscript DLL if it is loaded.
 %
 %  The format of the NTGhostscriptUnLoadDLL method is:
 %
 %      int NTGhostscriptUnLoadDLL(void)
 %
-%
+%%
 */
 MagickExport int NTGhostscriptUnLoadDLL(void)
 {
@@ -1464,80 +1542,77 @@ MagickExport int NTGhostscriptUnLoadDLL(void)
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  NTRegistryKeyLookup() returns ImageMagick installation path settings stored
-%  in the Windows Registry. Path settings are specific to the installed
-%  ImageMagick version so that multiple ImageMagick installations may coexist.
+%  NTRegistryKeyLookup() returns ImageMagick installation path settings
+%  stored in the Windows Registry.  Path settings are specific to the
+%  installed ImageMagick version so that multiple Image Magick installations
+%  may coexist.
 %
-%  Values are stored in the registry under a path path similar to
-%  "HKEY_LOCAL_MACHINE/SOFTWARE/ImageMagick/5.5.5/LibPath".
+%  Values are stored in the registry under a base path path similar to
+%  "HKEY_LOCAL_MACHINE/SOFTWARE\ImageMagick\5.5.7\Q:16". The provided subkey
+%  is appended to this base path to form the full key.
 %
 %  The format of the NTRegistryKeyLookup method is:
 %
-%      char *NTRegistryKeyLookup(const char *key)
+%      char *NTRegistryKeyLookup(const char *subkey)
 %
 %  A description of each parameter follows:
 %
-%    o key: Specifies a string that identifies the registry object.
-%           Currently supported keys include: "ApplicationDefaultsPath",
-%           "BinPath", "LibPath", "ModulesPath", and "SharePath".
-%
+%    o subkey: Specifies a string that identifies the registry object.
+%      Currently supported sub-keys include: "BinPath", "ConfigurePath",
+%      "LibPath", "CoderModulesPath", "FilterModulesPath", "SharePath".
 %
 */
-MagickExport char *NTRegistryKeyLookup(const char *key)
+MagickExport char *NTRegistryKeyLookup(const char *subkey)
 {
-  static HKEY
-    reg_key = (HKEY) INVALID_HANDLE_VALUE;
-
   char
-    *dst;
-
+    *value;
+    
   DWORD
     size,
     type;
 
   LONG
-    res;
+    status;
+    
+  static HKEY
+    registry_key = (HKEY) INVALID_HANDLE_VALUE;
 
-  /* Can probably append MagickLibVersionText to string for efficiency */
-  if (reg_key == (HKEY) INVALID_HANDLE_VALUE) {
-    res = RegOpenKeyExA (HKEY_LOCAL_MACHINE, "SOFTWARE\\ImageMagick", 0, KEY_READ, &reg_key);
+  if (registry_key == (HKEY) INVALID_HANDLE_VALUE)
+    {
+      char
+        package_key[MaxTextExtent];
 
-    if (res == ERROR_SUCCESS)
-      res = RegOpenKeyExA (reg_key, MagickLibVersionText, 0, KEY_READ, &reg_key);
-
-    if (res == ERROR_SUCCESS)
-      {
-#if QuantumDepth == 8
-        res = RegOpenKeyExA (reg_key, "Q8", 0, KEY_READ, &reg_key);
-#elif QuantumDepth == 16
-        res = RegOpenKeyExA (reg_key, "Q16", 0, KEY_READ, &reg_key);
-#elif QuantumDepth == 32
-        res = RegOpenKeyExA (reg_key, "Q32", 0, KEY_READ, &reg_key);
-#else
-# error "Specified value of QuantumDepth is not supported"
-#endif
-      }
-
-    if (res != ERROR_SUCCESS) {
-      reg_key = (HKEY) INVALID_HANDLE_VALUE;
-      return 0;
+      /*
+        Look-up base key.
+      */
+      FormatString(package_key,"SOFTWARE\\%s\\%s\\Q:%d",MagickPackageName,
+        MagickLibVersionText,QuantumDepth);
+      status=RegOpenKeyExA(HKEY_LOCAL_MACHINE,package_key,0,KEY_READ,
+        &registry_key);
+      if (status != ERROR_SUCCESS)
+        {
+          registry_key=(HKEY) INVALID_HANDLE_VALUE;
+          return(0);
+        }
     }
-  }
-
-  size = 32;
-  dst = (char *) AcquireMemory(size);
-
-  res = RegQueryValueExA (reg_key, key, 0, &type, dst, &size);
-  if (res == ERROR_MORE_DATA && type == REG_SZ) {
-    ReacquireMemory((void**) &dst,size);
-    res = RegQueryValueExA (reg_key, key, 0, &type, dst, &size);
-  }
-
-  if (type != REG_SZ || res != ERROR_SUCCESS) {
-    LiberateMemory((void**) &dst);
-  }
-
-  return dst;
+  /*
+    Look-up sub key.
+  */
+  size=32;
+  value=(char *) AcquireMemory(size);
+  if (value == (char *) NULL)
+    return((char *) NULL);
+  status=RegQueryValueExA(registry_key,subkey,0,&type,value,&size);
+  if ((status == ERROR_MORE_DATA) && (type == REG_SZ))
+    {
+      ReacquireMemory((void **) &value,size);
+      if (value == (char *) NULL)
+        return((char *) NULL);
+      status=RegQueryValueExA(registry_key,subkey,0,&type,value,&size);
+    }
+  if ((type != REG_SZ) || (status != ERROR_SUCCESS))
+    LiberateMemory((void**) &value);
+  return(value);
 }
 
 /*
@@ -1553,10 +1628,10 @@ MagickExport char *NTRegistryKeyLookup(const char *key)
 %
 %  NTResourceToBlob() returns a blob containing the contents of the resource
 %  in the current executable specified by the id parameter. This is currently
-%  used to retrieve MGK files tha have been embedded into the various
-%  command line utilities.
+%  used to retrieve MGK files tha have been embedded into the various command
+%  line utilities.
 %
-%  The format of the telldir method is:
+%  The format of the NTResourceToBlob method is:
 %
 %      unsigned char *NTResourceToBlob(const char *id)
 %
@@ -1631,8 +1706,8 @@ MagickExport unsigned char *NTResourceToBlob(const char *id)
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  NTSystemComman() executes the specified command and waits until it
-%  terminates.  The returned value is the exit status of the command.
+%   Method NTSystemComman executes the specified command and waits until it
+%   terminates.  The returned value is the exit status of the command.
 %
 %  The format of the NTSystemComman method is:
 %
@@ -1707,7 +1782,7 @@ MagickExport int NTSystemComman(const char *command)
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  NTUserTime() returns the total time the process has been scheduled (i
+%  Method NTUserTime returns the total time the process has been scheduled (i
 %  seconds) since the last call to StartTimer().
 %
 %  The format of the UserTime method is:
@@ -1768,7 +1843,7 @@ MagickExport double NTUserTime(void)
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  NTWarningHandler() displays a warning reason.
+%  Method NTWarningHandler displays a warning reason.
 %
 %  The format of the NTWarningHandler method is:
 %
@@ -1815,8 +1890,8 @@ MagickExport void NTWarningHandler(const ExceptionType warning,
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  opendir() opens the directory named by filename and associates a directory
-%  stream with it.
+%  Method opendir opens the directory named by filename and associates
+%  a directory stream with it.
 %
 %  The format of the opendir method is:
 %
@@ -1869,8 +1944,9 @@ MagickExport DIR *opendir(char *path)
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  readdir() returns a pointer to a structure representing the directory entry
-%  at the current position in the directory stream to which entry refers.
+%  Method readdir returns a pointer to a structure representing the
+%  directory entry at the current position in the directory stream to
+%  which entry refers.
 %
 %  The format of the readdir
 %
@@ -1913,8 +1989,8 @@ MagickExport struct dirent *readdir(DIR *entry)
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  seekdir() sets the position of the next readdir() operation on the
-%  directory stream.
+%   Method seekdir sets the position of the next readdir() operation
+%   on the directory stream.
 %
 %  The format of the seekdir method is:
 %
@@ -1990,6 +2066,7 @@ MagickExport long sysconf(int name)
   }
   return(0);
 }
+
 
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -2002,7 +2079,7 @@ MagickExport long sysconf(int name)
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  telldir() returns the current location associated with the named directory
+%  telldir() returns the current location associated  with  the named directory
 %  stream.
 %
 %  The format of the telldir method is:
