@@ -8,7 +8,7 @@
 extern "C" {
 #endif
 
-#include "delegate.h"
+#include "magick/delegate.h"
 
 #define WIN32_LEAN_AND_MEAN
 #define VC_EXTRALEAN
@@ -36,9 +36,20 @@ extern "C" {
 #define RW_OK 6
 #define _SC_PAGE_SIZE 1
 #define _SC_PHYS_PAGES 2
-#if !defined(HasLTDL)
-#  define lt_dlerror NTGetLastError
+
+#if !defined(chsize)
+# if defined(__BORLANDC__)
+#   define chsize(file,length) chsize(file,length)
+# else
+#   define chsize(file,length) _chsize(file,length)
+# endif
 #endif
+
+#if !defined(tempnam)
+# define tempnam _tempnam
+#endif
+#define vsnprintf _vsnprintf
+
 #if defined(_MT) && defined(WIN32)
 #define SAFE_GLOBAL __declspec(thread)
 #else
@@ -78,23 +89,9 @@ typedef struct _DIR
 
 #endif
 
-
-/*
-  NT utilities routines.
-*/
 extern MagickExport char
   *NTGetLastError(void);
 
-extern MagickExport int
-  Exit(int),
-  IsWindows95(),
-  NTGhostscriptDLL(char *path, int path_length),
-  NTGhostscriptEXE(char *path, int path_length),
-  NTGhostscriptFonts(char *path, int path_length),
-  NTGhostscriptLoadDLL(void),
-  NTGhostscriptUnLoadDLL(void),
-  NTSystemComman(const char *);
-
 extern MagickExport const GhostscriptVectors
   *NTGhostscriptDLLVectors( void );
 
@@ -107,11 +104,22 @@ extern MagickExport double
   NTUserTime(void);
 
 extern MagickExport int
+  Exit(int),
+  ftruncate(int,ExtendedSignedIntegralType),
+  IsWindows95(),
 #if !defined(HasLTDL)
+  lt_dlclose(void *),
   lt_dlexit(void),
   lt_dlinit(void),
+  lt_dlsetsearchpath(const char *),
 #endif /* !HasLTDL */
-  munmap(void *,size_t);
+  munmap(void *,size_t),
+  NTGhostscriptDLL(char *path, int path_length),
+  NTGhostscriptEXE(char *path, int path_length),
+  NTGhostscriptFonts(char *path, int path_length),
+  NTGhostscriptLoadDLL(void),
+  NTGhostscriptUnLoadDLL(void),
+  NTSystemComman(const char *);
 
 extern MagickExport long
   sysconf(int),
@@ -120,6 +128,11 @@ extern MagickExport long
 extern MagickExport struct dirent
   *readdir(DIR *);
 
+#if !defined(HasLTDL)
+extern MagickExport const char
+  *lt_dlerror(void);
+#endif
+
 extern MagickExport unsigned char
   *NTResourceToBlob(const char *);
 
@@ -133,18 +146,14 @@ extern MagickExport void
   DebugLevel(const int),
   DestroyTracingCriticalSection(void),
   InitializeTracingCriticalSection(void),
+#if !defined(HasLTDL)
+  *lt_dlopen(const char *),
+  *lt_dlsym(void *,const char *),
+#endif
   *mmap(char *,size_t,int,int,int,off_t),
   NTErrorHandler(const ExceptionType,const char *,const char *),
   NTWarningHandler(const ExceptionType,const char *,const char *),
-  seekdir(DIR *,long)
-#if !defined(HasLTDL)
-  ,
-  lt_dlsetsearchpath(char *),
-  *lt_dlopen(char *),
-  lt_dlclose(void *),
-  *lt_dlsym(void *, char *)
-#endif /* !HasLTDL */
-  ;
+  seekdir(DIR *,long);
 
 #endif /* !XS_VERSION */
 
