@@ -8,7 +8,7 @@
 extern "C" {
 #endif
 
-#include "render.h"
+#include "magick/render.h"
 
 /*
   NT features routines.
@@ -17,6 +17,7 @@ extern MagickExport char
   *NTRegistryKeyLookup(const char *key);
 
 extern MagickExport void
+  *CropImageToHBITMAP(Image *,const RectangleInfo *,ExceptionInfo *),
   *ImageToHBITMAP(Image* image);
 
 #if !defined(XS_VERSION)
