@@ -716,7 +716,7 @@ MagickExport unsigned int TransparentImage(Image *image,
     q=GetImagePixels(image,0,y,image->columns,1);
     if (q == (PixelPacket *) NULL)
       break;
-    for (x=(long) image->columns; x > 0; x--)
+    for (x=(long) image->columns-1; x >= 0; x--)
     {
       if (FuzzyColorCompare(image,q,&target))
         q->opacity=opacity;
