@@ -188,10 +188,11 @@
 /*
   Include declarations.
 */
-#include "studio.h"
-#include "quantize.h"
-#include "monitor.h"
-#include "utility.h"
+#include "magick/studio.h"
+#include "magick/error.h"
+#include "magick/quantize.h"
+#include "magick/monitor.h"
+#include "magick/utility.h"
 
 /*
   Define declarations.
@@ -212,7 +213,7 @@ typedef struct _NodeInfo
   double
     number_unique;
 
-  long double
+  ExtendedRationalType
     total_red,
     total_green,
     total_blue,
@@ -230,7 +231,7 @@ typedef struct _NodeInfo
 typedef struct _Nodes
 {
   NodeInfo
-    nodes[NodesInAList];
+    *nodes;
 
   struct _Nodes
     *next;
@@ -247,7 +248,7 @@ typedef struct _CubeInfo
   DoublePixelPacket
     color;
 
-  long double
+  ExtendedRationalType
     distance,
     pruning_threshold,
     next_threshold;
@@ -343,6 +344,19 @@ static void
 %
 %
 */
+
+static inline unsigned long ColorToNodeId(Quantum red,Quantum green,
+  Quantum blue,IndexPacket index)
+{
+  unsigned long
+    id;
+
+  id=(unsigned long) (((ScaleQuantumToChar(red) >> index) & 0x01) << 2 | 
+    ((ScaleQuantumToChar(green) >> index) & 0x01) << 1 | 
+    ((ScaleQuantumToChar(blue) >> index) & 0x01));
+  return(id);
+}
+
 static unsigned int AssignImageColors(CubeInfo *cube_info,Image *image)
 {
 #define AssignImageTag  "Assign/Image"
@@ -405,10 +419,7 @@ static unsigned int AssignImageColors(CubeInfo *cube_info,Image *image)
         node_info=cube_info->root;
         for (index=MaxTreeDepth-1; (long) index > 0; index--)
         {
-          id=(unsigned long)
-            (((ScaleQuantumToChar(q->red) >> index) & 0x01) << 2 |
-             ((ScaleQuantumToChar(q->green) >> index) & 0x01) << 1 |
-             ((ScaleQuantumToChar(q->blue) >> index) & 0x01));
+          id=ColorToNodeId(q->red,q->green,q->blue,index);
           if ((node_info->census & (1 << id)) == 0)
             break;
           node_info=node_info->child[id];
@@ -450,13 +461,15 @@ static unsigned int AssignImageColors(CubeInfo *cube_info,Image *image)
       /*
         Monochrome image.
       */
+      q=image->colormap;
       for (i=0; i < (long) image->colors; i++)
       {
-        intensity=(Quantum) (PixelIntensityToQuantum(&image->colormap[i]) <
-          (MaxRGB/2) ? 0 : MaxRGB);
-        image->colormap[i].red=intensity;
-        image->colormap[i].green=intensity;
-        image->colormap[i].blue=intensity;
+        intensity=(Quantum)
+          (PixelIntensityToQuantum(q) < (MaxRGB/2) ? 0 : MaxRGB);
+        q->red=intensity;
+        q->green=intensity;
+        q->blue=intensity;
+        q++;
       }
     }
   if (cube_info->quantize_info->measure_error)
@@ -591,10 +604,7 @@ static unsigned int ClassifyImageColors(CubeInfo *cube_info,const Image *image,
       for (level=1; level <= 8; level++)
       {
         bisect*=0.5;
-        id=(unsigned long)
-          (((ScaleQuantumToChar(p->red) >> index) & 0x01) << 2 |
-           ((ScaleQuantumToChar(p->green) >> index) & 0x01) << 1 |
-           ((ScaleQuantumToChar(p->blue) >> index) & 0x01));
+        id=ColorToNodeId(p->red,p->green,p->blue,index);
         mid.red+=id & 4 ? bisect : -bisect;
         mid.green+=id & 2 ? bisect : -bisect;
         mid.blue+=id & 1 ? bisect : -bisect;
@@ -606,7 +616,7 @@ static unsigned int ClassifyImageColors(CubeInfo *cube_info,const Image *image,
             node_info->census|=(1 << id);
             node_info->child[id]=GetNodeInfo(cube_info,id,level,node_info);
             if (node_info->child[id] == (NodeInfo *) NULL)
-              ThrowException(exception,ResourceLimitError,
+              (void) ThrowException(exception,ResourceLimitError,
                 "MemoryAllocationFailed","UnableToQuantizeImage");
             if (level == 8)
               cube_info->colors++;
@@ -672,10 +682,7 @@ static unsigned int ClassifyImageColors(CubeInfo *cube_info,const Image *image,
       for (level=1; level <= cube_info->depth; level++)
       {
         bisect*=0.5;
-        id=(unsigned long)
-          (((ScaleQuantumToChar(p->red) >> index) & 0x01) << 2 |
-           ((ScaleQuantumToChar(p->green) >> index) & 0x01) << 1 |
-           ((ScaleQuantumToChar(p->blue) >> index) & 0x01));
+        id=ColorToNodeId(p->red,p->green,p->blue,index);
         mid.red+=id & 4 ? bisect : -bisect;
         mid.green+=id & 2 ? bisect : -bisect;
         mid.blue+=id & 1 ? bisect : -bisect;
@@ -687,7 +694,7 @@ static unsigned int ClassifyImageColors(CubeInfo *cube_info,const Image *image,
             node_info->census|=(1 << id);
             node_info->child[id]=GetNodeInfo(cube_info,id,level,node_info);
             if (node_info->child[id] == (NodeInfo *) NULL)
-              ThrowException(exception,ResourceLimitError,
+              (void) ThrowException(exception,ResourceLimitError,
                 "MemoryAllocationFailed","UnableToQuantizeImage");
             if (level == cube_info->depth)
               cube_info->colors++;
@@ -977,6 +984,7 @@ static void DestroyCubeInfo(CubeInfo *cube_info)
   do
   {
     nodes=cube_info->node_queue->next;
+    LiberateMemory((void **) &cube_info->node_queue->nodes);
     LiberateMemory((void **) &cube_info->node_queue);
     cube_info->node_queue=nodes;
   } while (cube_info->node_queue != (Nodes *) NULL);
@@ -1114,10 +1122,7 @@ static unsigned int Dither(CubeInfo *cube_info,Image *image,
           node_info=p->root;
           for (index=MaxTreeDepth-1; (long) index > 0; index--)
           {
-            id=(unsigned long)
-              (((ScaleQuantumToChar(pixel.red) >> index) & 0x01) << 2 |
-               ((ScaleQuantumToChar(pixel.green) >> index) & 0x01) << 1 |
-               ((ScaleQuantumToChar(pixel.blue) >> index) & 0x01));
+            id=ColorToNodeId(pixel.red,pixel.green,pixel.blue,index);
             if ((node_info->census & (1 << id)) == 0)
               break;
             node_info=node_info->child[id];
@@ -1378,6 +1383,9 @@ static NodeInfo *GetNodeInfo(CubeInfo *cube_info,const unsigned int id,
       nodes=(Nodes *) AcquireMemory(sizeof(Nodes));
       if (nodes == (Nodes *) NULL)
         return((NodeInfo *) NULL);
+      nodes->nodes=(NodeInfo *) AcquireMemory(NodesInAList*sizeof(NodeInfo));
+      if (nodes->nodes == (NodeInfo *) NULL)
+        return((NodeInfo *) NULL);
       nodes->next=cube_info->node_queue;
       cube_info->node_queue=nodes;
       cube_info->next_node=nodes->nodes;
@@ -1440,7 +1448,9 @@ MagickExport unsigned int GetImageQuantizeError(Image *image)
   double
     distance,
     maximum_error_per_pixel,
-    normalize;
+    mean_error_per_pixel,
+    normalize,
+    number_pixels;
 
   DoublePixelPacket
     pixel;
@@ -1451,9 +1461,6 @@ MagickExport unsigned int GetImageQuantizeError(Image *image)
   long
     y;
 
-  long double
-    total_error;
-
   register const PixelPacket
     *p;
 
@@ -1475,8 +1482,9 @@ MagickExport unsigned int GetImageQuantizeError(Image *image)
   /*
     For each pixel, collect error statistics.
   */
+  number_pixels=(double) image->columns*image->rows;
   maximum_error_per_pixel=0;
-  total_error=0;
+  mean_error_per_pixel=0;
   for (y=0; y < (long) image->rows; y++)
   {
     p=AcquireImagePixels(image,0,y,image->columns,1,&image->exception);
@@ -1491,7 +1499,7 @@ MagickExport unsigned int GetImageQuantizeError(Image *image)
       pixel.blue=p->blue-(double) image->colormap[index].blue;
       distance=pixel.red*pixel.red+pixel.green*pixel.green+
         pixel.blue*pixel.blue;
-      total_error+=distance;
+      mean_error_per_pixel+=distance/number_pixels;
       if (distance > maximum_error_per_pixel)
         maximum_error_per_pixel=distance;
       p++;
@@ -1501,9 +1509,8 @@ MagickExport unsigned int GetImageQuantizeError(Image *image)
     Compute final error statistics.
   */
   normalize=3.0*((double) MaxRGB+1.0)*((double) MaxRGB+1.0);
-  image->error.mean_error_per_pixel=total_error/image->columns/image->rows;
-  image->error.normalized_mean_error=
-    image->error.mean_error_per_pixel/normalize;
+  image->error.mean_error_per_pixel=mean_error_per_pixel;
+  image->error.normalized_mean_error=mean_error_per_pixel/normalize;
   image->error.normalized_maximum_error=maximum_error_per_pixel/normalize;
   return(True);
 }
@@ -1688,7 +1695,7 @@ static void HilbertCurve(CubeInfo *cube_info,Image *image,
 %
 %    o image: Specifies a pointer to an Image structure.
 %
-%    o map_image: Specifies a pointer to a Image structure.  Reduce
+%    o map_image: The image.  Reduce
 %      image to a set of colors represented by this image.
 %
 %    o dither: Set this integer value to something other than zero to
@@ -1759,7 +1766,7 @@ MagickExport unsigned int MapImage(Image *image,const Image *map_image,
 %
 %    o image: Specifies a pointer to a set of Image structures.
 %
-%    o map_image: Specifies a pointer to a Image structure.  Reduce
+%    o map_image: The image.  Reduce
 %      image to a set of colors represented by this image.
 %
 %    o dither: Set this integer value to something other than zero to
@@ -2081,7 +2088,7 @@ static void PruneToCubeDepth(CubeInfo *cube_info,const NodeInfo *node_info)
 %
 %    o quantize_info: Specifies a pointer to an QuantizeInfo structure.
 %
-%    o image: Specifies a pointer to a Image structure.
+%    o image: The image.
 %
 */
 MagickExport unsigned int QuantizeImage(const QuantizeInfo *quantize_info,
@@ -2106,6 +2113,10 @@ MagickExport unsigned int QuantizeImage(const QuantizeInfo *quantize_info,
     number_colors=MaxColormapSize;
   if (number_colors > MaxColormapSize)
     number_colors=MaxColormapSize;
+  if (quantize_info->colorspace != RGBColorspace)
+    (void) SetImageColorspace(image,quantize_info->colorspace);
+  if ((image->storage_class == PseudoClass) && (image->colors <= number_colors))
+    return(True);
   depth=quantize_info->tree_depth;
   if (depth == 0)
     {
@@ -2130,8 +2141,6 @@ MagickExport unsigned int QuantizeImage(const QuantizeInfo *quantize_info,
   if (cube_info == (CubeInfo *) NULL)
     ThrowBinaryException(ResourceLimitError,"MemoryAllocationFailed",
       "UnableToQuantizeImage");
-  if (quantize_info->colorspace != RGBColorspace)
-    (void) RGBTransformImage(image,quantize_info->colorspace);
   status=ClassifyImageColors(cube_info,image,&image->exception);
   if (status != False)
     {
@@ -2141,7 +2150,7 @@ MagickExport unsigned int QuantizeImage(const QuantizeInfo *quantize_info,
       ReduceImageColors(cube_info,number_colors,&image->exception);
       status=AssignImageColors(cube_info,image);
       if (quantize_info->colorspace != RGBColorspace)
-        (void) TransformRGBImage(image,quantize_info->colorspace);
+        (void) SetImageColorspace(image,quantize_info->colorspace);
     }
   DestroyCubeInfo(cube_info);
   return(status);
@@ -2254,7 +2263,7 @@ MagickExport unsigned int QuantizeImages(const QuantizeInfo *quantize_info,
   for (i=0; image != (Image *) NULL; i++)
   {
     if (quantize_info->colorspace != RGBColorspace)
-      (void) RGBTransformImage(image,quantize_info->colorspace);
+      (void) SetImageColorspace(image,quantize_info->colorspace);
     image=image->next;
   }
   number_images=i;
@@ -2284,7 +2293,7 @@ MagickExport unsigned int QuantizeImages(const QuantizeInfo *quantize_info,
         if (status == False)
           break;
         if (quantize_info->colorspace != RGBColorspace)
-          (void) TransformRGBImage(image,quantize_info->colorspace);
+          (void) SetImageColorspace(image,quantize_info->colorspace);
         image=image->next;
         (void) SetMonitorHandler(handler);
         if (!MagickMonitor(AssignImageTag,i,number_images,&image->exception))
