@@ -13,32 +13,7 @@ extern "C" {
 */
 #define MaxTreeDepth  8
 #define NodesInAList  1536
-
-/*
-  Typedef declarations.
-*/
-typedef struct _QuantizeInfo
-{
-  unsigned long
-    number_colors;
 
-  unsigned int
-    tree_depth,
-    dither;
-
-  ColorspaceType
-    colorspace;
-
-  unsigned int
-    measure_error;
-
-  unsigned long
-    signature;
-} QuantizeInfo;
-
-/*
-  Quantization utilities methods.
-*/
 extern MagickExport DoublePixelPacket
   GetImageDynamicThreshold(const Image *,const double,const double,
     ExceptionInfo *);
