@@ -52,9 +52,12 @@
 /*
   Include declarations.
 */
-#include "studio.h"
-#include "signature.h"
-#include "utility.h"
+#include "magick/studio.h"
+#include "magick/error.h"
+#include "magick/semaphore.h"
+#include "magick/resource.h"
+#include "magick/signature.h"
+#include "magick/utility.h"
 
 /*
   Global declarations.
@@ -372,13 +375,14 @@ static void InitializeRandomReservoir(void)
   pid=getpid();
   DistillRandomEvent((const unsigned char *) &pid,sizeof(long));
   DistillRandomEvent((const unsigned char *) &roulette,sizeof(unsigned long *));
-  (void) strcpy(filename,"magic");
-  (void) tmpnam(filename);
+  (void) AcquireUniqueFilename(filename);
   DistillRandomEvent((const unsigned char *) filename,MaxTextExtent);
+  (void) LiberateUniqueFileResource(filename);
   file=open("/dev/random",O_RDONLY | O_BINARY);
-  if (file == -1)
-    return;
-  (void) read(file,random,MaxTextExtent);
-  (void) close(file);
-  DistillRandomEvent(random,MaxTextExtent);
+  if (file != -1)
+    {
+      (void) read(file,random,MaxTextExtent);
+      (void) close(file);
+      DistillRandomEvent(random,MaxTextExtent);
+    }
 }
