@@ -52,10 +52,12 @@
 /*
   Include declarations.
 */
-#include "studio.h"
-#include "list.h"
-#include "registry.h"
-#include "utility.h"
+#include "magick/studio.h"
+#include "magick/error.h"
+#include "magick/list.h"
+#include "magick/registry.h"
+#include "magick/semaphore.h"
+#include "magick/utility.h"
 
 /*
   Global declarations.
@@ -250,7 +252,7 @@ MagickExport Image *GetImageFromMagickRegistry(const char *name,long *id,
   }
   LiberateSemaphoreInfo(&registry_semaphore);
   if (image == (Image *) NULL)
-    ThrowException(exception,RegistryError,"UnableToLocateImage",name);
+    (void) ThrowException(exception,RegistryError,"UnableToLocateImage",name);
   return(image);
 }
 
@@ -331,7 +333,7 @@ MagickExport void *GetMagickRegistry(const long id,RegistryType *type,
         blob=(void *) AcquireMemory(registry_info->length);
         if (blob == (void *) NULL)
           {
-            ThrowException(exception,ResourceLimitError,
+            (void) ThrowException(exception,ResourceLimitError,
               "MemoryAllocationFailed","UnableToGetFromRegistry");
             break;
           }
@@ -350,7 +352,7 @@ MagickExport void *GetMagickRegistry(const long id,RegistryType *type,
         description[MaxTextExtent];
 
       FormatString(description,"id=%ld",id);
-      ThrowException(exception,RegistryError,"UnableToLocateRegistryID",
+      (void) ThrowException(exception,RegistryError,"UnableToLocateRegistryID",
         description);
     }
   return(blob);
@@ -407,13 +409,13 @@ MagickExport long SetMagickRegistry(const RegistryType type,const void *blob,
       image=(Image *) blob;
       if (length != sizeof(Image))
         {
-          ThrowException(exception,RegistryError,"UnableToSetRegistry",
+          (void) ThrowException(exception,RegistryError,"UnableToSetRegistry",
             "StructureSizeMismatch");
           return(-1);
         }
       if (image->signature != MagickSignature)
         {
-          ThrowException(exception,RegistryError,"UnableToSetRegistry",
+          (void) ThrowException(exception,RegistryError,"UnableToSetRegistry",
             "ImageExpected");
           return(-1);
         }
@@ -430,13 +432,13 @@ MagickExport long SetMagickRegistry(const RegistryType type,const void *blob,
       image_info=(ImageInfo *) blob;
       if (length != sizeof(ImageInfo))
         {
-          ThrowException(exception,RegistryError,"UnableToSetRegistry",
+          (void) ThrowException(exception,RegistryError,"UnableToSetRegistry",
             "StructureSizeMismatch");
           return(-1);
         }
       if (image_info->signature != MagickSignature)
         {
-          ThrowException(exception,RegistryError,"UnableToSetRegistry",
+          (void) ThrowException(exception,RegistryError,"UnableToSetRegistry",
             "ImageInfoExpected");
           return(-1);
         }
