@@ -23,8 +23,12 @@ typedef enum
 /*
   Method declarations.
 */
+extern MagickExport int
+  AcquireUniqueFileResource(char *);
+
 extern MagickExport unsigned int
   AcquireMagickResource(const ResourceType,const ExtendedSignedIntegralType),
+  LiberateUniqueFileResource(const char *),
   ListMagickResourceInfo(FILE *file,ExceptionInfo *exception);
 
 extern MagickExport unsigned long
