@@ -95,15 +95,24 @@
 %
 */
 
-#include "studio.h"
-#include "monitor.h"
-#include "quantize.h"
-#include "utility.h"
+#include "magick/studio.h"
+#include "magick/error.h"
+#include "magick/monitor.h"
+#include "magick/quantize.h"
+#include "magick/utility.h"
 
 /*
   Define declarations.
 */
 #define  MaxDimension  3
+#define  FastClassify  1
+#if defined(FastClassify)
+#define WeightingExponent  2.0
+#define SegmentPower(ratio) (ratio)
+#else
+#define WeightingExponent  2.5
+#define SegmentPower(ratio) pow(ratio,(double) (1.0/(weighting_exponent-1.0)));
+#endif
 
 /*
   Typedef declarations.
@@ -542,7 +551,7 @@ static unsigned int Classify(Image *image,short **extrema,
               (long) ScaleQuantumToChar(p->green)]+
               squares[ScaleQuantumToChar(q->blue)-
               (long) ScaleQuantumToChar(p->blue)];
-            numerator=sqrt(distance_squared);
+            numerator=distance_squared;
             for (k=0; k < (long) image->colors; k++)
             {
               p=image->colormap+k;
@@ -552,8 +561,8 @@ static unsigned int Classify(Image *image,short **extrema,
                 (long) ScaleQuantumToChar(p->green)]+
                 squares[ScaleQuantumToChar(q->blue)-
                 (long) ScaleQuantumToChar(p->blue)];
-              ratio=numerator/sqrt(distance_squared);
-              sum+=pow(ratio,(double) (2.0/(weighting_exponent-1.0)));
+              ratio=numerator/distance_squared;
+              sum+=SegmentPower(ratio);
             }
             if (sum && ((1.0/sum) > local_minima))
               {
@@ -854,7 +863,6 @@ MagickExport DoublePixelPacket GetImageDynamicThreshold(const Image *image,
 {
 #define DeltaTau  0.5
 #define Tau  5.2
-#define WeightingExponent  2.0
 
   Cluster
     *background,
@@ -907,7 +915,7 @@ MagickExport DoublePixelPacket GetImageDynamicThreshold(const Image *image,
           LiberateMemory((void **) &extrema[i]);
           LiberateMemory((void **) &histogram[i]);
         }
-        ThrowException(exception,ResourceLimitError,"MemoryAllocationFailed",
+        (void) ThrowException(exception,ResourceLimitError,"MemoryAllocationFailed",
           image->filename);
         return(pixel);
       }
@@ -951,7 +959,7 @@ MagickExport DoublePixelPacket GetImageDynamicThreshold(const Image *image,
           }
         if (cluster == (Cluster *) NULL)
           {
-            ThrowException(exception,ResourceLimitError,
+            (void) ThrowException(exception,ResourceLimitError,
               "MemoryAllocationFailed",image->filename);
             return(pixel);
           }
@@ -974,7 +982,7 @@ MagickExport DoublePixelPacket GetImageDynamicThreshold(const Image *image,
       cluster=(Cluster *) AcquireMemory(sizeof(Cluster));
       if (cluster == (Cluster *) NULL)
         {
-          ThrowException(exception,ResourceLimitError,"MemoryAllocationFailed",
+          (void) ThrowException(exception,ResourceLimitError,"MemoryAllocationFailed",
             image->filename);
           return(pixel);
         }
@@ -1681,7 +1689,6 @@ MagickExport unsigned int SegmentImage(Image *image,
 {
 #define DeltaTau  0.5
 #define Tau  5.2
-#define WeightingExponent  2.0
 
   long
     *histogram[MaxDimension];
@@ -1716,7 +1723,7 @@ MagickExport unsigned int SegmentImage(Image *image,
       }
   }
   if (colorspace != RGBColorspace)
-    (void) RGBTransformImage(image,colorspace);
+    (void) SetImageColorspace(image,colorspace);
   /*
     Initialize histogram.
   */
@@ -1732,7 +1739,7 @@ MagickExport unsigned int SegmentImage(Image *image,
   */
   status=Classify(image,extrema,cluster_threshold,WeightingExponent,verbose);
   if (colorspace != RGBColorspace)
-    (void) TransformRGBImage(image,colorspace);
+    (void) SetImageColorspace(image,colorspace);
   /*
     Free memory.
   */
