@@ -52,22 +52,29 @@
 /*
   Include declarations.
 */
-#include "studio.h"
-#include "attribute.h"
-#include "signature.h"
-#include "utility.h"
+#include "magick/studio.h"
+#include "magick/error.h"
+#include "magick/attribute.h"
+#include "magick/signature.h"
+#include "magick/utility.h"
 
 /*
   Define declarations.
 */
 #define Trunc32(x)  ((x) & 0xffffffffUL)
 
+/*
+  Forward declarations.
+*/
+static void
+  TransformSignature(SignatureInfo *);
+
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %                                                                             %
 %                                                                             %
 %                                                                             %
-%   F i n a l i z e S i g n a t u r e                                         %
++   F i n a l i z e S i g n a t u r e                                         %
 %                                                                             %
 %                                                                             %
 %                                                                             %
@@ -97,6 +104,8 @@ MagickExport void FinalizeSignature(SignatureInfo *signature_info)
   /*
     Add padding and return the message digest.
   */
+  assert(signature_info != (SignatureInfo *) NULL);
+  assert(signature_info->signature == MagickSignature);
   low_order=signature_info->low_order;
   high_order=signature_info->high_order;
   count=(long) ((low_order >> 3) & 0x3f);
@@ -125,7 +134,7 @@ MagickExport void FinalizeSignature(SignatureInfo *signature_info)
 %                                                                             %
 %                                                                             %
 %                                                                             %
-%   G e t S i g n a t u r e I n f o                                           %
++   G e t S i g n a t u r e I n f o                                           %
 %                                                                             %
 %                                                                             %
 %                                                                             %
@@ -148,6 +157,7 @@ MagickExport void GetSignatureInfo(SignatureInfo *signature_info)
   unsigned long
     lsb_first;
 
+  assert(signature_info != (SignatureInfo *) NULL);
   (void) memset(signature_info,0,sizeof(SignatureInfo));
   signature_info->digest[0]=0x6a09e667UL;
   signature_info->digest[1]=0xbb67ae85UL;
@@ -159,6 +169,7 @@ MagickExport void GetSignatureInfo(SignatureInfo *signature_info)
   signature_info->digest[7]=0x5be0cd19UL;
   lsb_first=1;
   signature_info->lsb_first=(*(char *) &lsb_first);
+  signature_info->signature=MagickSignature;
 }
 
 /*
@@ -308,7 +319,7 @@ MagickExport unsigned int SignatureImage(Image *image)
 %                                                                             %
 %                                                                             %
 %                                                                             %
-%   T r a n s f o r m S i g n a t u r e                                       %
++   T r a n s f o r m S i g n a t u r e                                       %
 %                                                                             %
 %                                                                             %
 %                                                                             %
@@ -326,15 +337,15 @@ MagickExport unsigned int SignatureImage(Image *image)
 %
 %
 */
-MagickExport void TransformSignature(SignatureInfo *signature_info)
+static void TransformSignature(SignatureInfo *signature_info)
 {
 #define Ch(x,y,z)  (((x) & (y)) ^ (~(x) & (z)))
 #define Maj(x,y,z)  (((x) & (y)) ^ ((x) & (z)) ^ ((y) & (z)))
-#define Rot32(x,n)  Trunc32((((x) >> (n)) | ((x) << (32-(n)))))
-#define Sigma0(x)  (Rot32(x,7) ^ Rot32(x,18) ^ Trunc32((x) >> 3))
-#define Sigma1(x)  (Rot32(x,17) ^ Rot32(x,19) ^ Trunc32((x) >> 10))
-#define Suma0(x)  (Rot32(x,2) ^ Rot32(x,13) ^ Rot32(x,22))
-#define Suma1(x)  (Rot32(x,6) ^ Rot32(x,11) ^ Rot32(x,25))
+#define RotateRight(x,n)  Trunc32((((x) >> (n)) | ((x) << (32-(n)))))
+#define Sigma0(x)  (RotateRight(x,7) ^ RotateRight(x,18) ^ Trunc32((x) >> 3))
+#define Sigma1(x)  (RotateRight(x,17) ^ RotateRight(x,19) ^ Trunc32((x) >> 10))
+#define Suma0(x)  (RotateRight(x,2) ^ RotateRight(x,13) ^ RotateRight(x,22))
+#define Suma1(x)  (RotateRight(x,6) ^ RotateRight(x,11) ^ RotateRight(x,25))
 
   long
     j,
@@ -462,7 +473,7 @@ MagickExport void TransformSignature(SignatureInfo *signature_info)
 %                                                                             %
 %                                                                             %
 %                                                                             %
-%   U p d a t e S i g n a t u r e                                             %
++   U p d a t e S i g n a t u r e                                             %
 %                                                                             %
 %                                                                             %
 %                                                                             %
@@ -498,6 +509,8 @@ MagickExport void UpdateSignature(SignatureInfo *signature_info,
   /*
     Update the SHA digest.
   */
+  assert(signature_info != (SignatureInfo *) NULL);
+  assert(signature_info->signature == MagickSignature);
   n=length;
   count=Trunc32(signature_info->low_order+(n << 3));
   if (count < signature_info->low_order)
