@@ -31,6 +31,9 @@ typedef struct _SignatureInfo
 
   unsigned char
     message[SignatureSize];
+
+  unsigned long
+    signature;
 } SignatureInfo;
 
 /*
@@ -48,7 +51,6 @@ extern MagickExport void
   FinalizeSignature(SignatureInfo *),
   GetRandomKey(unsigned char *,const size_t),
   GetSignatureInfo(SignatureInfo *),
-  TransformSignature(SignatureInfo *),
   UpdateSignature(SignatureInfo *,const unsigned char *,const size_t);
 
 #if defined(__cplusplus) || defined(c_plusplus)
