@@ -8,7 +8,7 @@
 extern "C" {
 #endif
 
-#if !defined(HasMODULES)
+#if !defined(BuildMagickModules)
 extern ModuleExport void
   RegisterARTImage(void),
   RegisterAVIImage(void),
@@ -53,8 +53,7 @@ extern ModuleExport void
   RegisterJPEGImage(void),
   RegisterJP2Image(void),
   RegisterLABELImage(void),
-  RegisterLOCALEImage(void),
-  RegisterLOGOImage(void),
+  RegisterMAGICKImage(void),
   RegisterMAPImage(void),
   RegisterMATImage(void),
   RegisterMATTEImage(void),
@@ -74,6 +73,7 @@ extern ModuleExport void
   RegisterPBMImage(void),
   RegisterOTBImage(void),
   RegisterPALMImage(void),
+  RegisterPATTERNImage(void),
   RegisterPCDImage(void),
   RegisterPCDSImage(void),
   RegisterPCLImage(void),
@@ -180,7 +180,7 @@ extern ModuleExport void
   UnregisterJP2Image(void),
   UnregisterLABELImage(void),
   UnregisterLOCALEImage(void),
-  UnregisterLOGOImage(void),
+  UnregisterMAGICKImage(void),
   UnregisterMAPImage(void),
   UnregisterMATImage(void),
   UnregisterMATTEImage(void),
@@ -200,6 +200,7 @@ extern ModuleExport void
   UnregisterPBMImage(void),
   UnregisterOTBImage(void),
   UnregisterPALMImage(void),
+  UnregisterPATTERNImage(void),
   UnregisterPCDImage(void),
   UnregisterPCDSImage(void),
   UnregisterPCLImage(void),
@@ -262,10 +263,13 @@ extern ModuleExport void
   UnregisterXVImage(void),
   UnregisterXWDImage(void),
   UnregisterYUVImage(void);
-#endif /* !defined(HasMODULES) */
+
+extern unsigned int
+  AnalyzeImage(Image **,const int,char **);
+#endif
 
 #if defined(__cplusplus) || defined(c_plusplus)
 }
 #endif
 
-#endif /* _MAGICK_STATIC_H */
+#endif
