@@ -19,7 +19,7 @@ extern "C" {
 #define _GNU_SOURCE  1
 #define _ISOC99_SOURCE  1
 #define _POSIX_C_SOURCE  199506L
-#define _XOPEN_SOURCE  500 
+#define _XOPEN_SOURCE  500
 #define _LARGEFILE64_SOURCE  1
 
 #if !defined(_MAGICK_CONFIG_H)
@@ -161,6 +161,7 @@ extern "C" {
 # if !defined(S_ISREG)
 #  define S_ISREG(mode) (((mode) & S_IFMT) == S_IFREG)
 # endif
+# include "magick/info.h"
 # include "magick/image.h"
 # if !defined(WIN32)
 #  include <sys/time.h>
@@ -179,20 +180,29 @@ extern "C" {
 #  include <console.h>
 #  include <unix.h>
 # endif
-# include "image.h"
+# include "magick/info.h"
+# include "magick/image.h"
+#endif
+
+#if defined(S_IRUSR) && defined(S_IWUSR)
+# define S_MODE (S_IRUSR | S_IWUSR)
+#elif defined (WIN32)
+# define S_MODE (_S_IREAD | _S_IWRITE)
+#else
+# define S_MODE  0600
 #endif
 
 #if defined(WIN32)
-# include "nt_base.h"
+# include "magick/nt_base.h"
 #endif
 #if defined(WIN32) || defined(__CYGWIN__)
-# include "nt_feature.h"
+# include "magick/nt_feature.h"
 #endif
 #if defined(macintosh)
-# include "mac.h"
+# include "magick/mac.h"
 #endif
 #if defined(vms)
-# include "vms.h"
+# include "magick/vms.h"
 #endif
 #if defined(HAVE_MMAP) && !defined(WIN32)
 # include <sys/mman.h>
@@ -230,7 +240,8 @@ extern "C" {
 #  define Exit  exit
 #  define IsBasenameSeparator(c)  (((c) == ']') || ((c) == ':') || ((c) == '/'))
 #  define MagickLibPath  "sys$login:"
-#  define MagickModulesPath  "sys$login:"
+#  define MagickCoderModulesPath  "sys$login:"
+#  define MagickFilterModulesPath  "sys$login:"
 #  define MagickSharePath  "sys$login:"
 #  define PreferencesDefaults  "decw$user_defaults:"
 #  define ProcessPendingEvents(text)
@@ -245,7 +256,8 @@ extern "C" {
 #  define EditorOptions ""
 #  define IsBasenameSeparator(c)  ((c) == ':')
 #  define MagickLibPath  ""
-#  define MagickModulesPath  ""
+#  define MagickCoderModulesPath  ""
+#  define MagickFilterModulesPath  ""
 #  define MagickSharePath  ""
 #  define PreferencesDefaults  "~/."
 #  define ReadCommandlLine(argc,argv)  argc=ccommand(argv); puts(MagickVersion);
@@ -321,17 +333,26 @@ extern "C" {
 #define MAP_FAILED      ((void *) -1)
 #endif
 
-#if defined(HasLTDL) || defined(_MAGICKMOD_)
-#define HasMODULES
+#if defined(HasLTDL) || ( defined(WIN32) && defined(_DLL) )
+#  define SupportMagickModules
+#endif
+
+#if defined(_MAGICKMOD_)
+#  undef BuildMagickModules
+#  define BuildMagickModules
 #endif
 
 /*
   I/O defines.
 */
-#if defined(WIN32) && !defined(Windows95) && defined(_VISUALC_)
+#if defined(WIN32) && !defined(Windows95) && !defined(__BORLANDC__)
 #define MagickSeek(file,offset,whence)  _lseeki64(file,offset,whence)
+#define MagickTell(file)  _telli64(file)
+#define MagickOffset ExtendedSignedIntegralType
 #else
 #define MagickSeek(file,offset,whence)  lseek(file,offset,whence)
+#define MagickTell(file) tell(file)
+#define MagickOffset off_t
 #endif
 
 #if defined(__cplusplus) || defined(c_plusplus)
