@@ -13,6 +13,7 @@ extern "C" {
 */
 typedef enum
 {
+  MagickPath,
   RootPath,
   HeadPath,
   TailPath,
@@ -71,6 +72,7 @@ extern MagickExport unsigned char
   *Base64Decode(const char *, size_t *);
 
 extern MagickExport unsigned int
+  AcquireUniqueFilename(char *),
   CloneString(char **,const char *),
   ConcatenateString(char **,const char *),
   ExpandFilenames(int *,char ***),
@@ -93,8 +95,7 @@ extern MagickExport void
   LocaleLower(char *),
   LocaleUpper(char *),
   ReacquireMemory(void **,const size_t),
-  Strip(char *),
-  TemporaryFilename(char *);
+  Strip(char *);
 
 extern MagickExport void
 #if defined(__GNUC__)
