@@ -28,74 +28,75 @@
 #endif
 static void ScribbleImage ( Image *image)
 {
-  DrawContext
-    context;
+  DrawingWand
+    *draw_wand;
 
-  context = DrawAllocateContext((DrawInfo*)NULL, image);
+/* SetLogEventMask("Render"); */
+  draw_wand = DrawAllocateWand((DrawInfo*)NULL, image);
   
-  DrawPushGraphicContext(context);
+  DrawPushGraphicContext(draw_wand);
   {
-    DrawSetViewbox(context,0,0,image->columns,image->rows);
-    DrawScale(context,1.101,1.08);
-    DrawTranslate(context,-23.69,-22.97);
-    DrawRotate(context,0);
-    DrawSetFillColorString(context,"#ffffff");
-    DrawRectangle(context,23.69,22.97,564.6,802.2);
-    DrawSetFillOpacity(context,1.0);
-    DrawSetFillColorString(context,"none");
-    DrawSetStrokeColorString(context,"none");
+    DrawSetViewbox(draw_wand,0,0,image->columns,image->rows);
+    DrawScale(draw_wand,1.101,1.08);
+    DrawTranslate(draw_wand,-23.69,-22.97);
+    DrawRotate(draw_wand,0);
+    DrawSetFillColorString(draw_wand,"#ffffff");
+    DrawRectangle(draw_wand,23.69,22.97,564.6,802.2);
+    DrawSetFillOpacity(draw_wand,1.0);
+    DrawSetFillColorString(draw_wand,"none");
+    DrawSetStrokeColorString(draw_wand,"none");
 
-    DrawSetStrokeAntialias(context,True);
-    DrawSetStrokeLineCap(context,RoundCap);
-    DrawSetStrokeLineJoin(context,RoundJoin);
+    DrawSetStrokeAntialias(draw_wand,True);
+    DrawSetStrokeLineCap(draw_wand,RoundCap);
+    DrawSetStrokeLineJoin(draw_wand,RoundJoin);
 
-    DrawPushDefs(context);
+    DrawPushDefs(draw_wand);
     {
-      DrawPushClipPath(context,"clip_1");
+      DrawPushClipPath(draw_wand,"clip_1");
       {
-        DrawPushGraphicContext(context);
+        DrawPushGraphicContext(draw_wand);
         {
-          DrawRectangle(context,0,0,595.3,841.9);
+          DrawRectangle(draw_wand,0,0,595.3,841.9);
         }
-        DrawPopGraphicContext(context);
+        DrawPopGraphicContext(draw_wand);
       }
-      DrawPopClipPath(context);
+      DrawPopClipPath(draw_wand);
     }
-    DrawPopDefs(context);
+    DrawPopDefs(draw_wand);
     
-    DrawPushGraphicContext(context);
+    DrawPushGraphicContext(draw_wand);
     {
-      DrawSetClipPath(context, "url(#clip_1)");
+      DrawSetClipPath(draw_wand, "url(#clip_1)");
       
-      DrawPushGraphicContext(context);
+      DrawPushGraphicContext(draw_wand);
       {
-        DrawSetStrokeAntialias(context,True);
-        DrawSetStrokeWidth(context,4.032);
-        DrawSetStrokeLineCap(context,RoundCap);
-        DrawSetStrokeLineJoin(context,RoundJoin);
-        DrawSetStrokeDashArray(context,0,(const double *)NULL);
-        DrawSetStrokeColorString(context,"#ff0000");
-        DrawSetFillRule(context,EvenOddRule);
-        DrawSetFillColorString(context,"#ff00ff");
-        DrawRectangle(context,72,72,144,144);
+        DrawSetStrokeAntialias(draw_wand,True);
+        DrawSetStrokeWidth(draw_wand,4.032);
+        DrawSetStrokeLineCap(draw_wand,RoundCap);
+        DrawSetStrokeLineJoin(draw_wand,RoundJoin);
+        DrawSetStrokeDashArray(draw_wand,0,(const double *)NULL);
+        DrawSetStrokeColorString(draw_wand,"#ff0000");
+        DrawSetFillRule(draw_wand,EvenOddRule);
+        DrawSetFillColorString(draw_wand,"#ff00ff");
+        DrawRectangle(draw_wand,72,72,144,144);
       }
-      DrawPopGraphicContext(context);
+      DrawPopGraphicContext(draw_wand);
       
-      DrawPushGraphicContext(context);
+      DrawPushGraphicContext(draw_wand);
       {
-        DrawSetStrokeAntialias(context,True);
-        DrawSetStrokeWidth(context,9);
-        DrawSetStrokeLineCap(context,RoundCap);
-        DrawSetStrokeLineJoin(context,RoundJoin);
-        DrawSetStrokeDashArray(context,0,(const double *)NULL);
-        DrawSetStrokeColorString(context,"#00ff00");
-        DrawSetFillRule(context,EvenOddRule);
-        DrawSetFillColorString(context,"#0080ff");
-        DrawRoundRectangle(context,72,216,360,432,9,9);
+        DrawSetStrokeAntialias(draw_wand,True);
+        DrawSetStrokeWidth(draw_wand,9);
+        DrawSetStrokeLineCap(draw_wand,RoundCap);
+        DrawSetStrokeLineJoin(draw_wand,RoundJoin);
+        DrawSetStrokeDashArray(draw_wand,0,(const double *)NULL);
+        DrawSetStrokeColorString(draw_wand,"#00ff00");
+        DrawSetFillRule(draw_wand,EvenOddRule);
+        DrawSetFillColorString(draw_wand,"#0080ff");
+        DrawRoundRectangle(draw_wand,72,216,360,432,9,9);
       }
-      DrawPopGraphicContext(context);
+      DrawPopGraphicContext(draw_wand);
       
-      DrawPushGraphicContext(context);
+      DrawPushGraphicContext(draw_wand);
       {
         const PointInfo points[37] =
         {
@@ -111,33 +112,33 @@ static void ScribbleImage ( Image *image)
           { 378.1,81.72 }
         };
         
-        DrawSetStrokeAntialias(context,True);
-        DrawSetStrokeWidth(context,2.016);
-        DrawSetStrokeLineCap(context,RoundCap);
-        DrawSetStrokeLineJoin(context,RoundJoin);
-        DrawSetStrokeDashArray(context,0,(const double *)NULL);
-        DrawSetStrokeColorString(context,"#000080");
-        DrawSetFillRule(context,EvenOddRule);
-        DrawSetFillColorString(context,"#c2c280");
-        DrawPolygon(context,37,points);
+        DrawSetStrokeAntialias(draw_wand,True);
+        DrawSetStrokeWidth(draw_wand,2.016);
+        DrawSetStrokeLineCap(draw_wand,RoundCap);
+        DrawSetStrokeLineJoin(draw_wand,RoundJoin);
+        DrawSetStrokeDashArray(draw_wand,0,(const double *)NULL);
+        DrawSetStrokeColorString(draw_wand,"#000080");
+        DrawSetFillRule(draw_wand,EvenOddRule);
+        DrawSetFillColorString(draw_wand,"#c2c280");
+        DrawPolygon(draw_wand,37,points);
       }
-      DrawPopGraphicContext(context);
+      DrawPopGraphicContext(draw_wand);
       
-      DrawPushGraphicContext(context);
+      DrawPushGraphicContext(draw_wand);
       {
-        DrawSetStrokeAntialias(context,True);
-        DrawSetStrokeWidth(context,3.024);
-        DrawSetStrokeLineCap(context,RoundCap);
-        DrawSetStrokeLineJoin(context,RoundJoin);
-        DrawSetStrokeDashArray(context,0,(const double *)NULL);
-        DrawSetStrokeColorString(context,"#000080");
-        DrawSetFillRule(context,EvenOddRule);
-        DrawSetFillColorString(context,"#00ffff");
-        DrawEllipse(context,489.6,424.8,72,129.6,0,360);
+        DrawSetStrokeAntialias(draw_wand,True);
+        DrawSetStrokeWidth(draw_wand,3.024);
+        DrawSetStrokeLineCap(draw_wand,RoundCap);
+        DrawSetStrokeLineJoin(draw_wand,RoundJoin);
+        DrawSetStrokeDashArray(draw_wand,0,(const double *)NULL);
+        DrawSetStrokeColorString(draw_wand,"#000080");
+        DrawSetFillRule(draw_wand,EvenOddRule);
+        DrawSetFillColorString(draw_wand,"#00ffff");
+        DrawEllipse(draw_wand,489.6,424.8,72,129.6,0,360);
       }
-      DrawPopGraphicContext(context);
+      DrawPopGraphicContext(draw_wand);
       
-      DrawPushGraphicContext(context);
+      DrawPushGraphicContext(draw_wand);
       {
         const PointInfo points[48] =
         {
@@ -155,46 +156,46 @@ static void ScribbleImage ( Image *image)
           { 207.4,31.82 }, { 209.2,28.87 }, { 211.3,26.64},  { 213.8,25.13 }
         };
         
-        DrawSetStrokeAntialias(context,True);
-        DrawSetStrokeWidth(context,3.024);
-        DrawSetStrokeLineCap(context,RoundCap);
-        DrawSetStrokeLineJoin(context,RoundJoin);
-        DrawSetStrokeDashArray(context,0,(const double *)NULL);
-        DrawSetStrokeColorString(context,"#ff8000");
-        DrawSetFillRule(context,EvenOddRule);
-        DrawSetFillColorString(context,"#00ffff");
-        DrawPolygon(context,48,points);
+        DrawSetStrokeAntialias(draw_wand,True);
+        DrawSetStrokeWidth(draw_wand,3.024);
+        DrawSetStrokeLineCap(draw_wand,RoundCap);
+        DrawSetStrokeLineJoin(draw_wand,RoundJoin);
+        DrawSetStrokeDashArray(draw_wand,0,(const double *)NULL);
+        DrawSetStrokeColorString(draw_wand,"#ff8000");
+        DrawSetFillRule(draw_wand,EvenOddRule);
+        DrawSetFillColorString(draw_wand,"#00ffff");
+        DrawPolygon(draw_wand,48,points);
       }
-      DrawPopGraphicContext(context);
+      DrawPopGraphicContext(draw_wand);
       
-      DrawPushGraphicContext(context);
+      DrawPushGraphicContext(draw_wand);
       {
-        DrawSetStrokeAntialias(context,True);
-        DrawSetStrokeWidth(context,12.02);
-        DrawSetStrokeLineCap(context,RoundCap);
-        DrawSetStrokeLineJoin(context,RoundJoin);
-        DrawSetStrokeDashArray(context,0,(const double *)NULL);
-        DrawSetStrokeColorString(context,"#4000c2");
-        DrawSetFillColorString(context,"none");
-        DrawArc(context,360,554.4,187.2,237.6,0,90);
+        DrawSetStrokeAntialias(draw_wand,True);
+        DrawSetStrokeWidth(draw_wand,12.02);
+        DrawSetStrokeLineCap(draw_wand,RoundCap);
+        DrawSetStrokeLineJoin(draw_wand,RoundJoin);
+        DrawSetStrokeDashArray(draw_wand,0,(const double *)NULL);
+        DrawSetStrokeColorString(draw_wand,"#4000c2");
+        DrawSetFillColorString(draw_wand,"none");
+        DrawArc(draw_wand,360,554.4,187.2,237.6,0,90);
       }
-      DrawPopGraphicContext(context);
+      DrawPopGraphicContext(draw_wand);
 
-      DrawPushGraphicContext(context);
+      DrawPushGraphicContext(draw_wand);
       {
-        DrawSetStrokeAntialias(context,True);
-        DrawSetStrokeWidth(context,9);
-        DrawSetStrokeLineCap(context,RoundCap);
-        DrawSetStrokeLineJoin(context,RoundJoin);
-        DrawSetStrokeDashArray(context,0,(const double *)NULL);
-        DrawSetStrokeColorString(context,"#4000c2");
-        DrawSetFillRule(context,EvenOddRule);
-        DrawSetFillColorString(context,"#800000");
-        DrawEllipse(context,388.8,626.4,100.8,122.4,0,90);
+        DrawSetStrokeAntialias(draw_wand,True);
+        DrawSetStrokeWidth(draw_wand,9);
+        DrawSetStrokeLineCap(draw_wand,RoundCap);
+        DrawSetStrokeLineJoin(draw_wand,RoundJoin);
+        DrawSetStrokeDashArray(draw_wand,0,(const double *)NULL);
+        DrawSetStrokeColorString(draw_wand,"#4000c2");
+        DrawSetFillRule(draw_wand,EvenOddRule);
+        DrawSetFillColorString(draw_wand,"#800000");
+        DrawEllipse(draw_wand,388.8,626.4,100.8,122.4,0,90);
       }
-      DrawPopGraphicContext(context);
+      DrawPopGraphicContext(draw_wand);
 
-      DrawPushGraphicContext(context);
+      DrawPushGraphicContext(draw_wand);
       {
         const PointInfo points[6] =
         {
@@ -202,19 +203,19 @@ static void ScribbleImage ( Image *image)
           { 77.26,578.6 }, { 180,504 }
         };
         
-        DrawSetStrokeAntialias(context,True);
-        DrawSetStrokeWidth(context,9);
-        DrawSetStrokeLineCap(context,RoundCap);
-        DrawSetStrokeLineJoin(context,RoundJoin);
-        DrawSetStrokeDashArray(context,0,(const double *)NULL);
-        DrawSetStrokeColorString(context,"#4000c2");
-        DrawSetFillRule(context,EvenOddRule);
-        DrawSetFillColorString(context,"#800000");
-        DrawPolygon(context,6,points);
+        DrawSetStrokeAntialias(draw_wand,True);
+        DrawSetStrokeWidth(draw_wand,9);
+        DrawSetStrokeLineCap(draw_wand,RoundCap);
+        DrawSetStrokeLineJoin(draw_wand,RoundJoin);
+        DrawSetStrokeDashArray(draw_wand,0,(const double *)NULL);
+        DrawSetStrokeColorString(draw_wand,"#4000c2");
+        DrawSetFillRule(draw_wand,EvenOddRule);
+        DrawSetFillColorString(draw_wand,"#800000");
+        DrawPolygon(draw_wand,6,points);
       }
-      DrawPopGraphicContext(context);
+      DrawPopGraphicContext(draw_wand);
       
-      DrawPushGraphicContext(context);
+      DrawPushGraphicContext(draw_wand);
       {
         const PointInfo points[11] =
         {
@@ -223,19 +224,19 @@ static void ScribbleImage ( Image *image)
           { 77.26,578.6 }, { 148.2,568.3 }, { 180,504 }
         };
         
-        DrawSetStrokeAntialias(context,True);
-        DrawSetStrokeWidth(context,9);
-        DrawSetStrokeLineCap(context,RoundCap);
-        DrawSetStrokeLineJoin(context,RoundJoin);
-        DrawSetStrokeDashArray(context,0,(const double *)NULL);
-        DrawSetStrokeColorString(context,"#4000c2");
-        DrawSetFillRule(context,EvenOddRule);
-        DrawSetFillColorString(context,"#800000");
-        DrawPolygon(context,11,points);
+        DrawSetStrokeAntialias(draw_wand,True);
+        DrawSetStrokeWidth(draw_wand,9);
+        DrawSetStrokeLineCap(draw_wand,RoundCap);
+        DrawSetStrokeLineJoin(draw_wand,RoundJoin);
+        DrawSetStrokeDashArray(draw_wand,0,(const double *)NULL);
+        DrawSetStrokeColorString(draw_wand,"#4000c2");
+        DrawSetFillRule(draw_wand,EvenOddRule);
+        DrawSetFillColorString(draw_wand,"#800000");
+        DrawPolygon(draw_wand,11,points);
       }
-      DrawPopGraphicContext(context);
+      DrawPopGraphicContext(draw_wand);
       
-      DrawPushGraphicContext(context);
+      DrawPushGraphicContext(draw_wand);
       {
         const PointInfo points[15] =
         {
@@ -245,19 +246,19 @@ static void ScribbleImage ( Image *image)
           { 540,172.8 },   { 540,223.2 },   { 540,288 }
         };
         
-        DrawSetStrokeAntialias(context,True);
-        DrawSetStrokeWidth(context,5.976);
-        DrawSetStrokeLineCap(context,RoundCap);
-        DrawSetStrokeLineJoin(context,RoundJoin);
-        DrawSetStrokeDashArray(context,0,(const double *)NULL);
-        DrawSetStrokeColorString(context,"#4000c2");
-        DrawSetFillRule(context,EvenOddRule);
-        DrawSetFillColorString(context,"#ffff00");
-        DrawPolygon(context,15,points);
+        DrawSetStrokeAntialias(draw_wand,True);
+        DrawSetStrokeWidth(draw_wand,5.976);
+        DrawSetStrokeLineCap(draw_wand,RoundCap);
+        DrawSetStrokeLineJoin(draw_wand,RoundJoin);
+        DrawSetStrokeDashArray(draw_wand,0,(const double *)NULL);
+        DrawSetStrokeColorString(draw_wand,"#4000c2");
+        DrawSetFillRule(draw_wand,EvenOddRule);
+        DrawSetFillColorString(draw_wand,"#ffff00");
+        DrawPolygon(draw_wand,15,points);
       }
-      DrawPopGraphicContext(context);
+      DrawPopGraphicContext(draw_wand);
       
-      DrawPushGraphicContext(context);
+      DrawPushGraphicContext(draw_wand);
       {
         const PointInfo points[7] =
         {
@@ -265,19 +266,19 @@ static void ScribbleImage ( Image *image)
           { 151.2,756 }, { 86.4,748.8 }, { 57.6,640.8 }
         };
         
-        DrawSetStrokeAntialias(context,True);
-        DrawSetStrokeWidth(context,5.976);
-        DrawSetStrokeLineCap(context,RoundCap);
-        DrawSetStrokeLineJoin(context,RoundJoin);
-        DrawSetStrokeDashArray(context,0,(const double *)NULL);
-        DrawSetStrokeColorString(context,"#4000c2");
-        DrawSetFillRule(context,EvenOddRule);
-        DrawSetFillColorString(context,"#ffff00");
-        DrawPolygon(context,7,points);
+        DrawSetStrokeAntialias(draw_wand,True);
+        DrawSetStrokeWidth(draw_wand,5.976);
+        DrawSetStrokeLineCap(draw_wand,RoundCap);
+        DrawSetStrokeLineJoin(draw_wand,RoundJoin);
+        DrawSetStrokeDashArray(draw_wand,0,(const double *)NULL);
+        DrawSetStrokeColorString(draw_wand,"#4000c2");
+        DrawSetFillRule(draw_wand,EvenOddRule);
+        DrawSetFillColorString(draw_wand,"#ffff00");
+        DrawPolygon(draw_wand,7,points);
       }
-      DrawPopGraphicContext(context);
+      DrawPopGraphicContext(draw_wand);
       
-      DrawPushGraphicContext(context);
+      DrawPushGraphicContext(draw_wand);
       {
         const PointInfo points[193] =
         {
@@ -332,24 +333,24 @@ static void ScribbleImage ( Image *image)
           { 27.86,565.3 }
         };
         
-        DrawSetStrokeAntialias(context,True);
-        DrawSetStrokeWidth(context,5.904);
-        DrawSetStrokeLineCap(context,RoundCap);
-        DrawSetStrokeLineJoin(context,RoundJoin);
-        DrawSetStrokeDashArray(context,0,(const double *)NULL);
-        DrawSetStrokeColorString(context,"#4000c2");
-        DrawSetFillRule(context,EvenOddRule);
-        DrawSetFillColorString(context,"#ffff00");
-        DrawPolygon(context,193,points);
+        DrawSetStrokeAntialias(draw_wand,True);
+        DrawSetStrokeWidth(draw_wand,5.904);
+        DrawSetStrokeLineCap(draw_wand,RoundCap);
+        DrawSetStrokeLineJoin(draw_wand,RoundJoin);
+        DrawSetStrokeDashArray(draw_wand,0,(const double *)NULL);
+        DrawSetStrokeColorString(draw_wand,"#4000c2");
+        DrawSetFillRule(draw_wand,EvenOddRule);
+        DrawSetFillColorString(draw_wand,"#ffff00");
+        DrawPolygon(draw_wand,193,points);
       }
-      DrawPopGraphicContext(context);
+      DrawPopGraphicContext(draw_wand);
     }
-    DrawPopGraphicContext(context);
+    DrawPopGraphicContext(draw_wand);
   }
-  DrawPopGraphicContext(context);
+  DrawPopGraphicContext(draw_wand);
 
-  DrawRender(context);
-  DrawDestroyContext(context);
+  DrawRender(draw_wand);
+  DestroyDrawingWand(draw_wand);
 }
 
 int main ( int argc, char **argv )
