@@ -54,11 +54,13 @@
 /*
   Include declarations.
 */
-#include "studio.h"
-#include "command.h"
-#include "log.h"
-#include "version.h"
-#include "utility.h"
+#include "magick/studio.h"
+#include "magick/command.h"
+#include "magick/error.h"
+#include "magick/log.h"
+#include "magick/magick.h"
+#include "magick/version.h"
+#include "magick/utility.h"
 
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -94,7 +96,7 @@ static void CompositeUsage(void)
       "-colorspace type     alternate image colorspace",
       "-comment string      annotate image with comment",
       "-compose operator    composite operator",
-      "-compress type       image compression tyhpe",
+      "-compress type       image compression type",
       "-debug events        display copious debugging information",
       "-density geometry    horizontal and vertical density of the image",
       "-depth value         image depth",
@@ -132,6 +134,7 @@ static void CompositeUsage(void)
       "-size geometry       width and height of image",
       "-stegano offset      hide watermark within an image",
       "-stereo              combine two image to create a stereo anaglyph",
+      "-thumbnail geometry  create a thumbnail of the image",
       "-tile                repeat composite operation across image",
       "-transform           affine transform image",
       "-treedepth value     color tree depth",
