@@ -59,11 +59,13 @@
 /*
   Include declarations.
 */
-#include "studio.h"
-#include "command.h"
-#include "log.h"
-#include "utility.h"
-#include "version.h"
+#include "magick/studio.h"
+#include "magick/command.h"
+#include "magick/error.h"
+#include "magick/log.h"
+#include "magick/magick.h"
+#include "magick/utility.h"
+#include "magick/version.h"
 
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -95,6 +97,8 @@ static void ConvertUsage(void)
       "-authenticate value  decrypt image with this password",
       "-average             average an image sequence",
       "-background color    background color",
+      "-black-threshold value",
+      "                     forces all pixels below the threshold into black",
       "-blue-primary point  chomaticity blue primary point",
       "-blur geometry       blur the image",
       "-border geometry     surround image with a border of color",
@@ -108,7 +112,7 @@ static void ConvertUsage(void)
       "-colors value        preferred number of colors in the image",
       "-colorspace type     alternate image colorspace",
       "-comment string      annotate image with comment",
-      "-compress type       image compression tyhpe",
+      "-compress type       image compression type",
       "-contrast            enhance or reduce the image contrast",
       "-convolve coefficients",
       "                     apply a convolution kernel to the image",
@@ -168,6 +172,8 @@ static void ConvertUsage(void)
       "-noise radius        add or reduce noise in an image",
       "-normalize           transform image to span the full range of colors",
       "-opaque color        change this color to the fill color",
+      "-ordered-dither channeltype LOWxHIGH",
+      "                     ordered dither the image",
       "-page geometry       size and location of an image canvas",
       "-paint radius        simulate an oil painting",
       "-ping                efficiently determine image attributes",
@@ -176,11 +182,14 @@ static void ConvertUsage(void)
       "-profile filename    add ICM or IPTC information profile to image",
       "-quality value       JPEG/MIFF/PNG compression level",
       "-raise value         lighten/darken image edges to create a 3-D effect",
+      "-random-threshold    channeltype LOWxHIGH",
+      "                     random threshold the image",
       "-region geometry     apply options to a portion of the image",
       "-raise value         lighten/darken image edges to create a 3-D effect",
       "-red-primary point   chomaticity red primary point",
       "-render              render vector graphics",
       "-resize geometry     resize the image",
+      "-resample geometry   change the resolution of an image",
       "-roll geometry       roll an image vertically or horizontally",
       "-rotate degrees      apply Paeth rotation to the image",
       "-sample geometry     scale image with pixel sampling",
@@ -202,6 +211,7 @@ static void ConvertUsage(void)
       "-swirl degrees       swirl image pixels about the center",
       "-texture filename    name of texture to tile onto the image background",
       "-threshold value     threshold the image",
+      "-thumbnail geometry  create a thumbnail of the image",
       "-tile filename       tile image when filling a graphic primitive",
       "-transform           affine transform image",
       "-transparent color   make this color transparent within the image",
@@ -218,6 +228,8 @@ static void ConvertUsage(void)
       "                     Constant, Edge, Mirror, or Tile",
       "-wave geometry       alter an image along a sine wave",
       "-white-point point   chomaticity white point",
+      "-white-threshold value",
+      "                     forces all pixels above the threshold into white",
       "-write filename      write images to this file",
       (char *) NULL
     };
