@@ -55,16 +55,18 @@
 /*
   Include declarations.
 */
-#include "studio.h"
-#include "command.h"
-#include "delegate.h"
-#include "log.h"
-#include "magic.h"
-#include "module.h"
-#include "render.h"
-#include "resource.h"
-#include "utility.h"
-#include "version.h"
+#include "magick/studio.h"
+#include "magick/command.h"
+#include "magick/delegate.h"
+#include "magick/error.h"
+#include "magick/log.h"
+#include "magick/magic.h"
+#include "magick/magick.h"
+#include "magick/module.h"
+#include "magick/render.h"
+#include "magick/resource.h"
+#include "magick/utility.h"
+#include "magick/version.h"
 
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
