@@ -56,11 +56,13 @@
 /*
   Include declarations.
 */
-#include "studio.h"
-#include "command.h"
-#include "log.h"
-#include "utility.h"
-#include "version.h"
+#include "magick/studio.h"
+#include "magick/command.h"
+#include "magick/error.h"
+#include "magick/log.h"
+#include "magick/magick.h"
+#include "magick/utility.h"
+#include "magick/version.h"
 
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -98,7 +100,7 @@ static void MontageUsage(void)
       "-colorspace type     alternate image colorsapce",
       "-comment string      annotate image with comment",
       "-compose operator    composite operator",
-      "-compress type       image compression tyhpe",
+      "-compress type       image compression type",
       "-crop geometry       preferred size and location of the cropped image",
       "-debug events        display copious debugging information",
       "-density geometry    horizontal and vertical density of the image",
@@ -141,6 +143,7 @@ static void MontageUsage(void)
       "-size geometry       width and height of image",
       "-stroke color        color to use when stroking a graphic primitive",
       "-texture filename    name of texture to tile onto the image background",
+      "-thumbnail geometry  create a thumbnail of the image",
       "-tile geometry       number of tiles per row and column",
       "-transform           affine transform image",
       "-transparent color   make this color transparent within the image",
